<?php

/*
 +-----------------------------------------------------------------------+
 | localization/<lang>/labels.inc                                        |
 |                                                                       |
 | Localization file of the Roundcube Webmail client                     |
 | Copyright (C) 2005-2015, The Roundcube Dev Team                       |
 |                                                                       |
 | Licensed under the GNU General Public License version 3 or            |
 | any later version with exceptions for skins & plugins.                |
 | See the README file for a full license statement.                     |
 |                                                                       |
 +-----------------------------------------------------------------------+

 For translation see https://www.transifex.com/projects/p/roundcube-webmail/resource/labels/
*/
$labels['welcome']   = 'Welkom bij $product';
$labels['username']  = 'Gebruikersnaam';
$labels['password']  = 'Wachtwoord';
$labels['server']    = 'Server';
$labels['login']     = 'Aanmelden';
$labels['logout']   = 'Afmelden';
$labels['mail']     = 'Berichten';
$labels['settings'] = 'Instellingen';
$labels['addressbook'] = 'Contactpersonen';
$labels['inbox']  = 'Postvak IN';
$labels['drafts'] = 'Concepten';
$labels['sent']   = 'Verzonden berichten';
$labels['trash']  = 'Prullenbak';
$labels['junk']   = 'Spam';
$labels['subject'] = 'Onderwerp';
$labels['from']    = 'Van';
$labels['sender']  = 'Afzender';
$labels['to']      = 'Aan';
$labels['cc']      = 'Cc';
$labels['bcc']     = 'Bcc';
$labels['replyto'] = 'Antwoorden aan';
$labels['followupto'] = 'Followup aan';
$labels['date']    = 'Datum';
$labels['size']    = 'Grootte';
$labels['priority'] = 'Prioriteit';
$labels['organization'] = 'Organisatie';
$labels['readstatus'] = 'Gelezen?';
$labels['listoptions'] = 'Lijstopties...';
$labels['mailboxlist'] = 'Mappen';
$labels['messagesfromto'] = 'Berichten $from - $to van $count';
$labels['threadsfromto'] = 'Conversaties $from - $to van $count';
$labels['messagenrof'] = 'Bericht $nr van $count';
$labels['fromtoshort'] = '$from - $to van $count';
$labels['copy']     = 'Kopieer';
$labels['move']     = 'Verplaats';
$labels['moveto']   = 'Verplaats naar...';
$labels['download'] = 'Downloaden';
$labels['showattachment'] = 'Weergeven';
$labels['showanyway'] = 'Toch weergeven';
$labels['filename'] = 'Bestandsnaam';
$labels['filesize'] = 'Bestandsgrootte';
$labels['addtoaddressbook'] = 'Voeg toe aan lijst met contactpersonen';
$labels['sun'] = 'Zo';
$labels['mon'] = 'Ma';
$labels['tue'] = 'Di';
$labels['wed'] = 'Wo';
$labels['thu'] = 'Do';
$labels['fri'] = 'Vr';
$labels['sat'] = 'Za';
$labels['sunday']    = 'Zondag';
$labels['monday']    = 'Maandag';
$labels['tuesday']   = 'Dinsdag';
$labels['wednesday'] = 'Woensdag';
$labels['thursday']  = 'Donderdag';
$labels['friday']    = 'Vrijdag';
$labels['saturday']  = 'Zaterdag';
$labels['jan']	= 'Jan';
$labels['feb']	= 'Feb';
$labels['mar']	= 'Mrt';
$labels['apr']	= 'Apr';
$labels['may']	= 'Mei';
$labels['jun']	= 'Jun';
$labels['jul'] 	= 'Jul';
$labels['aug']	= 'Aug';
$labels['sep']	= 'Sep';
$labels['oct']	= 'Okt';
$labels['nov']	= 'Nov';
$labels['dec']	= 'Dec';
$labels['longjan']	= 'Januari';
$labels['longfeb']	= 'Februari';
$labels['longmar']	= 'Maart';
$labels['longapr']	= 'April';
$labels['longmay']	= 'Mei';
$labels['longjun']	= 'Juni';
$labels['longjul']	= 'Juli';
$labels['longaug']	= 'Augustus';
$labels['longsep']	= 'September';
$labels['longoct']	= 'Oktober';
$labels['longnov']	= 'November';
$labels['longdec']	= 'December';
$labels['today'] = 'Vandaag';
$labels['refresh']          = 'Vernieuwen';
$labels['checkmail']        = 'Controleer op nieuwe berichten';
$labels['compose']          = 'Nieuw bericht opstellen';
$labels['writenewmessage']  = 'Nieuw bericht';
$labels['reply']            = 'Beantwoorden';
$labels['replytomessage']   = 'Beantwoorden aan afzender';
$labels['replytoallmessage'] = 'Antwoorden naar lijst of naar afzender en alle ontvangers';
$labels['replyall']         = 'Allen beantwoorden';
$labels['replylist']        = 'Lijst beantwoorden';
$labels['forward']          = 'Doorsturen';
$labels['forwardattachment'] = 'Doorsturen als bijlage';
$labels['forwardmessage']   = 'Bericht doorsturen';
$labels['deletemessage']    = 'Dit bericht verwijderen';
$labels['movemessagetotrash'] = 'Verplaats bericht naar verwijderde items';
$labels['printmessage']     = 'Afdrukken';
$labels['previousmessage']  = 'Vorig bericht';
$labels['firstmessage']     = 'Eerste bericht';
$labels['nextmessage']      = 'Volgende bericht';
$labels['lastmessage']      = 'Laatste bericht';
$labels['backtolist']       = 'Terug naar berichtenlijst';
$labels['viewsource']       = 'Broncode bericht weergeven';
$labels['mark']             = 'Markeren';
$labels['markmessages']     = 'Markeer berichten';
$labels['markread']         = 'Als gelezen';
$labels['markunread']       = 'Als ongelezen';
$labels['markflagged']      = 'Selecteren';
$labels['markunflagged']    = 'Niet Selecteren';
$labels['moreactions']      = 'Meer acties...';
$labels['more']             = 'Meer';
$labels['back']             = 'Terug';
$labels['options']          = 'Opties';
$labels['select'] = 'Selecteren';
$labels['all'] = 'Alle';
$labels['none'] = 'Geen';
$labels['currpage'] = 'Huidige pagina';
$labels['unread'] = 'Ongelezen';
$labels['flagged'] = 'Geselecteerd';
$labels['unanswered'] = 'Onbeantwoord';
$labels['deleted'] = 'Verwijderd';
$labels['undeleted'] = 'Niet verwijderd';
$labels['invert'] = 'Selectie omkeren';
$labels['filter'] = 'Filter';
$labels['list'] = 'Lijst';
$labels['threads'] = 'Conversaties';
$labels['expand-all'] = 'Alles uitklappen';
$labels['expand-unread'] = 'Ongelezen uitklappen';
$labels['collapse-all'] = 'Alles inklappen';
$labels['threaded'] = 'Conversaties';
$labels['autoexpand_threads'] = 'Klap alle conversaties uit';
$labels['do_expand'] = 'alle conversaties';
$labels['expand_only_unread'] = 'alleen met ongelezen berichten';
$labels['fromto'] = 'Afzender/Ontvanger';
$labels['flag'] = 'Markeer';
$labels['attachment'] = 'Bijlage';
$labels['nonesort'] = 'Geen';
$labels['sentdate'] = 'Verzenddatum';
$labels['arrival'] = 'Ontvangstdatum';
$labels['asc'] = 'oplopend';
$labels['desc'] = 'aflopend';
$labels['listcolumns'] = 'Kolommen';
$labels['listsorting'] = 'Sorteerkolom';
$labels['listorder'] = 'Sorteervolgorde';
$labels['listmode'] = 'Lijstweergave mode';
$labels['layoutlist'] = 'Lijst';
$labels['folderactions'] = 'Acties voor map...';
$labels['compact'] = 'Comprimeren';
$labels['empty'] = 'Legen';
$labels['quota'] = 'Gebruikte schijfruimte';
$labels['unknown']  = 'onbekend';
$labels['unlimited']  = 'onbeperkt';
$labels['quotastorage'] = 'Schijfruimte';
$labels['quicksearch']  = 'Snelzoeken';
$labels['resetsearch']  = 'Zoek opnieuw';
$labels['searchmod']  = 'Zoekopties';
$labels['msgtext']  = 'Volledig bericht';
$labels['namex'] = 'Naam';
$labels['currentfolder'] = 'Huidige map';
$labels['searchinterval-1W'] = 'ouder dan een week';
$labels['searchinterval-1M'] = 'ouder dan een maand';
$labels['searchinterval-1Y'] = 'ouder dan een jaar';
$labels['searchinterval1W'] = 'jonger dan een week';
$labels['searchinterval1M'] = 'jonger dan een maand';
$labels['searchinterval1Y'] = 'jonger dan een jaar';
$labels['openinextwin'] = 'Openen in een nieuw venster';
$labels['emlsave'] = 'Opslaan (.eml)';
$labels['editasnew']      = 'Als nieuw bewerken';
$labels['send']           = 'Verzenden';
$labels['sendmessage']    = 'Bericht verzenden';
$labels['savemessage']    = 'Bewaar als concept';
$labels['addattachment']  = 'Bestand toevoegen als bijlage';
$labels['charset']        = 'Karakterset';
$labels['editortype']     = 'Opmaak';
$labels['returnreceipt']  = 'Ontvangstbevestiging';
$labels['dsn']            = 'Delivery Status Notification';
$labels['mailreplyintro'] = 'Op $date, schreef $sender:';
$labels['originalmessage'] = 'Orgineel bericht';
$labels['selectimage']    = 'Selecteer beeld';
$labels['addimage']       = 'Voeg beeld toe';
$labels['selectmedia']    = 'Selecteer film';
$labels['addmedia']       = 'Voeg film toe';
$labels['keylength']      = 'Bits';
$labels['keyexpired']     = 'Verlopen';
$labels['editidents']    = 'Bewerk identiteiten';
$labels['spellcheck']    = 'Spellen';
$labels['checkspelling'] = 'Controleer spelling';
$labels['resumeediting'] = 'Hervat bewerken';
$labels['revertto']      = 'Ongedaan maken';
$labels['ignore'] = 'Negeer';
$labels['responses'] = 'Antwoorden';
$labels['insertresponse'] = 'Antwoord invoegen';
$labels['manageresponses'] = 'Antwoorden beheren';
$labels['newresponse'] = 'Nieuw antwoord';
$labels['addresponse'] = 'Antwoord invoegen';
$labels['editresponse'] = 'Antwoord bewerken';
$labels['editresponses'] = 'Antwoorden bewerken';
$labels['responsename'] = 'Naam';
$labels['attach'] = 'Bijvoegen';
$labels['attachments'] = 'Bijlagen';
$labels['upload'] = 'Uploaden';
$labels['close']  = 'Sluiten';
$labels['messageoptions']  = 'Opties voor bericht...';
$labels['low']     = 'Laag';
$labels['lowest']  = 'Laagste';
$labels['normal']  = 'Normaal';
$labels['high']    = 'Hoog';
$labels['highest'] = 'Hoogste';
$labels['nosubject']  = '(geen onderwerp)';
$labels['showimages'] = 'Toon afbeeldingen';
$labels['alwaysshow'] = 'Afbeeldingen van $sender altijd tonen';
$labels['isdraft']    = 'Dit is een concept bericht.';
$labels['andnmore']   = '$nr meer...';
$labels['togglemoreheaders'] = 'Toon meer berichthoofden';
$labels['htmltoggle'] = 'HTML';
$labels['plaintoggle'] = 'Platte tekst';
$labels['savesentmessagein'] = 'Bewaar verzonden bericht in';
$labels['dontsave'] = 'niet bewaren';
$labels['maxuploadsize'] = 'Maximum toegestane bestandsgrootte is $size';
$labels['addcc'] = 'Cc toevoegen';
$labels['addbcc'] = 'Bcc toevoegen';
$labels['addreplyto'] = 'Antwoorden aan toevoegen';
$labels['addfollowupto'] = 'Followup aan toevoegen';
$labels['mdnrequest'] = 'De afzender heeft een ontvangstbevestiging gevraagd. Wilt u deze versturen?';
$labels['receiptread'] = 'Ontvangstbevestiging (gelezen)';
$labels['yourmessage'] = 'Dir is een onvangstbevestiging voor uw bericht';
$labels['receiptnote'] = 'Opmerking: deze ontvangstbevestiging houdt enkel in dat het bericht was weergegeven bij de ontvanger. Er is geen garantie dat de ontvanger het bericht daadwerkelijk heeft gelezen en/of begrepen.';
$labels['name']         = 'Naam';
$labels['firstname']    = 'Voornaam';
$labels['surname']      = 'Achternaam';
$labels['middlename']   = 'Middelnaam';
$labels['nameprefix']   = 'Prefix';
$labels['namesuffix']   = 'Suffix';
$labels['nickname']     = 'Roepnaam';
$labels['jobtitle']     = 'Job titel';
$labels['gender']       = 'Geslacht';
$labels['email']        = 'E-mailadres';
$labels['phone']        = 'Telefoonnummer';
$labels['address']      = 'Adres';
$labels['street']       = 'Straat';
$labels['locality']     = 'Stad';
$labels['zipcode']      = 'Postcode';
$labels['region']       = 'Staat/Provincie';
$labels['country']      = 'Land';
$labels['birthday']     = 'Verjaardag';
$labels['website']      = 'Website';
$labels['male']   = 'man';
$labels['female'] = 'vrouw';
$labels['manager'] = 'Manager';
$labels['assistant'] = 'Assistent';
$labels['allfields'] = 'Alle velden';
$labels['search'] = 'Zoek';
$labels['searchresult'] = 'Zoekresultaat';
$labels['advanced'] = 'Geavanceerd';
$labels['other'] = 'Anders';
$labels['printcontact'] = 'Contactpersoon afdrukken';
$labels['typehome']   = 'Thuis';
$labels['typework']   = 'Werk';
$labels['typeother']  = 'Anders';
$labels['typemobile']  = 'Mobiel';
$labels['typehomefax']  = 'Thuis fax';
$labels['typeworkfax']  = 'Werk fax';
$labels['typecar']  = 'Auto';
$labels['typepager']  = 'Pager';
$labels['typevideo']  = 'Video';
$labels['typeassistant']  = 'Assistent';
$labels['typehomepage']  = 'Home page';
$labels['typeblog'] = 'Blog';
$labels['typeprofile'] = 'Profiel';
$labels['addfield'] = 'Veld toevoegen...';
$labels['addcontact'] = 'Contactpersoon toevoegen';
$labels['editcontact'] = 'Contactpersoon bewerken';
$labels['contacts'] = 'Contactpersonen';
$labels['contactproperties'] = 'Eigenschappen van contactpersoon';
$labels['contactnameandorg'] = 'Naam en organisatie';
$labels['personalinfo'] = 'Persoonlijke informatie';
$labels['contactphoto'] = 'Contact foto';
$labels['edit']   = 'Bewerken';
$labels['cancel'] = 'Annuleren';
$labels['save']   = 'Opslaan';
$labels['delete'] = 'Verwijderen';
$labels['rename'] = 'Hernoemen';
$labels['addphoto'] = 'Toevoegen';
$labels['replacephoto'] = 'Vervangen';
$labels['uploadphoto'] = 'Foto  uploaden';
$labels['newcontact']     = 'Nieuw contact';
$labels['deletecontact']  = 'Verwijder geselecteerde contactpersonen';
$labels['composeto']      = 'Mail sturen aan';
$labels['contactsfromto'] = 'Contactpersonen $from - $to van $count';
$labels['print']          = 'Afdrukken';
$labels['export']         = 'Exporteren';
$labels['exportall']      = 'Exporteer alle';
$labels['exportsel']      = 'Exporteer geslecteerden';
$labels['exportvcards']   = 'Exporteer contactpersonen in vCard formaat';
$labels['newgroup']       = 'Maak een nieuwe groep';
$labels['addgroup']       = 'Groep toevoegen';
$labels['grouprename']    = 'Groep hernoemen';
$labels['groupdelete']    = 'Groep verwijderen';
$labels['previouspage']   = 'Toon vorige';
$labels['firstpage']      = 'Toon eerste';
$labels['nextpage']       = 'Toon volgende';
$labels['lastpage']       = 'Toon laatste';
$labels['group'] = 'Groep';
$labels['groups'] = 'Groepen';
$labels['personaladrbook'] = 'Personlijke adressen';
$labels['import'] = 'Importeer';
$labels['importcontacts'] = 'Contactpersonen importeren';
$labels['importfromfile'] = 'Importeer van bestand:';
$labels['importreplace'] = 'Vervang het complete adresboek';
$labels['done'] = 'Klaar';
$labels['settingsfor'] = 'Instellingen voor';
$labels['about'] = 'Over';
$labels['preferences'] = 'Voorkeuren';
$labels['userpreferences'] = 'Gebruikersvoorkeuren';
$labels['editpreferences'] = 'Gebruikersvoorkeuren bewerken';
$labels['identities'] = 'Identiteiten';
$labels['preferhtml'] = 'Gebruik HTML-opmaak';
$labels['defaultcharset'] = 'Standaard karakterset';
$labels['htmlmessage'] = 'HTML-bericht';
$labels['prettydate'] = 'Uitgebreide datumweergave';
$labels['setdefault']  = 'Als standaard instellen';
$labels['autodetect']  = 'Automatisch';
$labels['language']  = 'Taal';
$labels['timezone']  = 'Tijdzone';
$labels['pagesize']  = 'Berichten per pagina';
$labels['signature'] = 'Handtekening';
$labels['dstactive']  = 'Zomer/wintertijd';
$labels['htmleditor'] = 'HTML berichten opmaken';
$labels['htmlonreply'] = 'enkel bij beantwoorden van een HTML bericht';
$labels['htmlsignature'] = 'HTML handtekening';
$labels['previewpane'] = 'Toon voorbeeldvenster';
$labels['skin'] = 'Opmaakprofiel';
$labels['logoutclear'] = 'Prullenbak legen bij uitloggen';
$labels['logoutcompact'] = 'Postvak IN opschonen bij uitloggen';
$labels['uisettings'] = 'Gebruikersinterface';
$labels['serversettings'] = 'Serverinstellingen';
$labels['mailboxview'] = 'Opmaak Mailbox';
$labels['mdnrequests'] = 'Ontvangstmeldingen';
$labels['askuser'] = 'vraag de gebruiker';
$labels['autosend'] = 'stuur automatisch';
$labels['autosendknown'] = 'stuur ontvangstbevestiging naar mijn contactpersonen, anders vraag mij';
$labels['autosendknownignore'] = 'stuur ontvangstbevestiging naar mijn contactpersonen, anders negeer';
$labels['ignorerequest'] = 'negeer verzoek';
$labels['readwhendeleted'] = 'Bericht na verwijderen als gelezen markeren';
$labels['flagfordeletion'] = 'Bericht niet verwijderen maar als verwijderd markeren';
$labels['skipdeleted'] = 'Verwijderde berichten niet tonen';
$labels['deletealways'] = 'Verwijder bericht wanneer verplaatsen naar Prullenbak mislukt';
$labels['showremoteimages'] = 'Geef externe toegevoegde berichten weer';
$labels['fromknownsenders'] = 'Van bekende afzenders';
$labels['always'] = 'altijd';
$labels['showinlineimages'] = 'Toon bijgevoegde afbeeldingen onder het bericht';
$labels['autosavedraft']  = 'Automatisch als concept opslaan';
$labels['everynminutes']  = 'elke $n minuten';
$labels['never']  = 'nooit';
$labels['immediately']  = 'onmiddellijk';
$labels['messagesdisplaying'] = 'Berichten weergave';
$labels['messagescomposition'] = 'Berichten aanmaken';
$labels['mimeparamfolding'] = 'Namen van bijlagen';
$labels['2231folding'] = 'Volledig RFC 2231 (Thunderbird)';
$labels['miscfolding'] = 'RFC 2047/2231 (MS Outlook)';
$labels['2047folding'] = 'Volledig RFC 2047 (andere)';
$labels['force7bit'] = 'Gebruik MIME codering voor 8-bit karakters';
$labels['advancedoptions'] = 'Geavanceerde opties';
$labels['focusonnewmessage'] = 'Focus browserscherm bij nieuw bericht';
$labels['checkallfolders'] = 'Controleer alle mappen op nieuwe berichten';
$labels['displaynext'] = 'Na verplaatsen/verwijderen het volgende bericht tonen';
$labels['mainoptions'] = 'Hoofdopties';
$labels['section'] = 'Sectie';
$labels['maintenance'] = 'Onderhoud';
$labels['newmessage'] = 'Nieuw bericht';
$labels['signatureoptions'] = 'Opties voor handtekening';
$labels['whenreplying'] = 'Bij beantwoorden';
$labels['replytopposting'] = 'begin bericht boven het origineel';
$labels['replybottomposting'] = 'begin bericht onder het origineel';
$labels['replyremovesignature'] = 'Verwijder handtekening uit het origneel bij beantwoorden';
$labels['autoaddsignature'] = 'Handtekening automatisch toevoegen';
$labels['newmessageonly'] = 'alleen bij nieuwe berichten';
$labels['replyandforwardonly'] = 'alleen bij beantwoorden en doorsturen';
$labels['insertsignature'] = 'Handtekening invoegen';
$labels['afternseconds']  = 'Na $n seconden';
$labels['reqmdn'] = 'Vraag altijd een ontvangstbevestiging';
$labels['reqdsn'] = 'Vraag altijd een Delivery Status Notification';
$labels['replysamefolder'] = 'Plaats antwoorden in de map van het beantwoorde bericht';
$labels['folder'] = 'Map';
$labels['folders'] = 'Mappen';
$labels['foldername'] = 'Naam';
$labels['subscribed'] = 'Geabonneerd';
$labels['messagecount'] = 'Berichten';
$labels['create'] = 'Aanmaken';
$labels['createfolder'] = 'Nieuwe map aanmaken';
$labels['managefolders'] = 'Mappen beheren';
$labels['specialfolders'] = 'Speciale mappen';
$labels['properties'] = 'Eigenschappen';
$labels['folderproperties'] = 'Eigenschappen van map';
$labels['parentfolder'] = 'Bovenliggende map';
$labels['location'] = 'Locatie';
$labels['info'] = 'Informatie';
$labels['getfoldersize'] = 'Klik voor de grootte van de map';
$labels['changesubscription'] = 'Klik voor abonnement te wijzigen';
$labels['sortby'] = 'Sorteren op';
$labels['sortasc']  = 'Oplopend sorteren';
$labels['sortdesc'] = 'Aflopend sorteren';
$labels['license'] = 'Licentie';
$labels['B'] = 'B';
$labels['KB'] = 'KB';
$labels['MB'] = 'MB';
$labels['GB'] = 'GB';
$labels['unicode'] = 'Unicode';
$labels['english'] = 'Engels';
$labels['westerneuropean'] = 'West-Europees';
$labels['easterneuropean'] = 'Oost-Europees';
$labels['southeasterneuropean'] = 'Zuidoost Europees';
$labels['baltic'] = 'Baltisch';
$labels['cyrillic'] = 'Cyrillisch';
$labels['arabic'] = 'Arabisch';
$labels['greek'] = 'Grieks';
$labels['hebrew'] = 'Hebreeuws';
$labels['turkish'] = 'Turks';
$labels['nordic'] = 'Noord-Germaans';
$labels['thai'] = 'Thais';
$labels['celtic'] = 'Keltisch';
$labels['vietnamese'] = 'Vietnamees';
$labels['japanese'] = 'Japans';
$labels['korean'] = 'Koreaans';
$labels['chinese'] = 'Chinees';
?>
