<?php

/*
 +-----------------------------------------------------------------------+
 | plugins/password/localization/<lang>.inc                              |
 |                                                                       |
 | Localization file of the Roundcube Webmail Password plugin            |
 | Copyright (C) 2012-2013, The Roundcube Dev Team                       |
 |                                                                       |
 | Licensed under the GNU General Public License version 3 or            |
 | any later version with exceptions for skins & plugins.                |
 | See the README file for a full license statement.                     |
 |                                                                       |
 +-----------------------------------------------------------------------+

 For translation see https://www.transifex.com/projects/p/roundcube-webmail/resource/plugin-password/
*/
$labels['changepasswd']  = 'Athraigh an focal faire';
$labels['curpasswd']  = 'An focal faire reatha:';
$labels['newpasswd']  = 'An focal faire nua:';
$labels['confpasswd']  = 'Deimhnigh an focal faire nua:';
$messages['nopassword'] = 'Cuir isteach focal faire nua.';
$messages['internalerror'] = 'Níorbh fhéidir an focal faire nua a chur i dtaisce.';
$messages['passwinhistory'] = 'Baineadh feidhm as an bhfocal faire seo cheana.';
