<?php

/*
 +-----------------------------------------------------------------------+
 | localization/<lang>/labels.inc                                        |
 |                                                                       |
 | Localization file of the Roundcube Webmail client                     |
 | Copyright (C) 2005-2015, The Roundcube Dev Team                       |
 |                                                                       |
 | Licensed under the GNU General Public License version 3 or            |
 | any later version with exceptions for skins & plugins.                |
 | See the README file for a full license statement.                     |
 |                                                                       |
 +-----------------------------------------------------------------------+

 For translation see https://www.transifex.com/projects/p/roundcube-webmail/resource/labels/
*/
$labels['welcome']   = 'Velkomin í $product';
$labels['username']  = 'Netfang';
$labels['password']  = 'Lykilorð';
$labels['server']    = 'Póstþjónn';
$labels['login']     = 'Innskrá';
$labels['menu']     = 'Valmynd';
$labels['logout']   = 'Útskrá';
$labels['mail']     = 'Tölvupóstur';
$labels['settings'] = 'Stillingar';
$labels['addressbook'] = 'Nafnaskrá';
$labels['inbox']  = 'Innhólf';
$labels['drafts'] = 'Drög';
$labels['sent']   = 'Sent';
$labels['trash']  = 'Rusl';
$labels['junk']   = 'Ruslpóstur';
$labels['show_real_foldernames'] = 'Birta raunveruleg heiti á sérmöppum';
$labels['subject'] = 'Titill';
$labels['from']    = 'Frá';
$labels['sender']  = 'Sendandi';
$labels['to']      = 'Til';
$labels['cc']      = 'Afrit';
$labels['bcc']     = 'Falið afrit';
$labels['replyto'] = 'Svar til';
$labels['followupto'] = 'Svar við';
$labels['date']    = 'Dagsetning';
$labels['size']    = 'Stærð';
$labels['priority'] = 'Forgangur';
$labels['organization'] = 'Stofnun';
$labels['readstatus'] = 'Lesmerking';
$labels['listoptions'] = 'Telja upp valkosti...';
$labels['listoptionstitle'] = 'Valkostir lista';
$labels['mailboxlist'] = 'Möppur';
$labels['messagesfromto'] = 'Skeyti $from til $to af $count';
$labels['threadsfromto'] = 'Skeytaþræðir $from til $to af $count';
$labels['messagenrof'] = 'Skeyti $nr af $count';
$labels['fromtoshort'] = '$from - $to af $count';
$labels['copy']     = 'Afrit';
$labels['move']     = 'Færa';
$labels['moveto']   = 'Færa í...';
$labels['copyto']   = 'Afrita í...';
$labels['download'] = 'Sækja';
$labels['open']     = 'Opna';
$labels['showattachment'] = 'Birta';
$labels['showanyway'] = 'Birta það samt';
$labels['filename'] = 'Skráarheiti';
$labels['filesize'] = 'Skráarstærð';
$labels['addtoaddressbook'] = 'Bæta í nafnaskrá';
$labels['sun'] = 'sun.';
$labels['mon'] = 'mán.';
$labels['tue'] = 'þri.';
$labels['wed'] = 'mið.';
$labels['thu'] = 'fim.';
$labels['fri'] = 'fös.';
$labels['sat'] = 'lau.';
$labels['sunday']    = 'sunnudagur';
$labels['monday']    = 'mánudagur';
$labels['tuesday']   = 'þriðjudagur';
$labels['wednesday'] = 'miðvikudagur';
$labels['thursday']  = 'fimmtudagur';
$labels['friday']    = 'föstudagur';
$labels['saturday']  = 'laugardagur';
$labels['jan']	= 'jan';
$labels['feb']	= 'feb';
$labels['mar']	= 'mar';
$labels['apr']	= 'apr';
$labels['may']	= 'maí';
$labels['jun']	= 'jún';
$labels['jul'] 	= 'júl';
$labels['aug']	= 'ágú';
$labels['sep']	= 'sep';
$labels['oct']	= 'okt';
$labels['nov']	= 'nóv';
$labels['dec']	= 'des';
$labels['longjan']	= 'janúar';
$labels['longfeb']	= 'febrúar';
$labels['longmar']	= 'mars';
$labels['longapr']	= 'apríl';
$labels['longmay']	= 'maí';
$labels['longjun']	= 'júní';
$labels['longjul']	= 'júlí';
$labels['longaug']	= 'ágúst';
$labels['longsep']	= 'september';
$labels['longoct']	= 'október';
$labels['longnov']	= 'nóvember';
$labels['longdec']	= 'desember';
$labels['today'] = 'Í dag';
$labels['refresh']          = 'Endurhlaða';
$labels['checkmail']        = 'Athuga með ný skeyti';
$labels['compose']          = 'Semja skeyti';
$labels['writenewmessage']  = 'Búa til nýtt skeyti';
$labels['reply']            = 'Svara';
$labels['replytomessage']   = 'Svara skeyti';
$labels['replytoallmessage'] = 'Svar til lista eða sendanda og allra viðtakenda';
$labels['replyall']         = 'Svara öllum';
$labels['replylist']        = 'Svar til lista';
$labels['forward']          = 'Áframsenda';
$labels['forwardinline']    = 'Áframsenda innan skeytis';
$labels['forwardattachment'] = 'Áframsenda sem viðhengi';
$labels['forwardmessage']   = 'Áframsenda skeyti';
$labels['bouncemsg']        = 'Endursenda (bounce)';
$labels['bounce']           = 'Endursenda';
$labels['deletemessage']    = 'Eyða skeyti';
$labels['movemessagetotrash'] = 'Færa skeyti í ruslið';
$labels['printmessage']     = 'Prenta skeyti';
$labels['previousmessage']  = 'Birta fyrra skeyti';
$labels['firstmessage']     = 'Birta fyrsta skeyti';
$labels['nextmessage']      = 'Birta næsta skeyti';
$labels['lastmessage']      = 'Birta síðasta skeyti';
$labels['backtolist']       = 'Til baka í skeytalista';
$labels['viewsource']       = 'Skoða kóða';
$labels['mark']             = 'Merki';
$labels['markmessages']     = 'Merkja skeyti';
$labels['markread']         = 'Sem lesið';
$labels['markunread']       = 'Sem ólesið';
$labels['markflagged']      = 'Sem flaggað';
$labels['markunflagged']    = 'Sem óflaggað';
$labels['moreactions']      = 'Fleiri aðgerðir...';
$labels['markallread']      = 'Merkja allt sem lesið';
$labels['folders-cur']      = 'Aðeins valin mappa';
$labels['folders-sub']      = 'Valin mappa og undirmöppur hennar';
$labels['folders-all']      = 'Allar möppur';
$labels['more']             = 'Meira';
$labels['back']             = 'Til baka';
$labels['options']          = 'Valkostir';
$labels['first'] = 'Fyrsta';
$labels['last'] = 'Síðasta';
$labels['previous'] = 'Fyrra';
$labels['next'] = 'Næsta';
$labels['select'] = 'Velja';
$labels['all'] = 'Allt';
$labels['none'] = 'Ekkert';
$labels['currpage'] = 'Núverandi síða';
$labels['isread'] = 'Lesið';
$labels['unread'] = 'Ólesið';
$labels['flagged'] = 'Flaggað';
$labels['unflagged'] = 'Óflaggað';
$labels['unanswered'] = 'Ósvarað';
$labels['withattachment'] = 'Með viðhengi';
$labels['deleted'] = 'Eytt';
$labels['undeleted'] = 'Ekki eytt';
$labels['replied'] = 'Svarað';
$labels['forwarded'] = 'Áframsent';
$labels['invert'] = 'Umhverfa';
$labels['filter'] = 'Sía';
$labels['list'] = 'Listi';
$labels['threads'] = 'Þræðir';
$labels['expand-all'] = 'Þenja allt út';
$labels['expand-unread'] = 'Þenja ólesið';
$labels['collapse-all'] = 'Fella allt saman';
$labels['threaded'] = 'Þrætt';
$labels['autoexpand_threads'] = 'Þenja skeytaþræði út';
$labels['do_expand'] = 'allir þræðir';
$labels['expand_only_unread'] = 'aðeins ólesin skeyti';
$labels['fromto'] = 'Frá/Til';
$labels['flag'] = 'Flagg';
$labels['attachment'] = 'Viðhengi';
$labels['nonesort'] = 'Ekkert';
$labels['sentdate'] = 'Sendingardagur';
$labels['arrival'] = 'Komudagur';
$labels['asc'] = 'hækkandi';
$labels['desc'] = 'lækkandi';
$labels['listcolumns'] = 'Listadálkar';
$labels['listsorting'] = 'Röðunardálkur';
$labels['listorder'] = 'Röðun';
$labels['listmode'] = 'Listayfirlit';
$labels['layout'] = 'Framsetning';
$labels['layoutwidescreen'] = 'Breiðskjár';
$labels['layoutdesktop'] = 'Skjáborð';
$labels['layoutlist'] = 'Listi';
$labels['layoutwidescreendesc'] = 'Breiðskjár (3-dálka sýn)';
$labels['layoutdesktopdesc'] = 'Skjáborð (breiður listi með forskoðun fyrir neðan)';
$labels['layoutlistdesc'] = 'Listi (engin forskoðun á pósti)';
$labels['folderactions'] = 'Möppuaðgerðir...';
$labels['compact'] = 'Pakka';
$labels['empty'] = 'Tæma';
$labels['importmessages'] = 'Flytja inn skeyti';
$labels['quota'] = 'Gagnamagn';
$labels['unknown']  = 'óþekkt';
$labels['unlimited']  = 'ótakmarkað';
$labels['quotatype'] = 'Tegund kvóta';
$labels['quotatotal'] = 'Takmarkað';
$labels['quotaused'] = 'Notað';
$labels['quotastorage'] = 'Diskpláss';
$labels['quotamessage'] = 'Fjöldi skeyta';
$labels['quicksearch']  = 'Flýtileit';
$labels['searchplaceholder']  = 'Leita...';
$labels['resetsearch']  = 'Tæma leit';
$labels['searchmod']  = 'Leitarskilyrði';
$labels['msgtext']  = 'Allt skeytið';
$labels['body']  = 'Meginmál';
$labels['type'] = 'Tegund';
$labels['namex'] = 'Heiti';
$labels['searchscope'] = 'Umfang';
$labels['currentfolder'] = 'Núverandi mappa';
$labels['subfolders'] = 'Þessi og undirmöppur';
$labels['allfolders'] = 'Allar möppur';
$labels['searchinterval-1W'] = 'eldri en vikugömul';
$labels['searchinterval-1M'] = 'eldri en mánaðargömul';
$labels['searchinterval-1Y'] = 'eldri en ársgömul';
$labels['searchinterval1W'] = 'yngri en vikugömul';
$labels['searchinterval1M'] = 'yngri en mánaðargömul';
$labels['searchinterval1Y'] = 'yngri en ársgömul';
$labels['openinextwin'] = 'Opna í nýjum glugga';
$labels['emlsave'] = 'Sækja (.eml)';
$labels['changeformattext'] = 'Birta sem hreinan texta';
$labels['changeformathtml'] = 'Birta á HTML-sniði';
$labels['editasnew']      = 'Breyta sem nýju';
$labels['send']           = 'Senda';
$labels['sendmessage']    = 'Senda skeytið núna';
$labels['savemessage']    = 'Vista drög';
$labels['addattachment']  = 'Hengja við';
$labels['charset']        = 'Stafatafla';
$labels['editortype']     = 'Gerð ritils';
$labels['returnreceipt']  = 'Kvittun við lestur';
$labels['dsn']            = 'Afhendingarstaða';
$labels['mailreplyintro'] = 'Þann $date, skrifaði $sender:';
$labels['originalmessage'] = 'Upprunalegt skeyti';
$labels['selectimage']    = 'Veldu mynd';
$labels['addimage']       = 'Bæta við mynd';
$labels['selectmedia']    = 'Veldu myndskeið';
$labels['addmedia']       = 'Bæta við myndskeiði';
$labels['encrypt']        = 'Dulrita';
$labels['encryptmessage'] = 'Dulrita skeyti';
$labels['encryptmessagemailvelope'] = 'Dulrita skeyti með Mailvelope';
$labels['importpubkeys']  = 'Flytja inn dreifilykla';
$labels['encryptedsendialog'] = 'Sendi dulritað skeyti';
$labels['keyid']          = 'Auðkenni lykils';
$labels['keylength']      = 'Bitar';
$labels['keyexpired']     = 'Útrunninn';
$labels['keyrevoked']     = 'Afturkallaður';
$labels['bccinstead']     = 'Nota BCC';
$labels['editidents']    = 'Breyta persónuauðkennum';
$labels['spellcheck']    = 'Stafsetning';
$labels['checkspelling'] = 'Athuga stafsetningu';
$labels['resumeediting'] = 'Aftur í ritham';
$labels['revertto']      = 'Hverfa aftur til';
$labels['restore'] = 'Endurheimta';
$labels['restoremessage'] = 'Endurheimta skeyti?';
$labels['ignore'] = 'Hunsa';
$labels['responses'] = 'Svör';
$labels['insertresponse'] = 'Setja inn svar';
$labels['manageresponses'] = 'Sýsla með svör';
$labels['newresponse'] = 'Búa til nýtt svar';
$labels['addresponse'] = 'Bæta við svari';
$labels['editresponse'] = 'Breyta svari';
$labels['editresponses'] = 'Breyta svörum';
$labels['responsename'] = 'Nafn';
$labels['responsetext'] = 'Texti svars';
$labels['attach'] = 'Viðhengi';
$labels['attachments'] = 'Viðhengi';
$labels['upload'] = 'Hlaða upp';
$labels['uploadprogress'] = '$percent ($current af $total)';
$labels['close']  = 'Loka';
$labels['messageoptions']  = 'Valkostir skeytis...';
$labels['togglecomposeoptions'] = 'Víxla valkostum samningar af/á';
$labels['attachmentrename']  = 'Endurnefna viðhengi';
$labels['low']     = 'Lágt';
$labels['lowest']  = 'Lægst';
$labels['normal']  = 'Venjulegt';
$labels['high']    = 'Hátt';
$labels['highest'] = 'Hæst';
$labels['nosubject']  = '(án titils)';
$labels['showimages'] = 'Birta myndir';
$labels['allow']      = 'Leyfa';
$labels['alwaysshow'] = 'Alltaf birta myndir frá $sender';
$labels['alwaysallow'] = 'Alltaf leyfa frá $sender';
$labels['isdraft']    = 'Þetta eru drög að skeyti';
$labels['andnmore']   = '$nr í viðbót...';
$labels['togglemoreheaders'] = 'Birta fleiri skeytahausa';
$labels['togglefullheaders'] = 'Víxla hráum skeytahausum af/á';
$labels['htmltoggle'] = 'HTML';
$labels['plaintoggle'] = 'Hreinn texti';
$labels['savesentmessagein'] = 'Vista send skeyti í';
$labels['dontsave'] = 'ekki vista';
$labels['maxuploadsize'] = 'Leyfileg hámarksstærð skjals er $size';
$labels['addcc'] = 'Bæta við Cc';
$labels['addbcc'] = 'Bæta við Bcc';
$labels['addreplyto'] = 'Bæta við Reply-To';
$labels['addfollowupto'] = 'Nýtt svar við';
$labels['mdnrequest'] = 'Sendandi þessa skeytið hefur óskað þess að þú látir vita að þú hafir lesið þetta skeyti. Viltu láta hann vita?';
$labels['receiptread'] = 'Kvittun (lesa)';
$labels['yourmessage'] = 'Þetta er kvittun fyrir skeytið';
$labels['receiptnote'] = 'ATH: Þessi kvittun segir aðeins til um að skeytið kom upp á skjánum á viðtakanda. Það er engin sönnun um að hann hafi lesið eða skilið innihaldið.';
$labels['name']         = 'Skjánafn';
$labels['firstname']    = 'Eiginnafn';
$labels['surname']      = 'Eftirnafn';
$labels['middlename']   = 'Millinafn';
$labels['nameprefix']   = 'Forskeyti';
$labels['namesuffix']   = 'Viðskeyti';
$labels['nickname']     = 'Stuttnefni';
$labels['jobtitle']     = 'Starfstitill';
$labels['department']   = 'Deild';
$labels['gender']       = 'Kyn';
$labels['maidenname']   = 'Ættarnafn móður';
$labels['email']        = 'Netfang';
$labels['phone']        = 'Sími';
$labels['address']      = 'Heimilisfang';
$labels['street']       = 'Götuheiti';
$labels['locality']     = 'Staður';
$labels['zipcode']      = 'Póstnúmer';
$labels['region']       = 'Ríki/Fylki';
$labels['country']      = 'Land';
$labels['birthday']     = 'Afmælisdagur';
$labels['anniversary']  = 'Afmæli';
$labels['website']      = 'Vefur';
$labels['instantmessenger'] = 'IM-spjall';
$labels['notes'] = 'Glósur';
$labels['male']   = 'karlkyns';
$labels['female'] = 'kvenkyns';
$labels['manager'] = 'Stjórnandi';
$labels['assistant'] = 'Aðstoðarmaður';
$labels['spouse'] = 'Maki';
$labels['allfields'] = 'Öll svæði';
$labels['search'] = 'Leit';
$labels['searchresult'] = 'Leitarniðurstöður';
$labels['advsearch'] = 'Ítarleg leit';
$labels['advanced'] = 'Nánar';
$labels['other'] = 'Annað';
$labels['printcontact'] = 'Prenta tengilið';
$labels['qrcode'] = 'QR-kóði';
$labels['typehome']   = 'Heimasími';
$labels['typework']   = 'Vinnusími';
$labels['typeother']  = 'Annað';
$labels['typemobile']  = 'Farsími';
$labels['typemain']  = 'Aðalstillingar';
$labels['typehomefax']  = 'Heimafax';
$labels['typeworkfax']  = 'Vinnufax';
$labels['typecar']  = 'Bílsími';
$labels['typepager']  = 'Friðþjófur';
$labels['typevideo']  = 'Myndband';
$labels['typeassistant']  = 'Aðstoðarmaður';
$labels['typehomepage']  = 'Heimasíða';
$labels['typeblog'] = 'Blogg';
$labels['typeprofile'] = 'Mannlýsing';
$labels['addfield'] = 'Bæta við svæði...';
$labels['addcontact'] = 'Bæta við tengilið';
$labels['editcontact'] = 'Breyta tengilið';
$labels['contacts'] = 'Tengiliðir';
$labels['contactproperties'] = 'Eiginleikar tengiliðar';
$labels['contactnameandorg'] = 'Nafn og fyrirtæki/stofnun';
$labels['personalinfo'] = 'Persónulegar upplýsingar';
$labels['personal'] = 'Einka';
$labels['contactphoto'] = 'Mynd af tengilið';
$labels['edit']   = 'Breyta';
$labels['cancel'] = 'Hætta við';
$labels['save']   = 'Vista';
$labels['delete'] = 'Eyða';
$labels['discard'] = 'Henda';
$labels['rename'] = 'Endurnefna';
$labels['addphoto'] = 'Bæta við';
$labels['replacephoto'] = 'Skipta út';
$labels['uploadphoto'] = 'Senda inn mynd';
$labels['newcontact']     = 'Búa til nýjan tengilið';
$labels['deletecontact']  = 'Eyða völdum tengiliðum';
$labels['composeto']      = 'Skrifa skeyti til';
$labels['contactsfromto'] = 'Tengiliðir $from til $to af $count';
$labels['print']          = 'Prenta';
$labels['export']         = 'Flytja út';
$labels['exportall']      = 'Flytja allt út';
$labels['exportsel']      = 'Flytja út valið';
$labels['exportvcards']   = 'Flytja út nafnspjöld á vCard formi';
$labels['newgroup']       = 'Búa til nýjan hóp';
$labels['addgroup']       = 'Bæta við hópi';
$labels['grouprename']    = 'Breyta nafni hóps';
$labels['groupdelete']    = 'Fjarlægja hóp';
$labels['groupremoveselected'] = 'Fjarlægja valda tengiliði úr hópi';
$labels['uponelevel']     = 'Upp um eitt stig';
$labels['previouspage']   = 'Birta fyrri síðu';
$labels['firstpage']      = 'Birta fyrstu síðu';
$labels['nextpage']       = 'Birta næstu síðu';
$labels['lastpage']       = 'Birta síðustu síðu';
$labels['group'] = 'Hópur';
$labels['groups'] = 'Hópar';
$labels['listgroup'] = 'Telja upp meðlimi hóps';
$labels['personaladrbook'] = 'Persónuleg heimilisföng';
$labels['searchsave'] = 'Vista leit';
$labels['searchdelete'] = 'Eyða leit';
$labels['import'] = 'Flytja inn';
$labels['importcontacts'] = 'Flytja inn nafnspjöld';
$labels['importfromfile'] = 'Flytja inn af skrá';
$labels['importtarget'] = 'Bæta tengiliðum í';
$labels['importreplace'] = 'Skipta út allri netfangaskránni';
$labels['importgroups'] = 'Flytja inn verkefni hóps';
$labels['importgroupsall'] = 'Allt (búa til hópa ef þess þarf)';
$labels['importgroupsexisting'] = 'Aðeins fyrirliggjandi hópar';
$labels['importdesc'] = 'Þú getur sent inn tengiliði úr fyrirliggjandi nafnaskrá.<br/>Núna er stuðningur við innflutning vistfanga úr <a href="http://en.wikipedia.org/wiki/VCard">vCard</a> eða CSV (kommu-aðgreind) gagnasniðum.';
$labels['done'] = 'Búið';
$labels['settingsfor'] = 'Stillingar fyrir';
$labels['about'] = 'Um forritið';
$labels['preferences'] = 'Stillingar';
$labels['userpreferences'] = 'Notendastillingar';
$labels['editpreferences'] = 'Breyta notendastillingum';
$labels['identities'] = 'Auðkenni';
$labels['manageidentities'] = 'Sýsla með auðkenni';
$labels['newidentity'] = 'Búa til nýtt auðkenni';
$labels['addidentity'] = 'Bæta við auðkenni';
$labels['editidentity'] = 'Breyta auðkenni';
$labels['preferhtml'] = 'Birta HTML';
$labels['defaultcharset'] = 'Sjálfgefin stafatafla';
$labels['htmlmessage'] = 'HTML-skeyti';
$labels['messagepart'] = 'Partur';
$labels['digitalsig'] = 'Stafræn undirritun';
$labels['dateformat'] = 'Snið dagsetningar';
$labels['timeformat'] = 'Tímasnið';
$labels['prettydate'] = 'Fallegar dagsetningar';
$labels['setdefault']  = 'Gera sjálfgilt';
$labels['autodetect']  = 'Sjálfvirkt';
$labels['language']  = 'Tungumál';
$labels['timezone']  = 'Tímabelti';
$labels['pagesize']  = 'Línur á síðu';
$labels['signature'] = 'Undirskrift';
$labels['dstactive']  = 'Sumar-/vetratími';
$labels['showinextwin'] = 'Opna skeyti í nýjum glugga';
$labels['composeextwin'] = 'Semja í nýjum glugga';
$labels['htmleditor'] = 'Skrifa HTML-skeyti';
$labels['htmlonreply'] = 'sem svar við HTML-skeytum';
$labels['htmlonreplyandforward'] = 'við áframsendingu eða svar við HTML-skeytum';
$labels['htmlsignature'] = 'HTML-undirskrift';
$labels['showemail'] = 'Birta tölvupóstföng með skjánafni';
$labels['previewpane'] = 'Birta forskoðunarglugga';
$labels['skin'] = 'Skinn á viðmóti';
$labels['logoutclear'] = 'Tæma rusl við útskráningu';
$labels['logoutcompact'] = 'Þjappa innhólf við útskráningu';
$labels['uisettings'] = 'Notandaviðmót';
$labels['serversettings'] = 'Stillingar þjóns';
$labels['mailboxview'] = 'Útlit pósthólfs';
$labels['mdnrequests'] = 'Við beiðni um kvittun skeytis';
$labels['askuser'] = 'spyrja notanda';
$labels['autosend'] = 'senda kvittun';
$labels['autosendknown'] = 'senda kvittun til tengiliða minna, spyrja mig ella';
$labels['autosendknownignore'] = 'senda kvittun til tengiliða minna, hunsa ella';
$labels['ignorerequest'] = 'hunsa beiðni';
$labels['readwhendeleted'] = 'Merkja skeyti sem lesið þegar því er hent';
$labels['flagfordeletion'] = 'Merkja skeyti til eyðingar í stað þess að eyða';
$labels['skipdeleted'] = 'Ekki birta eydd skeyti';
$labels['deletealways'] = 'Ef ekki er hægt að setja skeytið í ruslafötuna, henda þeim';
$labels['deletejunk'] = 'Eyða skeytum beint úr ruslpóstmöppu';
$labels['showremoteimages'] = 'Birta fjartengdar innbyggðar myndir';
$labels['allowremoteresources'] = 'Leyfa fjartengd tilföng (myndir, stílar)';
$labels['fromknownsenders'] = 'frá þekktum sendendum';
$labels['always'] = 'alltaf';
$labels['alwaysbutplain'] = 'alltaf, nema þegar svarað er skeyti á hreinum texta';
$labels['showinlineimages'] = 'Birta viðhangandi myndir fyrir neðan skeytið';
$labels['autosavedraft']  = 'Vista sjálfkrafa sem drög';
$labels['everynminutes']  = 'á $n mínútna fresti';
$labels['refreshinterval']  = 'Endurhlaða (athuga með ný skeyti, o.s.frv.)';
$labels['never']  = 'aldrei';
$labels['immediately']  = 'samstundis';
$labels['messagesdisplaying'] = 'Birting skeyta';
$labels['messagescomposition'] = 'Semja skeyti';
$labels['mimeparamfolding'] = 'Nöfn á viðhengjum';
$labels['2231folding'] = 'Full RFC 2231 (Thunderbird)';
$labels['miscfolding'] = 'RFC 2047/2231 (MS Outlook)';
$labels['2047folding'] = 'Full RFC 2047 (annað)';
$labels['force7bit'] = 'Nota MIME kóðun fyrir 8-bita stafi';
$labels['savelocalstorage'] = "Vista (tímabundið) í staðværri geymslu vafrans";
$labels['advancedoptions'] = 'Ítarlegir valkostir';
$labels['toggleadvancedoptions'] = 'Víxla ítarlegum valkostum af/á';
$labels['focusonnewmessage'] = 'Láta glugga beinast að nýju skeyti';
$labels['checkallfolders'] = 'Athuga ný skeyti í öllum möppum';
$labels['displaynext'] = 'Að eyðingu/færslu lokinni skal birta næsta skeyti';
$labels['defaultfont'] = 'Sjálfgefið letur HTML-skeyta';
$labels['mainoptions'] = 'Aðalstillingar';
$labels['browseroptions'] = 'Valkostir vafra';
$labels['section'] = 'Hluti';
$labels['maintenance'] = 'Viðhald';
$labels['newmessage'] = 'Nýtt skeyti';
$labels['signatureoptions'] = 'Valkostir undirskriftar';
$labels['whenreplying'] = 'Þegar svarað';
$labels['replyempty'] = 'ekki taka tilvitnun úr upprunalegu skeyti';
$labels['replytopposting'] = 'hefja nýtt skeyti fyrir ofan eldra';
$labels['replytoppostingnoindent'] = 'hefja nýtt skeyti fyrir ofan tilvitnun (enginn inndráttur)';
$labels['replybottomposting'] = 'hefja nýtt skeyti undir eldra';
$labels['replyremovesignature'] = 'Þegar svarað fjarlægja upphaflega undirskrift úr skeyti';
$labels['autoaddsignature'] = 'Bæta undirskrift við sjálfkrafa';
$labels['newmessageonly'] = 'ný skeyti eingöngu';
$labels['replyandforwardonly'] = 'svör og áframsendingar eingöngu';
$labels['insertsignature'] = 'Bæta undirskrift við';
$labels['sigbelow'] = 'Setja undirskrift fyrir neðan tilvísaða skeytið';
$labels['sigseparator'] = 'Þvinga staðlaðan aðgreini í undirskriftum';
$labels['automarkread']  = 'Merkja skeyti sem lesin';
$labels['afternseconds']  = 'eftir $n sekúndur';
$labels['reqmdn'] = 'Biðja ávallt um kvittun';
$labels['reqdsn'] = 'Biðja ávallt um sendingarstöðu';
$labels['replysamefolder'] = 'Setja svarskeyti í möppu sem upphaflegt skeyti er í';
$labels['defaultabook'] = 'Sjálfgefin nafnaskrá';
$labels['autocompletesingle'] = 'Sleppa aukanetföngum í sjálfklárun';
$labels['listnamedisplay'] = 'Lista tengiliði sem';
$labels['spellcheckbeforesend'] = 'Athuga stafsetningu áður en skeyti er sent';
$labels['spellcheckoptions'] = 'Stafsetningarvalkostir';
$labels['spellcheckignoresyms'] = 'Hunsa orð með táknum';
$labels['spellcheckignorenums'] = 'Hunsa orð með tölum';
$labels['spellcheckignorecaps'] = 'Hunsa orð sem eru í hástöfum';
$labels['addtodict'] = 'Bæta við orðalista';
$labels['mailtoprotohandler'] = 'Skrá fyrir meðhöndlun mailto: links samskiptamáta';
$labels['standardwindows'] = 'Meðhöndla sprettglugga sem venjulega glugga';
$labels['forwardmode'] = 'Áframsending skeyta';
$labels['inline'] = 'innfellt';
$labels['asattachment'] = 'sem viðhengi';
$labels['replyallmode'] = 'Sjálfgefin aðgerð [Svara öllum] hnappsins';
$labels['replyalldefault'] = 'svara öllum';
$labels['replyalllist'] = 'einungis svara póstlista (ef hann finnst)';
$labels['folder'] = 'Mappa';
$labels['folders'] = 'Möppur';
$labels['foldername'] = 'Nafn möppu';
$labels['subscribed'] = 'Valin';
$labels['messagecount'] = 'Skeyti';
$labels['create'] = 'Búa til';
$labels['createfolder'] = 'Búa til nýja möppu';
$labels['managefolders'] = 'Sýsla með möppur';
$labels['specialfolders'] = 'Sérstakar möppur';
$labels['properties'] = 'Eiginleikar';
$labels['folderproperties'] = 'Eiginleikar möppu';
$labels['parentfolder'] = 'Yfirmappa';
$labels['location'] = 'Staðsetning';
$labels['info'] = 'Upplýsingar';
$labels['getfoldersize'] = 'Smelltu til að sjá stærð möppu';
$labels['changesubscription'] = 'Smelltu til að breyta áskrift';
$labels['foldertype'] = 'Möpputegund';
$labels['personalfolder'] = 'Einkamappa';
$labels['otherfolder'] = 'Möppur annara notenda';
$labels['sharedfolder'] = 'Opinber mappa';
$labels['findfolders'] = 'Finna möppur';
$labels['findcontacts'] = 'Finna tengiliði';
$labels['findmail'] = 'Finna póstskeyti';
$labels['namespace.personal'] = 'Einka';
$labels['namespace.other'] = 'Annara notenda';
$labels['namespace.shared'] = 'Sameiginlegar';
$labels['dualuselabel'] = 'Getur aðeins innihaldið';
$labels['dualusemail'] = 'skeyti';
$labels['dualusefolder'] = 'möppur';
$labels['sortby'] = 'Raða eftir';
$labels['sortasc']  = 'Raða vaxandi';
$labels['sortdesc'] = 'Raða minnkandi';
$labels['undo'] = 'Taka til baka';
$labels['installedplugins'] = 'Uppsettar viðbætur';
$labels['plugin'] = 'Viðbætur';
$labels['version'] = 'Útgáfa';
$labels['source'] = 'Uppruni';
$labels['license'] = 'Notkunarleyfi';
$labels['support'] = 'Fá aðstoð';
$labels['savedsearches'] = 'Vistaðar leitir';
$labels['B'] = 'B';
$labels['KB'] = 'KB';
$labels['MB'] = 'MB';
$labels['GB'] = 'GB';
$labels['unicode'] = 'Unicode';
$labels['english'] = 'Enska';
$labels['westerneuropean'] = 'Vesturevrópskt';
$labels['easterneuropean'] = 'Austurevrópskt';
$labels['southeasterneuropean'] = 'Suðausturevrópskt';
$labels['baltic'] = 'Eystrasalts';
$labels['cyrillic'] = 'Kýrílískt';
$labels['arabic'] = 'Arabískt';
$labels['greek'] = 'Grískt';
$labels['hebrew'] = 'Hebreskt';
$labels['turkish'] = 'Tyrkneskt';
$labels['nordic'] = 'Norrænt';
$labels['thai'] = 'Tælenskt';
$labels['celtic'] = 'Keltneskt';
$labels['vietnamese'] = 'Víetnamskt';
$labels['japanese'] = 'Japanskt';
$labels['korean'] = 'Kóreskt';
$labels['chinese'] = 'Kínverskt';
$labels['arialabeltopnav'] = 'Gluggastýring';
$labels['arialabeltasknav'] = 'Verkefni forrits';
$labels['arialabeltoolbar'] = 'Verkfærastika forrits';
$labels['arialabelactivetask'] = 'Vikt verkefni';
$labels['arialabelmessagessearchfilter'] = 'Sía fyrir upptalningu tölvupósta';
$labels['arialabelmailsearchform'] = 'Leitargluggi fyrir tölvupósta';
$labels['arialabelcontactsearchform'] = 'Leitargluggi fyrir tengiliði';
$labels['arialabelmailquicksearchbox'] = 'Leitarinntak fyrir tölvupósta';
$labels['arialabelquicksearchbox'] = 'Leitarinntak';
$labels['arialabelfoldersearchfilter'] = 'Sía fyrir upptalningu á möppum';
$labels['arialabelfoldersearchform'] = 'Leitargluggi fyrir möppur';
$labels['arialabelfolderlist'] = 'Val á póstmöppum';
$labels['arialabelmessagelist'] = 'Upptalning á tölvupóstum';
$labels['arialabelmailpreviewframe'] = 'Forskoðun skeytis';
$labels['arialabelmailboxmenu'] = 'Valmynd möppuaðgerða';
$labels['arialabellistselectmenu'] = 'Valmynd vallista';
$labels['arialabelthreadselectmenu'] = 'Valmynd fyrir upptalningu skeytaþráða';
$labels['arialabelmessagelistoptions'] = 'Birting póstskeytalista og valkostir við röðun';
$labels['arialabelmailimportdialog'] = 'Innflutningsgluggi skeyta';
$labels['arialabelmessagenav'] = 'Rötun um skeyti';
$labels['arialabelmessagebody'] = 'Meginmál skeytis';
$labels['arialabelmessageactions'] = 'Aðgerðir skeytis';
$labels['arialabelcontactquicksearch'] = 'Leitargluggi fyrir tengiliði';
$labels['arialabelcontactsearchbox'] = 'Leitarinntak fyrir tengiliði';
$labels['arialabelmessageheaders'] = 'Skeytahausar';
$labels['arialabelforwardingoptions'] = 'Valkostir áframsendinga';
$labels['arialabelreplyalloptions'] = 'Valkostir við að svara-öllum';
$labels['arialabelmoremessageactions'] = 'Fleiri aðgerðir skeyta';
$labels['arialabelmarkmessagesas'] = 'Merka valin skeyti sem...';
$labels['arialabelcomposeoptions'] = 'Valkostir við samningu skeyta';
$labels['arialabelresponsesmenu'] = 'Valmynd fyrir stöðluð svör';
$labels['arialabelattachmentuploadform'] = 'Gluggi fyrir innsendingu viðhengja';
$labels['arialabelattachmentmenu'] = 'Valkostir viðhengja';
$labels['arialabelattachmentpreview'] = 'Forskoðun viðhengis';
$labels['ariasummarycomposecontacts'] = 'Listi yfir tengiliði og hópa sem velja má sem viðtakendur';
$labels['arialabelcontactexportoptions'] = 'Valkostir við útflutning tengiliða';
$labels['arialabelabookgroupoptions'] = 'Valkostir nafnaskrár/hópa';
$labels['arialabelpreferencesform'] = 'Kjörstillingagluggi';
$labels['arialabelidentityeditfrom'] = 'Gluggi til stillinga auðkenna';
$labels['arialabelresonseeditfrom'] = 'Gluggi fyrir breytingar á svari';
$labels['arialabelsearchterms'] = 'Leitarstrengir';
$labels['arialabeldropactionmenu'] = 'Aðgerðavalmynd fyrir draga-sleppa';
$labels['helplistnavigation'] = 'Listi fyrir rötun um skeyti með lyklaborði';
$labels['helplistkeyboardnavigation'] = "Örvar upp/niður: Flytja virkni/val um röð.
Bil: Velja virka röð.
Shift + upp/niður: Velja röð til viðbótar fyrir ofan/neðan.
Ctrl + Bil: Bæta virkri röð við val/fjarlægja úr vali.";
$labels['helplistkeyboardnavmessages'] = "Örvar hægri/vinstri: Þenja/fella saman skeytaþræði (einungis í samskiptaþráðaham).
Enter: Opna valið/virkt póstskeyti.
Del/Eyða: Færa valin skeyti í ruslið.";
$labels['helplistkeyboardnavcontacts'] = "Enter: Opna valinn/virkan tengilið.";
?>
