<?php

/*
 +-----------------------------------------------------------------------+
 | localization/<lang>/labels.inc                                        |
 |                                                                       |
 | Localization file of the Roundcube Webmail client                     |
 | Copyright (C) 2005-2015, The Roundcube Dev Team                       |
 |                                                                       |
 | Licensed under the GNU General Public License version 3 or            |
 | any later version with exceptions for skins & plugins.                |
 | See the README file for a full license statement.                     |
 |                                                                       |
 +-----------------------------------------------------------------------+

 For translation see https://www.transifex.com/projects/p/roundcube-webmail/resource/labels/
*/
$labels['welcome']   = '$product में स्वागत है';
$labels['username']  = 'यूसरनाम';
$labels['password']  = 'पासवर्ड';
$labels['server']    = 'सर्वर';
$labels['login']     = 'लॉगिन';
$labels['logout']   = 'लॉगआऊट';
$labels['mail']     = 'ई-मेल';
$labels['settings'] = 'निजी सैटिंग';
$labels['addressbook'] = 'पता खाता';
$labels['inbox']  = 'इनबॉक्स';
$labels['drafts'] = 'ड्राफ़ट';
$labels['sent']   = 'भेजा गया';
$labels['trash']  = 'रद्दी';
$labels['junk']   = 'स्पैम';
$labels['subject'] = 'विशय';
$labels['from']    = 'भेजने वाला';
$labels['to']      = 'पाने वाला';
$labels['cc']      = 'कार्बन';
$labels['bcc']     = 'अंधा कार्बन';
$labels['replyto'] = 'जवाब यहाँ';
$labels['followupto'] = 'को- फॉलोअप';
$labels['date']    = 'तारीख';
$labels['size']    = 'माप';
$labels['priority'] = 'मेल की महत्वपूर्णता';
$labels['organization'] = 'संस्था';
$labels['mailboxlist'] = 'फ़ोल्डर';
$labels['messagesfromto'] = '$from से ले कर $to, $count मेल में से';
$labels['messagenrof'] = '$nr नम्बर मेल, $count में से';
$labels['copy']     = 'कार्बन';
$labels['move']     = 'स्थानांतरित करें';
$labels['moveto']   = 'खीस्काऐं...';
$labels['download'] = 'डाऊनलोड';
$labels['filename'] = 'फ़ाईल नाम';
$labels['filesize'] = 'फ़ाईल माप';
$labels['addtoaddressbook'] = 'पता खाते में जोडें';
$labels['sun'] = 'रवि';
$labels['mon'] = 'सोम';
$labels['tue'] = 'मंग';
$labels['wed'] = 'बुध';
$labels['thu'] = 'गुरु';
$labels['fri'] = 'शुक्र';
$labels['sat'] = 'शनि';
$labels['sunday']    = 'रविवार';
$labels['monday']    = 'सोमवार';
$labels['tuesday']   = 'मंगलवार';
$labels['wednesday'] = 'बुधवार';
$labels['thursday']  = 'गुरुवार';
$labels['friday']    = 'शुक्रवार';
$labels['saturday']  = 'शनिवार';
$labels['jan']	= 'जनवरी';
$labels['feb']	= 'फ़रवरी';
$labels['mar']	= 'मार्च';
$labels['apr']	= 'अप्रेल';
$labels['may']	= 'मई';
$labels['jun']	= 'जून';
$labels['jul'] 	= 'जुलाई';
$labels['longjan']	= 'जनवरी';
$labels['longfeb']	= 'फ़रवरी';
$labels['longmar']	= 'मार्च';
$labels['longapr']	= 'अप्रैल';
$labels['longmay']	= 'मई';
$labels['longjun']	= 'जून';
$labels['longjul']	= 'जुलाई';
$labels['longaug']	= 'अगस्त';
$labels['longsep']	= 'सितंबर';
$labels['longoct']	= 'अक्टूबर';
$labels['longnov']	= 'नवम्बर';
$labels['longdec']	= 'दिसंबर';
$labels['today'] = 'आज';
$labels['refresh']          = 'ताज़ा करें';
$labels['checkmail']        = 'नये मेल लाऐं';
$labels['compose']          = 'मेल लिखें';
$labels['writenewmessage']  = 'मेल लिखें';
$labels['reply']            = 'जवाब';
$labels['replytomessage']   = 'मेल का जवाब दें';
$labels['replytoallmessage'] = 'सभी को जवाब लिखें';
$labels['forward']          = 'अग्रेषित करें';
$labels['forwardmessage']   = 'आगे भेजें';
$labels['deletemessage']    = 'रद्द करें';
$labels['printmessage']     = 'मेल छापें';
$labels['previousmessage']  = 'पीछे के मेल दिखाऐं';
$labels['firstmessage']     = 'पहला मेल दिखाऐं';
$labels['nextmessage']      = 'अगला मेल दिखाऐं';
$labels['lastmessage']      = 'आखीरी मेल दिखाऐं';
$labels['backtolist']       = 'मेल सूची देखें';
$labels['viewsource']       = 'सोर्स दिखाऐं';
$labels['mark']             = 'चिह्नित';
$labels['select'] = 'चुनें';
$labels['all'] = 'सभी';
$labels['none'] = 'कोई नहीं';
$labels['unread'] = 'अनदेखी';
$labels['nonesort'] = 'कोई नहीं';
$labels['compact'] = 'छोटा करें';
$labels['empty'] = 'मेल रद्दी में डालें';
$labels['quota'] = 'डिस्क उपयोग';
$labels['unknown']  = 'अज्ञात';
$labels['unlimited']  = 'असीम';
$labels['quicksearch']  = 'तेज़ खोज';
$labels['resetsearch']  = 'खोज खाली करें';
$labels['sendmessage']    = 'मेल भेजें';
$labels['savemessage']    = 'ड्राफ़ट सहेजें';
$labels['addattachment']  = 'फ़ाईल जोडें';
$labels['charset']        = 'कैरेक्टर सैट';
$labels['editortype']     = 'सम्पादक प्राकार';
$labels['returnreceipt']  = 'मेल रसीद';
$labels['checkspelling'] = 'स्पैलिंग जाँचें';
$labels['resumeediting'] = 'सम्पादन फिर शुरू करें';
$labels['revertto']      = 'पहले की स्थिती पर जाऐं';
$labels['attachments'] = 'जुडे फाईल';
$labels['upload'] = 'अपलोड';
$labels['close']  = 'बंद';
$labels['low']     = 'कम';
$labels['lowest']  = 'सबसे कम';
$labels['normal']  = 'साधारण';
$labels['high']    = 'उच्च';
$labels['highest'] = 'उच्चतम';
$labels['nosubject']  = '(कोई विशय नहीं)';
$labels['showimages'] = 'चित्र दिखाऐं';
$labels['htmltoggle'] = 'ऐच-टी-ऐम-एल (HTML)';
$labels['plaintoggle'] = 'सादा पाठ';
$labels['name']         = 'दिखने वाला नाम';
$labels['firstname']    = 'पहला नाम';
$labels['surname']      = 'उपनाम';
$labels['email']        = 'मेल';
$labels['editcontact'] = 'पता सम्पाद';
$labels['edit']   = 'सम्पाद';
$labels['cancel'] = 'रद्द';
$labels['save']   = 'सहेज';
$labels['delete'] = 'मिटा';
$labels['deletecontact']  = 'चुने पते मिटाऐं';
$labels['composeto']      = 'को मेल भेजें';
$labels['contactsfromto'] = '$from से ले कर $to, $count पते में से';
$labels['print']          = 'छापें';
$labels['export']         = 'ऐक्स्पोर्ट';
$labels['previouspage']   = 'इससे पहले के बन्डल को दिखाऐं';
$labels['firstpage']      = 'पहला बन्डल दिखाऐं';
$labels['nextpage']       = 'अगला बन्डल दिखाऐं';
$labels['lastpage']       = 'आखिरी बन्डल दिखाऐं';
$labels['settingsfor'] = 'इनके विन्यास:';
$labels['preferences'] = 'पसंद';
$labels['userpreferences'] = 'यूसर पसंद';
$labels['editpreferences'] = 'यूसर पसंद सम्पादें';
$labels['identities'] = 'पहचान';
$labels['preferhtml'] = 'ऐच-टी-ऐम-ऐल(HTML) दिखाऐं';
$labels['htmlmessage'] = 'ऐच-टी-ऐम-ऐल (HTML) रूप मेल करें';
$labels['prettydate'] = 'सुनदर तारीखें';
$labels['setdefault']  = 'तयशुदा चुनें';
$labels['language']  = 'भाषा';
$labels['timezone']  = 'समय क्षेत्र';
$labels['pagesize']  = 'हर पन्ने पर इतने';
$labels['signature'] = 'दस्तखत';
$labels['dstactive']  = 'रौशनी बचाव';
$labels['htmleditor'] = 'मेल ऐच-टी-ऐम-एल (HTML) मे लिखें';
$labels['htmlsignature'] = 'ऐच-टी-ऐम-एल (HTML) दस्तखत';
$labels['previewpane'] = 'झलक पट्टी दिखाऐं';
$labels['autosavedraft']  = 'ड्राफ़ट अपने आप सहेजते जाऐं';
$labels['never']  = 'कभी नहाीं';
$labels['folder'] = 'फ़ोल्डर';
$labels['folders'] = 'फ़ोल्डर';
$labels['foldername'] = 'फ़ोल्डर नाम';
$labels['subscribed'] = 'सबस्क्राईब किया गया';
$labels['create'] = 'बनाऐं';
$labels['createfolder'] = 'फ़ोलडर बनाऐं';
$labels['managefolders'] = 'फ़ोलडर को व्यवस्थित करें';
$labels['sortby'] = 'ऐसे तय करें';
$labels['sortasc']  = 'पहले से आखीरी तय करें';
$labels['sortdesc'] = 'आखीरी से पहले तय करें';
?>
