<?php

/*
 +-----------------------------------------------------------------------+
 | localization/<lang>/labels.inc                                        |
 |                                                                       |
 | Localization file of the Roundcube Webmail client                     |
 | Copyright (C) 2005-2015, The Roundcube Dev Team                       |
 |                                                                       |
 | Licensed under the GNU General Public License version 3 or            |
 | any later version with exceptions for skins & plugins.                |
 | See the README file for a full license statement.                     |
 |                                                                       |
 +-----------------------------------------------------------------------+

 For translation see https://www.transifex.com/projects/p/roundcube-webmail/resource/labels/
*/
$labels['welcome']   = 'Benvenescu à $product';
$labels['username']  = 'Coda da sámband';
$labels['password']  = 'Teßera';
$labels['server']    = 'Serveir';
$labels['login']     = 'S’anonçarh';
$labels['logout']   = 'Zespartarh';
$labels['mail']     = 'Telepost';
$labels['settings'] = 'Setatxen';
$labels['subject'] = 'Subxhect';
$labels['from']    = 'Da';
$labels['to']      = 'À';
$labels['date']    = 'Däts';
$labels['copy']     = 'Copiarh';
$labels['move']     = 'Muóvarh';
$labels['moveto']   = 'Muóvarh à...';
$labels['copyto']   = 'Copiarh à...';
$labels['download'] = 'Transreçáifarh';
$labels['showattachment'] = 'Mostrarh';
$labels['showanyway'] = 'Mostrarh-en zespitzi toct';
$labels['filename'] = 'Nómina del fischeir';
$labels['addtoaddressbook'] = 'Axhuntarh àl carnet dels adreçéux';
$labels['sun'] = 'Súl';
$labels['mon'] = 'Lún';
$labels['tue'] = 'Mai';
$labels['wed'] = 'Már';
$labels['thu'] = 'Xhú';
$labels['fri'] = 'Vié';
$labels['sat'] = 'Sát';
$labels['sunday']    = 'Súladi';
$labels['monday']    = 'Lúneçi';
$labels['tuesday']   = 'Maitzi';
$labels['wednesday'] = 'Márcuri';
$labels['thursday']  = 'Xhúadi';
$labels['friday']    = 'Viénerçi';
$labels['saturday']  = 'Sáturi';
$labels['jan']	= 'Jan';
$labels['feb']	= 'Fev';
$labels['mar']	= 'Mar';
$labels['apr']	= 'Avr';
$labels['may']	= 'Mai';
$labels['jun']	= 'Gün';
$labels['jul'] 	= 'Jul';
$labels['aug']	= 'Gus';
$labels['sep']	= 'Set';
$labels['oct']	= 'Lis';
$labels['nov']	= 'Noe';
$labels['dec']	= 'Zec';
$labels['longjan']	= 'Januar';
$labels['longfeb']	= 'Fevraglh';
$labels['longmar']	= 'Març';
$labels['longapr']	= 'Avrïu';
$labels['longmay']	= 'Mai';
$labels['longjun']	= 'Gün';
$labels['longjul']	= 'Julia';
$labels['longaug']	= 'Guscht';
$labels['longsep']	= 'Setemvar';
$labels['longoct']	= 'Listopäts';
$labels['longnov']	= 'Noemvar';
$labels['longdec']	= 'Zecemvar';
$labels['today'] = 'Oxhi';
$labels['reply']            = 'Contestarh';
$labels['forward']          = 'Promuóvarh';
$labels['deletemessage']    = 'Zeletarh el mensatx';
$labels['more']             = 'Pü';
$labels['options']          = 'Opziuns';
$labels['all'] = 'Toct';
$labels['isread'] = 'Lirarh';
$labels['filter'] = 'Strecureir';
$labels['unknown']  = 'inschì';
$labels['namex'] = 'Nómina';
$labels['send']           = 'Envoxhiarh';
$labels['ignore'] = 'Ignhorarh';
$labels['addresponse'] = 'Axhuntarh ün respuns';
$labels['responsename'] = 'Nómina';
$labels['close']  = 'Fermarh';
$labels['htmltoggle'] = 'HTML';
$labels['gender']       = 'Schlada';
$labels['email']        = 'Telepost';
$labels['locality']     = 'Cità';
$labels['country']      = 'Päts';
$labels['birthday']     = 'Nadaliça';
$labels['typehome']   = 'Casa';
$labels['typeprofile'] = 'Profil';
$labels['contacts'] = 'Contäctsilor';
$labels['edit']   = 'Redactarh';
$labels['cancel'] = 'Niþiliçarh';
$labels['save']   = 'Guardarh';
$labels['delete'] = 'Zeletarh';
$labels['rename'] = 'Rinominarh';
$labels['done'] = 'Fäts';
$labels['about'] = 'Över';
$labels['language']  = 'Glheþ';
$labels['location'] = 'Locaziun';
$labels['info'] = 'Informaziun';
$labels['version'] = 'Verziun';
$labels['B'] = 'o';
$labels['KB'] = 'Ko';
$labels['MB'] = 'Mo';
$labels['GB'] = 'Go';
$labels['unicode'] = 'Unicode';
$labels['english'] = 'Angleasca';
?>
