<roundcube:object name="doctype" value="html5" />
<html>
<head>
<title><roundcube:object name="pagetitle" /></title>
<roundcube:include file="/includes/links.html" />
</head>
<body class="iframe">

<h1 class="boxtitle"><roundcube:object name="keyname" part="name" /></h1>

<div id="key-details" class="boxcontent propform">
    <roundcube:object name="keydata" class="propform" />
</div>

<roundcube:include file="/includes/footer.html" />

</body>
</html>
