<?php

/*
 +-----------------------------------------------------------------------+
 | localization/<lang>/labels.inc                                        |
 |                                                                       |
 | Localization file of the Roundcube Webmail client                     |
 | Copyright (C) 2005-2015, The Roundcube Dev Team                       |
 |                                                                       |
 | Licensed under the GNU General Public License version 3 or            |
 | any later version with exceptions for skins & plugins.                |
 | See the README file for a full license statement.                     |
 |                                                                       |
 +-----------------------------------------------------------------------+

 For translation see https://www.transifex.com/projects/p/roundcube-webmail/resource/labels/
*/
$labels['welcome']   = 'Selamat datang ke $product';
$labels['username']  = 'Nama Pengguna';
$labels['password']  = 'Katalaluan';
$labels['server']    = 'Pelayan';
$labels['login']     = 'Log Masuk';
$labels['logout']   = 'Log Keluar';
$labels['mail']     = 'Mel';
$labels['settings'] = 'Tetapan';
$labels['addressbook'] = 'Buku Alamat';
$labels['inbox']  = 'Peti Masuk';
$labels['drafts'] = 'Draf';
$labels['sent']   = 'Hantar';
$labels['trash']  = 'Tong Sampah';
$labels['junk']   = 'Junk';
$labels['subject'] = 'Subjek';
$labels['from']    = 'Daripada';
$labels['to']      = 'Kepada';
$labels['cc']      = 'Cc';
$labels['bcc']     = 'Bcc';
$labels['replyto'] = 'Balasan Kepada';
$labels['followupto'] = 'Susulan Ke';
$labels['date']    = 'Tarikh';
$labels['size']    = 'Saiz';
$labels['priority'] = 'Prioriti';
$labels['organization'] = 'Organisasi';
$labels['readstatus'] = 'Status baca';
$labels['listoptions'] = 'Senarai pilihan';
$labels['mailboxlist'] = 'Folder';
$labels['messagesfromto'] = 'Mesej $from ke $to dari $count';
$labels['threadsfromto'] = 'Urutan $from ke $to dari $count';
$labels['messagenrof'] = 'Mesej $nr dari $count';
$labels['fromtoshort'] = '$from - $to dari $count';
$labels['copy']     = 'Salin';
$labels['move']     = 'Alih';
$labels['moveto']   = 'Alih ke...';
$labels['download'] = 'Muat Turun';
$labels['filename'] = 'Nama Fail';
$labels['filesize'] = 'Saiz Fail';
$labels['addtoaddressbook'] = 'Tambah ke buku alamat';
$labels['sun'] = 'Aha';
$labels['mon'] = 'Isn';
$labels['tue'] = 'Sel';
$labels['wed'] = 'Rab';
$labels['thu'] = 'Kha';
$labels['fri'] = 'Jum';
$labels['sat'] = 'Sab';
$labels['sunday']    = 'Ahad';
$labels['monday']    = 'Isnin';
$labels['tuesday']   = 'Selasa';
$labels['wednesday'] = 'Rabu';
$labels['thursday']  = 'Khamis';
$labels['friday']    = 'Jumaat';
$labels['saturday']  = 'Sabtu';
$labels['jan']	= 'Jan';
$labels['feb']	= 'Feb';
$labels['mar']	= 'Mac';
$labels['apr']	= 'Apr';
$labels['may']	= 'Mei';
$labels['jun']	= 'Jun';
$labels['jul'] 	= 'Jul';
$labels['aug']	= 'Ogo';
$labels['sep']	= 'Sep';
$labels['oct']	= 'Okt';
$labels['nov']	= 'Nov';
$labels['dec']	= 'Dis';
$labels['longjan']	= 'Januari';
$labels['longfeb']	= 'Februari';
$labels['longmar']	= 'March';
$labels['longapr']	= 'April';
$labels['longmay']	= 'Mei';
$labels['longjun']	= 'Jun';
$labels['longjul']	= 'Julai';
$labels['longaug']	= 'Ogos';
$labels['longsep']	= 'September';
$labels['longoct']	= 'Oktober';
$labels['longnov']	= 'November';
$labels['longdec']	= 'Disember';
$labels['today'] = 'Hari Ini';
$labels['refresh']          = 'Refresh';
$labels['checkmail']        = 'Semak mesej baru';
$labels['compose']          = 'Karang mesej';
$labels['writenewmessage']  = 'Cipta mesej baru';
$labels['reply']            = 'Balas';
$labels['replytomessage']   = 'Balas mesej';
$labels['replytoallmessage'] = 'Balas kepada penghantar dan semua penerima';
$labels['replyall']         = 'Balas semua';
$labels['replylist']        = 'Senarai balas';
$labels['forward']          = 'Majukan';
$labels['forwardinline']    = 'Majukan dalam mesej';
$labels['forwardattachment'] = 'Majukan sebagai lampiran';
$labels['forwardmessage']   = 'Marakan mesej';
$labels['deletemessage']    = 'Pindah mesej ke sampah';
$labels['movemessagetotrash'] = 'Pindah mesej ke Tong Sampah';
$labels['printmessage']     = 'Cetak mesej ini';
$labels['previousmessage']  = 'Papar mesej sebelumnya';
$labels['firstmessage']     = 'Papar mesej pertama';
$labels['nextmessage']      = 'Papat mesej seterusnya';
$labels['lastmessage']      = 'Papat mesej terakhir';
$labels['backtolist']       = 'Kembali ke senarai mesej';
$labels['viewsource']       = 'Papar sumber';
$labels['mark']             = 'Tanda';
$labels['markmessages']     = 'Tanda mesej';
$labels['markread']         = 'Sebagai Dibaca';
$labels['markunread']       = 'Sebagai Tidak dibaca';
$labels['markflagged']      = 'Seperti  ditanda';
$labels['markunflagged']    = 'Seperti tidak ditanda';
$labels['moreactions']      = 'Tindakan lanjut..';
$labels['more']             = 'Seterusnya';
$labels['back']             = 'Kembali';
$labels['options']          = 'Opsyen';
$labels['select'] = 'Pilih';
$labels['all'] = 'Semua';
$labels['none'] = 'Tiada';
$labels['currpage'] = 'Muka terkini';
$labels['unread'] = 'Belum dibaca';
$labels['flagged'] = 'Ditanda';
$labels['unanswered'] = 'Belum dijawab';
$labels['deleted'] = 'Telah dipadam';
$labels['invert'] = 'Songsangkan';
$labels['filter'] = 'Tapis';
$labels['list'] = 'Senarai';
$labels['threads'] = 'Urutan';
$labels['expand-all'] = 'Buka Semua';
$labels['expand-unread'] = 'Buka yang belum dibaca';
$labels['collapse-all'] = 'Tutup Semua';
$labels['threaded'] = 'Telah urutan';
$labels['autoexpand_threads'] = 'Buka mesej mengikut urutan';
$labels['do_expand'] = 'Kesemua urutan';
$labels['expand_only_unread'] = 'hanya dengan mesej yang belum dibaca';
$labels['fromto'] = 'Daripada/Kepada';
$labels['flag'] = 'Tanda';
$labels['attachment'] = 'Lampiran';
$labels['nonesort'] = 'Tiada';
$labels['sentdate'] = 'Tarikh dihantar';
$labels['arrival'] = 'Tarikh terima';
$labels['asc'] = 'menaik';
$labels['desc'] = 'menurun';
$labels['listcolumns'] = 'Senarai ruang';
$labels['listsorting'] = 'pengisihan ruang';
$labels['listorder'] = 'Urutan pengisihan';
$labels['listmode'] = 'Mod senarai paparan';
$labels['layoutlist'] = 'Senarai';
$labels['folderactions'] = 'Aksi folder';
$labels['compact'] = 'Kompak';
$labels['empty'] = 'Kosong';
$labels['quota'] = 'Penggunaan cakera';
$labels['unknown']  = 'tidak diketahui';
$labels['unlimited']  = 'Tidak terhad';
$labels['quicksearch']  = 'Carian pantas';
$labels['resetsearch']  = 'Set semula carian';
$labels['searchmod']  = 'Pengubah carian';
$labels['msgtext']  = 'Keseluruhan mesej';
$labels['openinextwin'] = 'Buka dalam tetingkap baru';
$labels['emlsave'] = 'Muat-turun (.eml)';
$labels['editasnew']      = 'Ubah seperti baharu';
$labels['sendmessage']    = 'Hantar mesej';
$labels['savemessage']    = 'Simapan sebagai draf';
$labels['addattachment']  = 'Lampir fail';
$labels['charset']        = 'Set aksara';
$labels['editortype']     = 'Jenis Editor';
$labels['returnreceipt']  = 'Penerimaan semula';
$labels['dsn']            = 'Status pemberitahuan penghantaran';
$labels['mailreplyintro'] = 'Pada $date, $sender menulis';
$labels['originalmessage'] = 'Mesej Asal';
$labels['editidents']    = 'Ubah identiti';
$labels['spellcheck']    = 'Eja';
$labels['checkspelling'] = 'Semak ejaan';
$labels['resumeediting'] = 'Sambung pengeditan';
$labels['revertto']      = 'Kembali kepada';
$labels['attach'] = 'Lampirkan';
$labels['attachments'] = 'Lampiran';
$labels['upload'] = 'Muat naik';
$labels['close']  = 'Tutup';
$labels['messageoptions']  = 'Opsyen mesej';
$labels['low']     = 'Rendah';
$labels['lowest']  = 'Paling Rendah';
$labels['normal']  = 'Normal';
$labels['high']    = 'Tinggi';
$labels['highest'] = 'Paling Tinggi';
$labels['nosubject']  = '(tiada subjek)';
$labels['showimages'] = 'Papar imej';
$labels['alwaysshow'] = 'selalu paparkan imej dari $sender';
$labels['isdraft']    = 'Ini adalah draf mesej';
$labels['htmltoggle'] = 'HTML';
$labels['plaintoggle'] = 'Teks kosong';
$labels['savesentmessagein'] = 'Simpan mesej yang telah dihantar dalam';
$labels['dontsave'] = 'Jangan simpan';
$labels['maxuploadsize'] = 'maksimum saiz fail yang dibenarkan ialah $size';
$labels['addcc'] = 'Tambah Cc';
$labels['addbcc'] = 'Tambah Bcc';
$labels['addreplyto'] = 'Tambah Reply-To';
$labels['addfollowupto'] = 'Tambah Followup-To';
$labels['mdnrequest'] = 'Pengirim mesej ini mahu diberitahu apabila anda membaca mesej ini. Adakah anda ingin memberitahu pengirim?';
$labels['receiptread'] = 'Balas Resip (dibaca)';
$labels['yourmessage'] = 'Ini adalah Resip Balasan untuk mesej anda';
$labels['receiptnote'] = 'Perhatian: Resip ini hanya untuk memberitahu yang mesej ini telah dipaparkan di komputer penerima. Tidak ada jaminan yang penerima telah membaca atau memahami kandungan mesej.';
$labels['name']         = 'Nama paparan';
$labels['firstname']    = 'Nama pertama';
$labels['surname']      = 'Nama akhir';
$labels['email']        = 'E-Mel';
$labels['editcontact'] = 'Ubahsuai Kontek';
$labels['edit']   = 'Sunting';
$labels['cancel'] = 'Batal';
$labels['save']   = 'Simpan';
$labels['delete'] = 'Padam';
$labels['deletecontact']  = 'Hapus kontek yang dipilih';
$labels['composeto']      = 'Karang mel kepada';
$labels['contactsfromto'] = 'Kontek $from ke $to dari $count';
$labels['print']          = 'Cetak';
$labels['export']         = 'Eksport';
$labels['previouspage']   = 'Papar set sebelumnya';
$labels['firstpage']      = 'Papar set pertama';
$labels['nextpage']       = 'Papar set seterusnya';
$labels['lastpage']       = 'Papar set akhir';
$labels['groups'] = 'Kumpulan';
$labels['personaladrbook'] = 'Alamat-alamat Peribadi';
$labels['settingsfor'] = 'Tetapan bagi';
$labels['preferences'] = 'Keutamaan';
$labels['userpreferences'] = 'Keutamaan pengguna';
$labels['editpreferences'] = 'Sunting keutamaan pengguna';
$labels['identities'] = 'Identiti';
$labels['preferhtml'] = 'Papar HTML';
$labels['htmlmessage'] = 'Mesej HTML';
$labels['prettydate'] = 'Tarikh-tarikh cantik';
$labels['setdefault']  = 'Tetap asal';
$labels['language']  = 'Bahasa';
$labels['timezone']  = 'Zon Masa';
$labels['pagesize']  = 'Baris setiap muka';
$labels['signature'] = 'Tandatangan';
$labels['dstactive']  = 'Simpanan siang hari';
$labels['htmleditor'] = 'Karang mesej HTML';
$labels['htmlsignature'] = 'Tandatangan HTML';
$labels['previewpane'] = 'Pamer ruang previu';
$labels['logoutclear'] = 'Kosongkan Tong sampah ketika keluar';
$labels['logoutcompact'] = 'Padatkan Inbox ketika keluar';
$labels['uisettings'] = 'Antaramuka Pengguna';
$labels['serversettings'] = 'Konfigurasi Pelayan';
$labels['mailboxview'] = 'Pandangan kotak Mel';
$labels['mdnrequests'] = 'Pemberitahuan Pengirim';
$labels['askuser'] = 'Tanya pengguna';
$labels['autosend'] = 'Hantar automatik';
$labels['readwhendeleted'] = 'Tanda mesej sebagai dibaca ketika hapus';
$labels['flagfordeletion'] = 'Tanda mesej untuk pembuangan (tidak delete terus)';
$labels['autosavedraft']  = 'Simpan draf dengan automatik';
$labels['never']  = 'tidak pernah';
$labels['folder'] = 'Kabinet Fail';
$labels['folders'] = 'Folder';
$labels['foldername'] = 'Nama Kabinet Fail';
$labels['subscribed'] = 'Dilanggan';
$labels['messagecount'] = 'Mesej-mesej';
$labels['create'] = 'Cipta';
$labels['createfolder'] = 'Cipta kabinet fail baru';
$labels['managefolders'] = 'Urus kabinet fail';
$labels['sortby'] = 'Susun dengan';
$labels['sortasc']  = 'Susun menaik';
$labels['sortdesc'] = 'Susun menurun';
?>
