<?php

/*
 +-----------------------------------------------------------------------+
 | plugins/markasjunk/localization/<lang>.inc                            |
 |                                                                       |
 | Localization file of the Roundcube Webmail Mark-As-Junk plugin        |
 | Copyright (C) 2012-2013, The Roundcube Dev Team                       |
 |                                                                       |
 | Licensed under the GNU General Public License version 3 or            |
 | any later version with exceptions for skins & plugins.                |
 | See the README file for a full license statement.                     |
 |                                                                       |
 +-----------------------------------------------------------------------+

 For translation see https://www.transifex.com/projects/p/roundcube-webmail/resource/plugin-markasjunk/
*/
$labels['buttontext'] = 'จดหมายขยะ';
$labels['buttontitle'] = 'มาร์คเป็นจดหมายขยะ';
$labels['reportedasjunk'] = 'รายงานสำเร็จแล้วว่าเป็นขยะ';
?>