<?php

/*
 +-----------------------------------------------------------------------+
 | localization/<lang>/labels.inc                                        |
 |                                                                       |
 | Localization file of the Roundcube Webmail client                     |
 | Copyright (C) 2005-2015, The Roundcube Dev Team                       |
 |                                                                       |
 | Licensed under the GNU General Public License version 3 or            |
 | any later version with exceptions for skins & plugins.                |
 | See the README file for a full license statement.                     |
 |                                                                       |
 +-----------------------------------------------------------------------+

 For translation see https://www.transifex.com/projects/p/roundcube-webmail/resource/labels/
*/
$labels['welcome']   = ' $product میں خوش آمدید';
$labels['username']  = 'صارف';
$labels['password']  = 'پاسورڈ';
$labels['server']    = 'سَروَر';
$labels['logout']   = 'لاگ آؤٹ';
$labels['mail']     = 'میل';
$labels['settings'] = 'ترتیبات';
$labels['addressbook'] = 'ایڈریس بک';
$labels['inbox']  = 'ان باکس';
$labels['drafts'] = 'ڈرافٹ';
$labels['subject'] = 'مضمون';
$labels['from']    = 'از';
$labels['sender']  = 'بھیجنے والا';
$labels['download'] = 'ڈاؤن لوڈ';
$labels['showanyway'] = 'جیسا بھی ہے ظاہر کر دیں';
$labels['markread']         = 'جیسے پڑھ لیا ہو';
$labels['markunread']       = 'جیسے ابھی نہ پڑھا ہو';
$labels['more']             = 'مزید';
$labels['back']             = 'واپس';
$labels['select'] = 'مۃنتخب کریں';
$labels['all'] = 'تمام';
$labels['none'] = 'کوئی نہیں';
$labels['currpage'] = 'موجودہ حفحہ';
$labels['unread'] = 'نہیں پڑھا';
$labels['deleted'] = 'ختم ہو گیا';
$labels['undeleted'] = 'ختم نہیں ہُوا';
$labels['invert'] = 'شکل تبدیل کریں';
$labels['list'] = 'لِسٹ';
$labels['expand-all'] = 'تمام کھولیں';
$labels['attachment'] = 'مُنسلَک شُدہ';
$labels['nonesort'] = 'کوئی نہیں';
$labels['layoutlist'] = 'لِسٹ';
?>
