<?php

/*
 +-----------------------------------------------------------------------+
 | localization/<lang>/messages.inc                                      |
 |                                                                       |
 | Localization file of the Roundcube Webmail client                     |
 | Copyright (C) 2005-2015, The Roundcube Dev Team                       |
 |                                                                       |
 | Licensed under the GNU General Public License version 3 or            |
 | any later version with exceptions for skins & plugins.                |
 | See the README file for a full license statement.                     |
 |                                                                       |
 +-----------------------------------------------------------------------+

 For translation see https://www.transifex.com/projects/p/roundcube-webmail/resource/messages/
*/
$messages['errortitle']  = '¡Ha ocurrido un error!';
$messages['loginfailed']  = 'Contraseña o nombre de usuario incorrecto.';
$messages['cookiesdisabled'] = 'Su navegador no acepta cookies.';
$messages['sessionerror'] = 'Su sesión no es válida o ha expirado.';
$messages['storageerror'] = 'Error de conexión con el servidor IMAP.';
$messages['servererror'] = '¡Error del servidor!';
$messages['servererrormsg'] = 'Error de servidor: $msg';
$messages['accountlocked'] = 'Demasiados intentos de conexión fallidos. Inténtalo de nuevo más tarde.';
$messages['connerror'] = '¡Error de conexión (fallo al intentar alcanzar el servidor)!';
$messages['dberror'] = '¡Error de base de datos!';
$messages['windowopenerror'] = 'iLa ventana emergente fue bloqueada!';
$messages['requesttimedout'] = 'Ha expirado el tiempo de respuesta';
$messages['errorreadonly'] = 'No se pudo realizar la operación. La carpeta es de sólo lectura.';
$messages['errornoperm'] = 'No se pudo realizar la operación. Permiso denegado.';
$messages['erroroverquota'] = 'No se pudo completar la operación. No hay espacio libre en el disco.';
$messages['erroroverquotadelete'] = 'No hay espacio libre en el disco. Use Shift+Supr para borrar un mensaje.';
$messages['invalidrequest'] = '¡Petición inválida! No se guardaron los datos.';
$messages['invalidhost'] = 'Nombre de servidor inválido.';
$messages['nomessagesfound'] = 'No se han encontrado mensajes en este buzón.';
$messages['loggedout'] = 'Ha terminado correctamente la sesión. ¡Hasta pronto!';
$messages['mailboxempty'] = 'El buzón está vacío';
$messages['nomessages'] = 'No hay mensajes';
$messages['refreshing'] = 'Actualizando…';
$messages['loading'] = 'Cargando...';
$messages['uploading'] = 'Cargando archivo...';
$messages['attaching'] = 'No se pudo adjuntar el archivo.';
$messages['uploadingmany'] = 'Cargando archivos…';
$messages['loadingdata'] = 'Cargando datos...';
$messages['checkingmail'] = 'Verificando si hay nuevos mensajes...';
$messages['sendingmessage'] = 'Enviando mensaje...';
$messages['messagesent'] = 'Mensaje enviado correctamente.';
$messages['savingmessage'] = 'Guardando mensaje...';
$messages['messagesaved'] = 'Mensaje guardado en Borradores.';
$messages['successfullysaved'] = 'Guardado correctamente.';
$messages['savingresponse'] = 'Guardando texto de respuesta...';
$messages['deleteresponseconfirm'] = '¿Realmente quiere eliminar este texto de respuesta?';
$messages['addedsuccessfully'] = 'Contacto añadido correctamente a la libreta de direcciones.';
$messages['contactexists'] = 'Ya existe un contacto con esta dirección de correo.';
$messages['contactnameexists'] = 'Ya existe un contacto con el mismo nombre.';
$messages['blockedimages'] = 'Para proteger su privacidad, las imágenes externas de este mensaje han sido bloqueadas.';
$messages['encryptedmessage'] = 'Este es un mensaje cifrado y no puede ser mostrado. ¡Lo sentimos!';
$messages['externalmessagedecryption'] = 'Este es un mensaje cifrado y se puede descifrar con una extensión de tu navegador.';
$messages['nopubkeyfor'] = 'No se ha encontrado una clave pública de $email';
$messages['nopubkeyforsender'] = 'No se ha encontrado una clave pública de tu identidad como emisor. ¿Quieres cifrar el mensaje sólo para los destinatarios?';
$messages['encryptnoattachments'] = 'Todavía no se pueden cifrar los adjuntos subidos. Por favor, añádelos luego en el editor de cifrado.';
$messages['searchpubkeyservers'] = '¿Quieres buscar servidores de clave pública para las claves que faltan?';
$messages['encryptpubkeysfound'] = 'Se han encontrado las siguientes claves públicas:';
$messages['keyservererror'] = 'No se ha podido obtener la clave del servidor de claves';
$messages['keyimportsuccess'] = 'La clave pública ¢key se ha importado correctamente a tu anillo de claves';
$messages['nocontactsfound'] = 'No se encontraron contactos.';
$messages['contactnotfound'] = 'El contacto solicitado no existe.';
$messages['contactsearchonly'] = 'Ingrese algún criterio para buscar contactos';
$messages['sendingfailed'] = 'Error al enviar mensaje.';
$messages['senttooquickly'] = 'Por favor, espere $sec segundo(s) antes de enviar este mensaje.';
$messages['errorsavingsent'] = 'Ha ocurrido un error al guardar el mensaje enviado.';
$messages['errorsaving'] = 'Ha ocurrido un error al guardar.';
$messages['errormoving'] = 'No se pudo mover el/los mensaje(s).';
$messages['errorcopying'] = 'No se pudo copiar el/los mensaje(s).';
$messages['errordeleting'] = 'No se pudo eliminar el/los mensaje(s).';
$messages['errormarking'] = 'No se pudo marcar el/los mensaje(s).';
$messages['deletecontactconfirm']  = '¿Realmente quiere eliminar los contactos seleccionados?';
$messages['deletegroupconfirm']  = '¿Realmente quiere borrar el grupo seleccionado?';
$messages['deletemessagesconfirm'] = '¿Realmente quiere eliminar los mensajes seleccionados?';
$messages['deletefolderconfirm']  = '¿Realmente quiere eliminar esta carpeta?';
$messages['purgefolderconfirm']  = '¿Realmente quiere eliminar todos los mensajes de esta carpeta?';
$messages['contactdeleting'] = 'Eliminando contacto(s)...';
$messages['groupdeleting'] = 'Eliminando grupo…';
$messages['folderdeleting'] = 'Eliminando carpeta...';
$messages['foldermoving'] = 'Moviendo carpeta...';
$messages['foldersubscribing'] = 'Suscribiendo carpeta...';
$messages['folderunsubscribing'] = 'Anulando suscripción a carpeta...';
$messages['formincomplete'] = 'No ha completado todos los campos del formulario.';
$messages['noemailwarning'] = 'Por favor, introduzca un correo electrónico válido.';
$messages['nonamewarning']  = 'Por favor, introduzca un nombre.';
$messages['nopagesizewarning'] = 'Por favor, introduzca un tamaño de página.';
$messages['nosenderwarning'] = 'Por favor, introduzca la dirección de correo del remitente.';
$messages['norecipientwarning'] = 'Por favor, introduzca al menos un destinatario.';
$messages['disclosedrecipwarning'] = 'Todos los receptores verán las direcciones de correo electrónico de cada uno. Para evitarlo y para proteger su privacidad puede utilizar el campo Cco';
$messages['disclosedreciptitle'] = 'Demasiados destinatarios';
$messages['nosubjectwarning']  = 'El campo "Asunto" está vacío. ¿Desea completarlo en este momento?';
$messages['nosubjecttitle']  = 'Sin asunto';
$messages['nobodywarning'] = '¿Desea enviar este mensaje sin texto?';
$messages['notsentwarning'] = 'El mensaje no se ha enviado y tiene cambios sin guardar. ¿Quieres descartar los cambios?';
$messages['restoresavedcomposedata'] = 'Se ha encontrado un mensaje previamente redactado sin enviar.\n\nAsunto: $subject\nGuardado: $date\n\n¿Desea restaurar este mensaje?';
$messages['nosearchname'] = 'Por favor, ingrese un nombre de contacto o dirección de correo electrónico.';
$messages['notuploadedwarning'] = 'No todos los adjuntos han sido cargados todavía. Por favor, espere o cancele la carga.';
$messages['searchsuccessful'] = 'Se encontraron $nr mensajes.';
$messages['contactsearchsuccessful'] = 'Encontrados $nr contactos.';
$messages['searchnomatch'] = 'No se obtuvieron resultados.';
$messages['searching'] = 'Buscando...';
$messages['checking'] = 'Revisando...';
$messages['stillsearching'] = 'Aún buscando...';
$messages['nospellerrors'] = 'No se encontraron errores ortográficos.';
$messages['folderdeleted'] = 'Carpeta eliminada correctamente.';
$messages['foldersubscribed'] = 'Suscrito a carpeta correctamente.';
$messages['folderunsubscribed'] = 'Suscripción a carpeta anulada correctamente.';
$messages['folderpurged'] = 'Carpeta purgada correctamente.';
$messages['folderexpunged'] = 'Carpeta compactada correctamente.';
$messages['deletedsuccessfully'] = 'Eliminado correctamente.';
$messages['converting'] = 'Eliminando formato de mensaje...';
$messages['messageopenerror'] = 'No se pudo cargar el mensaje del servidor.';
$messages['filelinkerror'] = 'No se pudo adjuntar el archivo.';
$messages['fileuploaderror'] = 'Error al cargar archivos.';
$messages['filesizeerror'] = 'El archivo excede el tamaño máximo ($size).';
$messages['filecounterror'] = 'Puedes subir un máximo de $count archivos de cada vez.';
$messages['msgsizeerror'] = 'No se ha podido adjuntar un archivo. El tamaño máximo del mensaje ($size) se ha excedido.';
$messages['copysuccess'] = '$nr contactos copiados correctamente.';
$messages['movesuccess'] = '$nr contactos movidos correctamente.';
$messages['copyerror'] = 'No se pudo copiar ningún contacto.';
$messages['moveerror'] = 'No se pudo mover ningún contacto.';
$messages['sourceisreadonly'] = 'Esta dirección origen es de sólo lectura.';
$messages['errorsavingcontact'] = 'No se pudo guardar la dirección de contacto.';
$messages['movingmessage'] = 'Moviendo mensaje(s)...';
$messages['copyingmessage'] = 'Copiando mensaje(s)...';
$messages['copyingcontact'] = 'Copiando contacto(s)…';
$messages['movingcontact'] = 'Moviendo contacto(s)...';
$messages['deletingmessage'] = 'Eliminando mensaje(s)...';
$messages['markingmessage'] = 'Marcando mensaje(s)...';
$messages['addingmember'] = 'Añadiendo contacto(s) al grupo…';
$messages['removingmember'] = 'Eliminando contacto(s) del grupo…';
$messages['receiptsent'] = 'La confirmación de lectura ha sido enviada correctamente.';
$messages['errorsendingreceipt'] = 'No se pudo enviar la confirmación de lectura.';
$messages['deleteidentityconfirm'] = '¿Realmente desea eliminar esta identidad?';
$messages['nodeletelastidentity'] = 'No se puede eliminar esta identidad puesto a que es la única.';
$messages['forbiddencharacter'] = 'El nombre de la carpeta contiene un carácter prohibido.';
$messages['selectimportfile'] = 'Por favor, seleccione un archivo para cargar.';
$messages['addresswriterror'] = 'La libreta de direcciones seleccionada no admite escritura.';
$messages['contactaddedtogroup'] = 'Se añadieron los contactos a este grupo correctamente.';
$messages['contactremovedfromgroup'] = 'Se eliminaron los contactos de este grupo correctamente.';
$messages['nogroupassignmentschanged'] = 'No hay cambios en la asignación de grupos.';
$messages['importwait'] = 'Importando, por favor espere...';
$messages['importformaterror'] = '¡La importación falló! El fichero enviado no es un fichero válido de importación de datos.';
$messages['importconfirm'] = '<b>Se han importado $inserted contactos correctamente</b>';
$messages['importconfirmskipped'] = '<b>Ignoradas $skipped entradas existentes</b>';
$messages['importmessagesuccess'] = '$nr mensajes importados correctamente';
$messages['importmessageerror'] = '¡La importación falló! El fichero enviado no es un fichero válido de mensaje o buzón de correo.';
$messages['opnotpermitted'] = '¡Operación no permitida!';
$messages['nofromaddress'] = 'Falta dirección electrónica en la identidad seleccionada.';
$messages['editorwarning'] = 'Al cambiar el tipo de editor puede ocasionar la pérdida de formato del texto. ¿Desea continuar?';
$messages['httpreceivedencrypterror'] = 'Ha ocurrido un error fatal de configuración. Contacte inmediatamente a su administrador. <b>Su mensaje no ha sido enviado.</b>';
$messages['smtpconnerror'] = 'Error SMTP ($code): Ha fallado la conexión al servidor.';
$messages['smtpautherror'] = 'Error SMTP ($code): Ha fallado la autenticación.';
$messages['smtpfromerror'] = 'Error SMTP ($code): No se pudo asignar el remitente "$from" ($msg).';
$messages['smtptoerror'] = 'Error SMTP ($code): No se pudo establecer destinatario "$to" ($msg).';
$messages['smtprecipientserror'] = 'Error SMTP: No es posible analizar la lista de destinatarios.';
$messages['smtperror'] = 'Error SMTP: $msg';
$messages['emailformaterror'] = 'Dirección de correo incorrecta: $email';
$messages['toomanyrecipients'] = 'Demasiados destinatarios. Reduzca el número de destinatarios a $max.';
$messages['maxgroupmembersreached'] = 'El número de miembros del grupo excede el máximo de $max.';
$messages['internalerror'] = 'Ha ocurrido un error interno. Por favor, inténtelo de nuevo.';
$messages['contactdelerror'] = 'No se pudo eliminar el/los contacto(s).';
$messages['contactdeleted'] = 'Contacto(s) eliminado(s) correctamente.';
$messages['contactrestoreerror'] = 'No se pudo restaurar contacto(s) eliminado(s).';
$messages['contactrestored'] = 'Contacto(s) restaurado(s) correctamente.';
$messages['groupdeleted'] = 'Grupo eliminado correctamente.';
$messages['grouprenamed'] = 'Grupo renombrado correctamente.';
$messages['groupcreated'] = 'Grupo creado correctamente.';
$messages['savedsearchdeleted'] = 'La búsqueda guardada se ha eliminado correctamente.';
$messages['savedsearchdeleteerror'] = 'No se ha podido eliminar la búsqueda guardada.';
$messages['savedsearchcreated'] = 'Se ha guardado la búsqueda correctamente.';
$messages['savedsearchcreateerror'] = 'No se pudo guardar la búsqueda.';
$messages['messagedeleted'] = 'Mensaje(s) eliminado(s) correctamente.';
$messages['messagemoved'] = 'Mensaje(s) movido(s) correctamente.';
$messages['messagemovedtotrash'] = 'Los mensajes se han trasladado a la papelera.';
$messages['messagecopied'] = 'Mensaje(s) copiado(s) correctamente.';
$messages['messagemarked'] = 'Mensaje(s) marcado(s) correctamente.';
$messages['autocompletechars'] = 'Introduce al menos $min caracteres para autocompletar.';
$messages['autocompletemore'] = 'Se encontraron más coincidencias. Favor de ingresar más caracteres.';
$messages['namecannotbeempty'] = 'El nombre no puede estar vacío.';
$messages['nametoolong'] = 'El nombre es demasiado largo.';
$messages['namedotforbidden'] = 'El nombre de la carpeta no puede empezar con un punto';
$messages['folderupdated'] = 'Carpeta actualizada correctamente.';
$messages['foldercreated'] = 'Carpeta creada correctamente.';
$messages['invalidimageformat'] = 'No es un formato de imagen válido.';
$messages['mispellingsfound'] = 'Se han detectado errores ortográficos en el mensaje.';
$messages['parentnotwritable'] = 'No se pudo crear/mover la carpeta a la carpeta superior seleccionada. No tiene permisos de acceso.';
$messages['messagetoobig'] = 'Esta parte del mensaje es demasiado grande para ser procesado.';
$messages['noscriptwarning'] = 'Advertencia: ¡Este servicio de webmail necesita Javascript! Para poder usarlo habilite el soporte de Javascript en su navegador, por favor.';
$messages['messageissent'] = 'El mensaje se ha enviado, pero aún no se ha guardado. ¿Quieres guardarlo ahora?';
$messages['errnotfound'] = 'Archivo no encontrado';
$messages['errnotfoundexplain'] = '¡No se ha encontrado el recurso solicitado!';
$messages['errfailedrequest'] = 'Ha fallado la petición';
$messages['errauthorizationfailed'] = 'Ha fallado la autorización';
$messages['errunauthorizedexplain'] = '¡No se ha podido comprobar que usted esté autorizado a acceder a este servicio!';
$messages['errrequestcheckfailed'] = 'Ha fallado la solicitud de comprobación';
$messages['errcsrfprotectionexplain'] = "Por su seguridad, se ha protegido el acceso a este recurso contra CSRF.\nSi lee esto probablemente no ha cerrado la sesión antes de dejar la aplicación web.\n\nAhora hace falta interacción humana para continuar.";
$messages['errcontactserveradmin'] = 'Por favor, póngase en contacto con el administrador de su servidor.';
$messages['clicktoresumesession'] = 'Haga clic aquí para reanudar la sesión anterior';
$messages['errcomposesession'] = 'Error de sesión de escritura';
$messages['errcomposesessionexplain'] = 'No se ha encontrado la sesión de escritura requerida.';
$messages['clicktocompose'] = 'Hacer clic aquí para escribir un nuevo mensaje';
