<?php

/*
 +-----------------------------------------------------------------------+
 | localization/<lang>/labels.inc                                        |
 |                                                                       |
 | Localization file of the Roundcube Webmail client                     |
 | Copyright (C) 2005-2015, The Roundcube Dev Team                       |
 |                                                                       |
 | Licensed under the GNU General Public License version 3 or            |
 | any later version with exceptions for skins & plugins.                |
 | See the README file for a full license statement.                     |
 |                                                                       |
 +-----------------------------------------------------------------------+

 For translation see https://www.transifex.com/projects/p/roundcube-webmail/resource/labels/
*/
$labels['isread'] = 'Ɣeṛ';
$labels['unknown']  = 'arussin';
$labels['other'] = 'Ayen-nniḍen';
$labels['typeother']  = 'Ayen-nniḍen';
$labels['delete'] = 'Kkes';
$labels['create'] = 'Rnu';
?>
