<?php

/*
 +-----------------------------------------------------------------------+
 | localization/<lang>/labels.inc                                        |
 |                                                                       |
 | Localization file of the Roundcube Webmail client                     |
 | Copyright (C) 2005-2015, The Roundcube Dev Team                       |
 |                                                                       |
 | Licensed under the GNU General Public License version 3 or            |
 | any later version with exceptions for skins & plugins.                |
 | See the README file for a full license statement.                     |
 |                                                                       |
 +-----------------------------------------------------------------------+

 For translation see https://www.transifex.com/projects/p/roundcube-webmail/resource/labels/
*/
$labels['welcome']   = 'Velkommen til $product';
$labels['username']  = 'Brukernavn';
$labels['password']  = 'Passord';
$labels['server']    = 'Tjener';
$labels['login']     = 'Logg inn';
$labels['logout']   = 'Logg ut';
$labels['mail']     = 'E-post';
$labels['settings'] = 'Innstillinger';
$labels['addressbook'] = 'Adressebok';
$labels['inbox']  = 'Innboks';
$labels['drafts'] = 'Kladd';
$labels['sent']   = 'Sendt';
$labels['trash']  = 'Slettet';
$labels['junk']   = 'Spam';
$labels['show_real_foldernames'] = 'Vis orginale navn for spesielle mapper';
$labels['subject'] = 'Emne';
$labels['from']    = 'Avsender';
$labels['sender']  = 'Avsender';
$labels['to']      = 'Mottaker';
$labels['cc']      = 'Kopi til';
$labels['bcc']     = 'Blindkopi til';
$labels['replyto'] = 'Svar til';
$labels['followupto'] = 'Oppfølging til';
$labels['date']    = 'Dato';
$labels['size']    = 'Størrelse';
$labels['priority'] = 'Prioritet';
$labels['organization'] = 'Organisasjon';
$labels['readstatus'] = 'Lese status';
$labels['listoptions'] = 'List muligheter';
$labels['mailboxlist'] = 'Mapper';
$labels['messagesfromto'] = 'Meldinger $from til $to av $count';
$labels['threadsfromto'] = 'Tråder $from til $to av $count';
$labels['messagenrof'] = 'Melding $nr av $count';
$labels['fromtoshort'] = '$from – $to av $count';
$labels['copy']     = 'Kopier';
$labels['move']     = 'Flytt';
$labels['moveto']   = 'flytt til...';
$labels['copyto']   = 'Kopier til...';
$labels['download'] = 'last ned';
$labels['open']     = 'Åpen';
$labels['showattachment'] = 'Vis';
$labels['showanyway'] = 'Vis likevel';
$labels['filename'] = 'Filnavn';
$labels['filesize'] = 'Filstørrelse';
$labels['addtoaddressbook'] = 'Legg til i adressebok';
$labels['sun'] = 'Søn';
$labels['mon'] = 'Man';
$labels['tue'] = 'Tir';
$labels['wed'] = 'Ons';
$labels['thu'] = 'Tor';
$labels['fri'] = 'Fre';
$labels['sat'] = 'Lør';
$labels['sunday']    = 'Søndag';
$labels['monday']    = 'Mandag';
$labels['tuesday']   = 'Tirsdag';
$labels['wednesday'] = 'Onsdag';
$labels['thursday']  = 'Torsdag';
$labels['friday']    = 'Fredag';
$labels['saturday']  = 'Lørdag';
$labels['jan']	= 'Jan';
$labels['feb']	= 'Feb';
$labels['mar']	= 'Mar';
$labels['apr']	= 'Apr';
$labels['may']	= 'Mai';
$labels['jun']	= 'Jun';
$labels['jul'] 	= 'Jul';
$labels['aug']	= 'Aug';
$labels['sep']	= 'Sep';
$labels['oct']	= 'Okt';
$labels['nov']	= 'Nov';
$labels['dec']	= 'Des';
$labels['longjan']	= 'Januar';
$labels['longfeb']	= 'Februar';
$labels['longmar']	= 'Mars';
$labels['longapr']	= 'April';
$labels['longmay']	= 'Mai';
$labels['longjun']	= 'Juni';
$labels['longjul']	= 'Juli';
$labels['longaug']	= 'August';
$labels['longsep']	= 'September';
$labels['longoct']	= 'Oktober';
$labels['longnov']	= 'November';
$labels['longdec']	= 'Desember';
$labels['today'] = 'I dag';
$labels['refresh']          = 'Oppdater';
$labels['checkmail']        = 'Se etter nye meldinger';
$labels['compose']          = 'Skriv ny e-post';
$labels['writenewmessage']  = 'Opprett ny e-post';
$labels['reply']            = 'Svar';
$labels['replytomessage']   = 'Svar på denne e-posten';
$labels['replytoallmessage'] = 'Svar til alle mottakere';
$labels['replyall']         = 'Svar alle';
$labels['replylist']        = 'Svarliste';
$labels['forward']          = 'Videresend';
$labels['forwardinline']    = 'Videresend i melding';
$labels['forwardattachment'] = 'Vidresend som vedlegg';
$labels['forwardmessage']   = 'Videresend denne e-posten';
$labels['deletemessage']    = 'Slett e-posten';
$labels['movemessagetotrash'] = 'Flytt e-posten til søppel';
$labels['printmessage']     = 'Skriv ut denne e-posten';
$labels['previousmessage']  = 'Vis forrige melding';
$labels['firstmessage']     = 'Vis første melding';
$labels['nextmessage']      = 'Vis neste melding';
$labels['lastmessage']      = 'Vis siste melding';
$labels['backtolist']       = 'Tilbake til e-postlisten';
$labels['viewsource']       = 'Vis kilde';
$labels['mark']             = 'Merke';
$labels['markmessages']     = 'Merk meldinger';
$labels['markread']         = 'som lest';
$labels['markunread']       = 'som ulest';
$labels['markflagged']      = 'som flagget';
$labels['markunflagged']    = 'som uflagget';
$labels['moreactions']      = 'Flere handlinger …';
$labels['folders-all']      = 'Alle mapper';
$labels['more']             = 'Mer';
$labels['back']             = 'Tilbake';
$labels['options']          = 'Alternativer';
$labels['select'] = 'Velg';
$labels['all'] = 'Alle';
$labels['none'] = 'Ingen';
$labels['currpage'] = 'Gjeldende side';
$labels['isread'] = 'Lese';
$labels['unread'] = 'Uleste';
$labels['flagged'] = 'Flagget';
$labels['unanswered'] = 'Ubesvarte';
$labels['withattachment'] = 'Med vedlegg';
$labels['deleted'] = 'Slettet';
$labels['undeleted'] = 'Ikke slettet';
$labels['invert'] = 'Inverter';
$labels['filter'] = 'Filter';
$labels['list'] = 'Liste';
$labels['threads'] = 'Tråder';
$labels['expand-all'] = 'Utvid alle';
$labels['expand-unread'] = 'Utvid uleste';
$labels['collapse-all'] = 'Skjul alle';
$labels['threaded'] = 'Trådet';
$labels['autoexpand_threads'] = 'Utvid tråder';
$labels['do_expand'] = 'alle tråder';
$labels['expand_only_unread'] = 'kun med uleste meldinger';
$labels['fromto'] = 'Avsender/Mottaker';
$labels['flag'] = 'Flagg';
$labels['attachment'] = 'Vedlegg';
$labels['nonesort'] = 'Ingen';
$labels['sentdate'] = 'Dato sendt';
$labels['arrival'] = 'Dato mottatt';
$labels['asc'] = 'stigende';
$labels['desc'] = 'synkende';
$labels['listcolumns'] = 'Listekolonner';
$labels['listsorting'] = 'Sorteringskolonne';
$labels['listorder'] = 'Sorteringsrekkefølge';
$labels['listmode'] = 'Listevisningsmodus';
$labels['layoutlist'] = 'Liste';
$labels['folderactions'] = 'Mappehandlinger...';
$labels['compact'] = 'Rydd opp';
$labels['empty'] = 'Tøm';
$labels['importmessages'] = 'Importer meldinger';
$labels['quota'] = 'Plassforbruk';
$labels['unknown']  = 'ukjent';
$labels['unlimited']  = 'ubegrenset';
$labels['quicksearch']  = 'Hurtigsøk';
$labels['resetsearch']  = 'Nullstill søk';
$labels['searchmod']  = 'Søke felt';
$labels['msgtext']  = 'Hele meldingen';
$labels['body']  = 'Meldingstekst';
$labels['type'] = 'Type';
$labels['namex'] = 'Navn';
$labels['searchscope'] = 'Omfanget';
$labels['currentfolder'] = 'Den nåværende mappen';
$labels['subfolders'] = 'Dette og undermappene';
$labels['allfolders'] = 'Alle mapper';
$labels['openinextwin'] = 'Åpne i nytt vindu';
$labels['emlsave'] = 'Last ned (.eml)';
$labels['changeformattext'] = 'Vis i ren tekst';
$labels['changeformathtml'] = 'Vis i HTML';
$labels['editasnew']      = 'Rediger som ny';
$labels['send']           = 'Send.';
$labels['sendmessage']    = 'Send e-posten';
$labels['savemessage']    = 'Lagre kladd';
$labels['addattachment']  = 'Vedlegg';
$labels['charset']        = 'Tegnsett';
$labels['editortype']     = 'Format';
$labels['returnreceipt']  = 'Be om kvittering';
$labels['dsn']            = 'Leveringsstatus varsling';
$labels['mailreplyintro'] = 'Den $date, skrev $sender:';
$labels['originalmessage'] = 'Opprinnelig melding';
$labels['editidents']    = 'Endre identiteter';
$labels['spellcheck']    = 'Stavekontroll';
$labels['checkspelling'] = 'Stavekontroll';
$labels['resumeediting'] = 'Fortsett redigering';
$labels['revertto']      = 'Tilbake til';
$labels['restore'] = 'Gjenopprett';
$labels['restoremessage'] = 'Gjenopprett melding?';
$labels['responses'] = 'Svar';
$labels['insertresponse'] = 'Sett inn et svar';
$labels['manageresponses'] = 'Rediger svar';
$labels['editresponse'] = 'Rediger svar';
$labels['editresponses'] = 'Rediger svar';
$labels['responsename'] = 'Navn';
$labels['responsetext'] = 'Svar tekst';
$labels['attach'] = 'Legg ved';
$labels['attachments'] = 'Vedlegg';
$labels['upload'] = 'Last opp';
$labels['close']  = 'Lukk';
$labels['messageoptions']  = 'Meldingsalternativer...';
$labels['low']     = 'Lav';
$labels['lowest']  = 'Lavest';
$labels['normal']  = 'Normal';
$labels['high']    = 'Høy';
$labels['highest'] = 'Høyest';
$labels['nosubject']  = '(intet emne)';
$labels['showimages'] = 'Vis bilder';
$labels['alwaysshow'] = 'Vis alltid bilder fra $sender';
$labels['isdraft']    = 'Dette er en kladd.';
$labels['andnmore']   = '$nr flere ...';
$labels['togglemoreheaders'] = 'Vis flere meldings-headere';
$labels['togglefullheaders'] = 'Veksle visning av meldingens headere i råformat';
$labels['htmltoggle'] = 'HTML';
$labels['plaintoggle'] = 'Ren tekst';
$labels['savesentmessagein'] = 'Lagre sendt melding i';
$labels['dontsave'] = 'ikke lagre';
$labels['maxuploadsize'] = 'Maksimalt tillatt filstørrelse er $size';
$labels['addcc'] = 'Legg til kopiadressat (Cc)';
$labels['addbcc'] = 'Legg til blindkopiadressat (Bcc)';
$labels['addreplyto'] = 'Legg til svar til (Reply-To)';
$labels['addfollowupto'] = 'Legg til oppfølging';
$labels['mdnrequest'] = 'Senderen av denne meldingen har bedt om å bli gjort oppmerksom på at denne meldingen er lest. Ønsker du å sende denne bekreftelsen?';
$labels['receiptread'] = 'Kvittering (lest)';
$labels['yourmessage'] = 'Dette er en kvittering for at din e-post er mottatt';
$labels['receiptnote'] = 'Merknad: Denne kvitteringen bekrefter bare at e-posten ble vist hos mottakeren. Det er ingen garanti for at mottakeren har lest eller forstått innholdet i e-posten.';
$labels['name']         = 'Visningsnavn';
$labels['firstname']    = 'Fornavn';
$labels['surname']      = 'Etternavn';
$labels['middlename']   = 'Mellom Navn';
$labels['nameprefix']   = 'Prefiks';
$labels['namesuffix']   = 'Suffiks';
$labels['nickname']     = 'Kallenavn';
$labels['jobtitle']     = 'Jobb Tittel';
$labels['department']   = 'Avdeling';
$labels['gender']       = 'Kjønn';
$labels['maidenname']   = 'Pikenavn';
$labels['email']        = 'E-post';
$labels['phone']        = 'Telefon';
$labels['address']      = 'Adresse';
$labels['street']       = 'Gate';
$labels['locality']     = 'Sted';
$labels['zipcode']      = 'Postkode';
$labels['region']       = 'Stat/provins';
$labels['country']      = 'Land';
$labels['birthday']     = 'Fødselsdag';
$labels['anniversary']  = 'Merkedag';
$labels['website']      = 'Nettsted';
$labels['instantmessenger'] = 'Lynmelding';
$labels['notes'] = 'Notater';
$labels['male']   = 'Mann';
$labels['female'] = 'Kvinne';
$labels['manager'] = 'Leder';
$labels['assistant'] = 'Assistent';
$labels['spouse'] = 'Ektefelle';
$labels['allfields'] = 'Alle felter';
$labels['search'] = 'Søk';
$labels['advsearch'] = 'Avansert søk';
$labels['advanced'] = 'Avansert';
$labels['other'] = 'Annet';
$labels['typehome']   = 'Hjem';
$labels['typework']   = 'Jobb';
$labels['typeother']  = 'Annet';
$labels['typemobile']  = 'Mobil';
$labels['typemain']  = 'Hoved';
$labels['typehomefax']  = 'Hjemmefaks';
$labels['typeworkfax']  = 'Faks på arbeid';
$labels['typecar']  = 'Bil';
$labels['typepager']  = 'Personsøker';
$labels['typevideo']  = 'Video';
$labels['typeassistant']  = 'Assistent';
$labels['typehomepage']  = 'Hjemmeside';
$labels['typeblog'] = 'Blogg';
$labels['typeprofile'] = 'Profil';
$labels['addfield'] = 'Legg til felt ...';
$labels['editcontact'] = 'Rediger kontakt';
$labels['contacts'] = 'Kontakter';
$labels['contactproperties'] = 'Egenskaper';
$labels['personalinfo'] = 'Personlig informasjon';
$labels['edit']   = 'Rediger';
$labels['cancel'] = 'Avbryt';
$labels['save']   = 'Lagre';
$labels['delete'] = 'Slett';
$labels['rename'] = 'Gi nytt navn';
$labels['addphoto'] = 'Legg til';
$labels['replacephoto'] = 'Erstatt';
$labels['uploadphoto'] = 'Last opp bilde';
$labels['deletecontact']  = 'Slett valgte kontakter';
$labels['composeto']      = 'Skriv e-post til';
$labels['contactsfromto'] = 'Kontakter $from til $to av $count';
$labels['print']          = 'Skriv ut';
$labels['export']         = 'Eksporter';
$labels['exportall']      = 'Eksporter alle';
$labels['exportsel']      = 'Eksporter valgte';
$labels['exportvcards']   = 'Eksporter kontakter i vCard-format';
$labels['grouprename']    = 'Endre navn på gruppe';
$labels['groupdelete']    = 'Slett gruppe';
$labels['groupremoveselected'] = 'Fjern valgte kontakter fra gruppe';
$labels['previouspage']   = 'Vis forrige sett';
$labels['firstpage']      = 'Vis første sett';
$labels['nextpage']       = 'Vis neste sett';
$labels['lastpage']       = 'Vis siste sett';
$labels['group'] = 'Gruppe';
$labels['groups'] = 'Grupper';
$labels['listgroup'] = 'Vis gruppemedlemmer';
$labels['personaladrbook'] = 'Egne adresser';
$labels['searchsave'] = 'Lagre søk';
$labels['searchdelete'] = 'Slett søk';
$labels['import'] = 'Importer';
$labels['importcontacts'] = 'Importer kontakter';
$labels['importfromfile'] = 'Importer fra fil:';
$labels['importtarget'] = 'Legg kontakter til';
$labels['importreplace'] = 'Erstatt hele adresseboken';
$labels['importgroups'] = 'Importer gruppetilordninger';
$labels['importgroupsall'] = 'Alle (opprett grupper hvis nødvendig)';
$labels['importgroupsexisting'] = 'Bare for eksisterende grupper';
$labels['importdesc'] = 'Du kan laste opp kontakter fra en eksisterende adressebok.<br/>Vi støtter adressebøker i <a href="http://no.wikipedia.org/wiki/VCard">vCard</a> eller CSV (kommaseparert) .';
$labels['done'] = 'Fullført';
$labels['settingsfor'] = 'Innstillinger for';
$labels['about'] = 'Om';
$labels['preferences'] = 'Oppsett';
$labels['userpreferences'] = 'Brukeroppsett';
$labels['editpreferences'] = 'Rediger brukeroppsett';
$labels['identities'] = 'Identiteter';
$labels['preferhtml'] = 'Foretrekk HTML';
$labels['defaultcharset'] = 'Standard tegnsett';
$labels['htmlmessage'] = 'HTML-melding';
$labels['messagepart'] = 'Del';
$labels['digitalsig'] = 'Digital signatur';
$labels['dateformat'] = 'Datoformat';
$labels['timeformat'] = 'Tidsformat';
$labels['prettydate'] = 'Pen datovisning';
$labels['setdefault']  = 'Sett som standard';
$labels['autodetect']  = 'Auto';
$labels['language']  = 'Språk';
$labels['timezone']  = 'Tidssone';
$labels['pagesize']  = 'Linjer per side';
$labels['signature'] = 'Signatur';
$labels['dstactive']  = 'Sommertid';
$labels['showinextwin'] = 'Åpne melding i nytt vindu';
$labels['composeextwin'] = 'Skriv i nytt vindu';
$labels['htmleditor'] = 'Bruk HTML-editor';
$labels['htmlonreply'] = 'ved svar på HTML-melding';
$labels['htmlonreplyandforward'] = 'ved videresending av eller svar på HTML-melding';
$labels['htmlsignature'] = 'HTML-signatur';
$labels['showemail'] = 'Vis e-postadresse sammen med visningsnavn';
$labels['previewpane'] = 'Forhåndsvisning';
$labels['skin'] = 'Utseende';
$labels['logoutclear'] = 'Tøm søppel ved utlogging';
$labels['logoutcompact'] = 'Kompakt innboksen ved utlogging';
$labels['uisettings'] = 'Brukergrensesnitt';
$labels['serversettings'] = 'Serverinnstillinger';
$labels['mailboxview'] = 'E-postvisning';
$labels['mdnrequests'] = 'Tilbakemelding til avsender';
$labels['askuser'] = 'spør hver gang';
$labels['autosend'] = 'send automatisk';
$labels['autosendknown'] = 'send kvittering til kontaktene mine, ellers spør meg';
$labels['autosendknownignore'] = 'send kvittering til kontaktene mine, ellers ignorer';
$labels['readwhendeleted'] = 'Merk melding som lest ved sletting';
$labels['flagfordeletion'] = 'Flagg meldingen for sletting i stedet for å slette';
$labels['skipdeleted'] = 'Ikke vis slettede meldinger';
$labels['deletealways'] = 'Hvis en melding ikke kan flyttes til Slettet, slett den';
$labels['deletejunk'] = 'Slett meldinger i spam direkte';
$labels['showremoteimages'] = 'Vis bilder fra eksterne servere i meldinger';
$labels['fromknownsenders'] = 'fra kjente avsendere';
$labels['always'] = 'alltid';
$labels['showinlineimages'] = 'Vis vedlagte bilder nedenfor meldingen';
$labels['autosavedraft']  = 'Autolagring av utkast';
$labels['everynminutes']  = 'hvert $n minutt';
$labels['refreshinterval']  = 'Oppdater (sjekk for nye meldinger etc.)';
$labels['never']  = 'Aldri';
$labels['immediately']  = 'umiddelbart';
$labels['messagesdisplaying'] = 'Visning av meldinger';
$labels['messagescomposition'] = 'Skriving av meldinger';
$labels['mimeparamfolding'] = 'Vedleggsnavn';
$labels['2231folding'] = 'Fullstendig RFC 2231 (Thunderbird)';
$labels['miscfolding'] = 'RFC 2047/2231 (MS Outlook)';
$labels['2047folding'] = 'Fullstendig RFC 2047 (andre)';
$labels['force7bit'] = 'Bruk MIME-koding for 8-bit-tegn';
$labels['advancedoptions'] = 'Avanserte alternativer';
$labels['focusonnewmessage'] = 'Gi nettleservindu fokus ved nye meldinger';
$labels['checkallfolders'] = 'Kontroller alle mapper for nye meldinger';
$labels['displaynext'] = 'Vis neste melding etter sletting/flytting av en melding';
$labels['defaultfont'] = 'Standard skrifttype i HTML-melding';
$labels['mainoptions'] = 'Hovedinnstillinger';
$labels['browseroptions'] = 'Alternativer for nettleser';
$labels['section'] = 'Kategori';
$labels['maintenance'] = 'Vedlikehold';
$labels['newmessage'] = 'Ny melding';
$labels['signatureoptions'] = 'Innstillinger for signatur';
$labels['whenreplying'] = 'Ved svar på e-post';
$labels['replyempty'] = 'Ikke siter den originale meldingen';
$labels['replytopposting'] = 'start den nye meldingen over orginalmeldingen';
$labels['replybottomposting'] = 'start den nye meldingen under orginalmeldingen';
$labels['replyremovesignature'] = 'Fjern orginalsignaturen i svar på melding';
$labels['autoaddsignature'] = 'Legg til signatur';
$labels['newmessageonly'] = 'kun på nye meldinger';
$labels['replyandforwardonly'] = 'kun i svar og videresendinger';
$labels['insertsignature'] = 'Sett inn signatur';
$labels['afternseconds']  = 'etter $n sekunder';
$labels['reqmdn'] = 'Alltid be om svarkvittering';
$labels['reqdsn'] = 'Alltid be om leveringsstatus';
$labels['replysamefolder'] = 'Legg svar i mappen til meldingen det svares på';
$labels['defaultabook'] = 'Standard adressebok';
$labels['autocompletesingle'] = 'Hopp over alternative e-postadresser i autofullføring';
$labels['listnamedisplay'] = 'Vis kontakter som';
$labels['spellcheckbeforesend'] = 'Kontroller staving før en melding sendes';
$labels['spellcheckoptions'] = 'Alternativer for stavekontroll';
$labels['spellcheckignoresyms'] = 'Ignorer ord med symboler';
$labels['spellcheckignorenums'] = 'Ignorer ord med tall';
$labels['spellcheckignorecaps'] = 'Ignorer ord med kun store bokstaver';
$labels['addtodict'] = 'Legg til i ordbok';
$labels['mailtoprotohandler'] = 'Registrer protokollhåndtering for mailto-lenker';
$labels['standardwindows'] = 'Håndter sprettoppvinduer som vanlige vinduer';
$labels['forwardmode'] = 'Meldinger videresendes';
$labels['inline'] = 'i teksten';
$labels['asattachment'] = 'som vedlegg';
$labels['replyallmode'] = 'Standard valg for [Svar alle] knapp';
$labels['replyalldefault'] = 'svar til alle';
$labels['replyalllist'] = 'svar kun til epostliste (hvis funnet)';
$labels['folder'] = 'Mappe';
$labels['folders'] = 'Mapper';
$labels['foldername'] = 'Mappenavn';
$labels['subscribed'] = 'Abonnere';
$labels['messagecount'] = 'Meldinger';
$labels['create'] = 'Opprett';
$labels['createfolder'] = 'Lag ny mappe';
$labels['managefolders'] = 'Rediger mapper';
$labels['specialfolders'] = 'Spesielle mapper';
$labels['properties'] = 'Egenskaper';
$labels['folderproperties'] = 'Egenskaper for mappe';
$labels['parentfolder'] = 'Overordnet mappe';
$labels['location'] = 'Sted';
$labels['info'] = 'Informasjon';
$labels['getfoldersize'] = 'Klikk for å få mappestørrelse';
$labels['changesubscription'] = 'Klikk for å endre abonnement';
$labels['foldertype'] = 'Mappetype';
$labels['personalfolder'] = 'Privat mappe';
$labels['otherfolder'] = 'Annen brukers mappe';
$labels['sharedfolder'] = 'Offentlig mappe';
$labels['sortby'] = 'Sorter etter';
$labels['sortasc']  = 'Eldste først';
$labels['sortdesc'] = 'Nyeste først';
$labels['undo'] = 'Angre';
$labels['installedplugins'] = 'Installerte tillegg';
$labels['plugin'] = 'Tilleggsmodul';
$labels['version'] = 'Versjon';
$labels['source'] = 'Kildekode';
$labels['license'] = 'Lisensvilkår';
$labels['support'] = 'Få hjelp';
$labels['B'] = 'B';
$labels['KB'] = 'KB';
$labels['MB'] = 'MB';
$labels['GB'] = 'GB';
$labels['unicode'] = 'Unicode';
$labels['english'] = 'Engelsk';
$labels['westerneuropean'] = 'Vesteuropeisk';
$labels['easterneuropean'] = 'Østeuropeisk';
$labels['southeasterneuropean'] = 'Sørøsteuropeisk';
$labels['baltic'] = 'Baltisk';
$labels['cyrillic'] = 'Cyrillisk';
$labels['arabic'] = 'Arabisk';
$labels['greek'] = 'Gresk';
$labels['hebrew'] = 'Hebraisk';
$labels['turkish'] = 'Tyrkisk';
$labels['nordic'] = 'Nordisk';
$labels['thai'] = 'Thailandsk';
$labels['celtic'] = 'Keltisk';
$labels['vietnamese'] = 'Vietnamesisk';
$labels['japanese'] = 'Japansk';
$labels['korean'] = 'Koreansk';
$labels['chinese'] = 'Kinesisk';
?>
