<roundcube:object name="doctype" value="html5" />
<html>
<head>
<title><roundcube:object name="pagetitle" /></title>
<roundcube:include file="/includes/links.html" />
</head>
<body class="iframe">

<h1 class="boxtitle"><roundcube:label name="advsearch" /></h1>

<div id="contact-details" class="boxcontent">
	<roundcube:object name="searchform" id="advsearchform" class="tabbed" size=30 />
	<p class="formbuttons">
		<roundcube:button command="save" type="input" class="button mainaction" label="search" />
	</p>
</div>

<roundcube:include file="/includes/footer.html" />

</body>
</html>
