<?php

/*
 +-----------------------------------------------------------------------+
 | plugins/userinfo/localization/<lang>.inc                              |
 |                                                                       |
 | Localization file of the Roundcube Webmail Userinfo plugin            |
 | Copyright (C) 2012-2013, The Roundcube Dev Team                       |
 |                                                                       |
 | Licensed under the GNU General Public License version 3 or            |
 | any later version with exceptions for skins & plugins.                |
 | See the README file for a full license statement.                     |
 |                                                                       |
 +-----------------------------------------------------------------------+

 For translation see https://www.transifex.com/projects/p/roundcube-webmail/resource/plugin-userinfo/
*/
$labels['userinfo'] = '사용자 정보';
$labels['created'] = '생성함';
$labels['lastlogin'] = '마지막 로그인';
$labels['defaultidentity'] = '기본 신원';
?>