<?php

/*
 +-----------------------------------------------------------------------+
 | localization/<lang>/labels.inc                                        |
 |                                                                       |
 | Localization file of the Roundcube Webmail client                     |
 | Copyright (C) 2005-2015, The Roundcube Dev Team                       |
 |                                                                       |
 | Licensed under the GNU General Public License version 3 or            |
 | any later version with exceptions for skins & plugins.                |
 | See the README file for a full license statement.                     |
 |                                                                       |
 +-----------------------------------------------------------------------+

 For translation see https://www.transifex.com/projects/p/roundcube-webmail/resource/labels/
*/
$labels['welcome']   = 'Velkommen til $product';
$labels['username']  = 'Brugernavn';
$labels['password']  = 'Adgangskode';
$labels['server']    = 'Server';
$labels['login']     = 'Log på';
$labels['menu']     = 'Menu';
$labels['logout']   = 'Log af';
$labels['mail']     = 'E-mail';
$labels['settings'] = 'Indstillinger';
$labels['addressbook'] = 'Adressebog';
$labels['inbox']  = 'Indbakke';
$labels['drafts'] = 'Kladder';
$labels['sent']   = 'Sendt post';
$labels['trash']  = 'Papirkurv';
$labels['junk']   = 'Spam';
$labels['show_real_foldernames'] = 'Vis rigtige navne for specielle mapper';
$labels['subject'] = 'Emne';
$labels['from']    = 'Afsender';
$labels['sender']  = 'Afsender';
$labels['to']      = 'Modtager';
$labels['cc']      = 'Cc';
$labels['bcc']     = 'Bcc';
$labels['replyto'] = 'Svar til';
$labels['followupto'] = 'Opfølgning til';
$labels['date']    = 'Dato';
$labels['size']    = 'Størrelse';
$labels['priority'] = 'Prioritet';
$labels['organization'] = 'Firma';
$labels['readstatus'] = 'Læst status';
$labels['listoptions'] = 'Listeindstillinger';
$labels['listoptionstitle'] = 'Vis muligheder';
$labels['mailboxlist'] = 'Mapper';
$labels['messagesfromto'] = 'Besked $from til $to af $count';
$labels['threadsfromto'] = 'Tråd $from til $to af $count';
$labels['messagenrof'] = 'Besked $nr af $count';
$labels['fromtoshort'] = '$from – $to af $count';
$labels['copy']     = 'Kopiér';
$labels['move']     = 'Flyt';
$labels['moveto']   = 'Flyt til...';
$labels['copyto']   = 'Kopier til...';
$labels['download'] = 'Download';
$labels['open']     = 'Åben';
$labels['showattachment'] = 'Vis';
$labels['showanyway'] = 'Vis alligevel';
$labels['filename'] = 'Filnavn';
$labels['filesize'] = 'Filstørrelse';
$labels['addtoaddressbook'] = 'Tilføj til adressebog';
$labels['sun'] = 'Søn';
$labels['mon'] = 'Man';
$labels['tue'] = 'Tir';
$labels['wed'] = 'Ons';
$labels['thu'] = 'Tor';
$labels['fri'] = 'Fre';
$labels['sat'] = 'Lør';
$labels['sunday']    = 'Søndag';
$labels['monday']    = 'Mandag';
$labels['tuesday']   = 'Tirsdag';
$labels['wednesday'] = 'Onsdag';
$labels['thursday']  = 'Torsdag';
$labels['friday']    = 'Fredag';
$labels['saturday']  = 'Lørdag';
$labels['jan']	= 'Jan';
$labels['feb']	= 'Feb';
$labels['mar']	= 'Mar';
$labels['apr']	= 'Apr';
$labels['may']	= 'Maj';
$labels['jun']	= 'Jun';
$labels['jul'] 	= 'Jul';
$labels['aug']	= 'Aug';
$labels['sep']	= 'Sep';
$labels['oct']	= 'Okt';
$labels['nov']	= 'Nov';
$labels['dec']	= 'Dec';
$labels['longjan']	= 'Januar';
$labels['longfeb']	= 'Februar';
$labels['longmar']	= 'Marts';
$labels['longapr']	= 'April';
$labels['longmay']	= 'Maj';
$labels['longjun']	= 'Juni';
$labels['longjul']	= 'Juli';
$labels['longaug']	= 'August';
$labels['longsep']	= 'September';
$labels['longoct']	= 'Oktober';
$labels['longnov']	= 'November';
$labels['longdec']	= 'December';
$labels['today'] = 'I dag';
$labels['refresh']          = 'Opdatér';
$labels['checkmail']        = 'Se efter nye beskeder';
$labels['compose']          = 'Ny besked';
$labels['writenewmessage']  = 'Skriv en ny besked';
$labels['reply']            = 'Svar';
$labels['replytomessage']   = 'Svar på denne besked';
$labels['replytoallmessage'] = 'Svar til alle modtagere';
$labels['replyall']         = 'Svar alle';
$labels['replylist']        = 'Svar til listen';
$labels['forward']          = 'Videresend';
$labels['forwardinline']    = 'Videresend';
$labels['forwardattachment'] = 'Videresend som vedhæftning';
$labels['forwardmessage']   = 'Videresend denne besked';
$labels['deletemessage']    = 'Slet besked';
$labels['movemessagetotrash'] = 'Flyt besked til skrald';
$labels['printmessage']     = 'Udskriv denne besked';
$labels['previousmessage']  = 'Vis forrige besked';
$labels['firstmessage']     = 'Vis første besked';
$labels['nextmessage']      = 'Vis næste besked';
$labels['lastmessage']      = 'Vis sidste besked';
$labels['backtolist']       = 'Tilbage til oversigten';
$labels['viewsource']       = 'Vis kilde';
$labels['mark']             = 'Markér';
$labels['markmessages']     = 'Markér beskeder';
$labels['markread']         = 'Som læst';
$labels['markunread']       = 'Som ulæst';
$labels['markflagged']      = 'Som markeret';
$labels['markunflagged']    = 'Som umarkeret';
$labels['moreactions']      = 'Flere funktioner...';
$labels['markallread']      = 'Marker alle som læst';
$labels['folders-cur']      = 'Du må kun vælge mapper';
$labels['folders-sub']      = 'Vælg mappe og dens undermapper';
$labels['folders-all']      = 'Alle mapper';
$labels['more']             = 'Mere';
$labels['back']             = 'Tilbage';
$labels['options']          = 'Indstillinger';
$labels['first'] = 'Første';
$labels['last'] = 'Sidste';
$labels['previous'] = 'Forrige';
$labels['next'] = 'Næste';
$labels['select'] = 'Vælg';
$labels['all'] = 'Alle';
$labels['none'] = 'Ingen';
$labels['currpage'] = 'Aktuel side';
$labels['isread'] = 'Læs';
$labels['unread'] = 'Ulæste';
$labels['flagged'] = 'Markeret';
$labels['unflagged'] = 'Ikke markeret';
$labels['unanswered'] = 'Ubesvaret';
$labels['withattachment'] = 'Med vedhæftning';
$labels['deleted'] = 'Slettede';
$labels['undeleted'] = 'Ikke slettet';
$labels['replied'] = 'Besvaret';
$labels['forwarded'] = 'Videresendt';
$labels['invert'] = 'Invertér';
$labels['filter'] = 'Filtrer';
$labels['list'] = 'Liste';
$labels['threads'] = 'Tråde';
$labels['expand-all'] = 'Udfold alle';
$labels['expand-unread'] = 'Udfold ulæste';
$labels['collapse-all'] = 'Fold alle';
$labels['threaded'] = 'Trådet';
$labels['autoexpand_threads'] = 'Udfold besked tråde';
$labels['do_expand'] = 'alle tråde';
$labels['expand_only_unread'] = 'kun dem med ulæste beskeder';
$labels['fromto'] = 'Afsender/Modtager';
$labels['flag'] = 'Flag';
$labels['attachment'] = 'Vedhæftning';
$labels['nonesort'] = 'Ingen';
$labels['sentdate'] = 'Sendt dato';
$labels['arrival'] = 'Modtaget dato';
$labels['asc'] = 'stigende';
$labels['desc'] = 'faldende';
$labels['listcolumns'] = 'Vist kolonne';
$labels['listsorting'] = 'Sorteringskolonne';
$labels['listorder'] = 'Sorter efter';
$labels['listmode'] = 'Listevisningsmode';
$labels['layout'] = 'Layout';
$labels['layoutlist'] = 'Liste';
$labels['layoutwidescreendesc'] = 'Widescreen (3 kolonner)';
$labels['layoutlistdesc'] = 'Liste (uden forhåndsvisning)';
$labels['folderactions'] = 'Mappehandlinger...';
$labels['compact'] = 'Ryd op';
$labels['empty'] = 'Tøm';
$labels['importmessages'] = 'Importer beskeder';
$labels['quota'] = 'Diskforbrug';
$labels['unknown']  = 'ukendt';
$labels['unlimited']  = 'ubegrænset';
$labels['quotatype'] = 'Kvotetype';
$labels['quotatotal'] = 'Grænse';
$labels['quotaused'] = 'Brugt';
$labels['quotastorage'] = 'Disk plads';
$labels['quotamessage'] = 'Beskeder';
$labels['quicksearch']  = 'Hurtigsøg';
$labels['searchplaceholder']  = 'Søg...';
$labels['resetsearch']  = 'Nulstil søgning';
$labels['searchmod']  = 'Søgeparametre';
$labels['msgtext']  = 'Hele beskeden';
$labels['body']  = 'Body';
$labels['type'] = 'Type';
$labels['namex'] = 'Navn';
$labels['searchscope'] = 'Omfang';
$labels['currentfolder'] = 'Nuværende mappe';
$labels['subfolders'] = 'Denne og undermapper';
$labels['allfolders'] = 'Alle mapper';
$labels['searchinterval-1W'] = 'ældre end en uge';
$labels['searchinterval-1M'] = 'ældre end en måned';
$labels['searchinterval-1Y'] = 'ældre end et år';
$labels['searchinterval1W'] = 'yngre end en uge';
$labels['searchinterval1M'] = 'yngre end en måned';
$labels['searchinterval1Y'] = 'yngre end et år';
$labels['openinextwin'] = 'Åbn i nyt vindue';
$labels['emlsave'] = 'Download (.eml)';
$labels['changeformattext'] = 'Vis i ren tekst format';
$labels['changeformathtml'] = 'Vis i HTML format';
$labels['editasnew']      = 'Redigér som ny';
$labels['send']           = 'Send';
$labels['sendmessage']    = 'Send besked';
$labels['savemessage']    = 'Gem som kladde';
$labels['addattachment']  = 'Vedhæft en fil';
$labels['charset']        = 'Tegnsæt';
$labels['editortype']     = 'Tekstbehandler';
$labels['returnreceipt']  = 'Anmod om kvittering ved læst';
$labels['dsn']            = 'Anmod om leveringsstatus';
$labels['mailreplyintro'] = '$sender skrev den $date:';
$labels['originalmessage'] = 'Original besked';
$labels['selectimage']    = 'Vælg billede';
$labels['addimage']       = 'Tilføje billede';
$labels['selectmedia']    = 'Vælg video';
$labels['addmedia']       = 'Tilføj video';
$labels['encrypt']        = 'Krypter';
$labels['encryptmessage'] = 'Krypter besked';
$labels['encryptmessagemailvelope'] = 'Krypter besked med Mailvelope';
$labels['importpubkeys']  = 'Importer offentlige nøgler';
$labels['encryptedsendialog'] = 'Sender krypteret besked';
$labels['keyid']          = 'NøgleID';
$labels['keylength']      = 'Bits';
$labels['keyexpired']     = 'Udløbet';
$labels['keyrevoked']     = 'Tilbagekaldt';
$labels['bccinstead']     = 'Brug Bcc';
$labels['editidents']    = 'Ret identiteter';
$labels['spellcheck']    = 'Stav';
$labels['checkspelling'] = 'Stavekontrol';
$labels['resumeediting'] = 'Genoptag redigering';
$labels['revertto']      = 'Vend tilbage til';
$labels['restore'] = 'Gendan';
$labels['restoremessage'] = 'Gendan besked';
$labels['ignore'] = 'Ignorer';
$labels['responses'] = 'Svar';
$labels['insertresponse'] = 'Indsæt et svar';
$labels['manageresponses'] = 'Administrer svar';
$labels['newresponse'] = 'Opret ny svar';
$labels['addresponse'] = 'Tilføj svar';
$labels['editresponse'] = 'Rediger svar';
$labels['editresponses'] = 'Rediger svar';
$labels['responsename'] = 'Navn';
$labels['responsetext'] = 'Svartekst';
$labels['attach'] = 'Vedhæft';
$labels['attachments'] = 'Vedhæftninger';
$labels['upload'] = 'Overfør';
$labels['uploadprogress'] = '$percent ($current af $total)';
$labels['close']  = 'Luk';
$labels['messageoptions']  = 'Beskedmuligheder...';
$labels['togglecomposeoptions'] = 'Skift kompositions indstillinger';
$labels['attachmentrename']  = 'Omdøb vedhæftet fil';
$labels['low']     = 'Lav';
$labels['lowest']  = 'Lavest';
$labels['normal']  = 'Normal';
$labels['high']    = 'Høj';
$labels['highest'] = 'Højest';
$labels['nosubject']  = '(intet emne)';
$labels['showimages'] = 'Vis billeder';
$labels['alwaysshow'] = 'Vis altid billeder fra $sender';
$labels['isdraft']    = 'Dette er en kladde.';
$labels['andnmore']   = '$nr yderligere...';
$labels['togglemoreheaders'] = 'Vis yderligere headers';
$labels['togglefullheaders'] = 'Ændre rå brevhoveder';
$labels['htmltoggle'] = 'HTML';
$labels['plaintoggle'] = 'Almindelig tekst';
$labels['savesentmessagein'] = 'Gem afsendt besked i';
$labels['dontsave'] = 'gem ikke';
$labels['maxuploadsize'] = 'Maksimale tilladte filstørrelse er $size';
$labels['addcc'] = 'Tilføj Cc';
$labels['addbcc'] = 'Tilføj Bcc';
$labels['addreplyto'] = 'Tilføj Svar-Til adresse';
$labels['addfollowupto'] = 'Tilføj følg-op adresse';
$labels['mdnrequest'] = 'Afsenderen af denne besked har bedt om at modtage en bekræftelse når du læser beskeden. Vil du sende kvittering for læsning?';
$labels['receiptread'] = 'Send kvittering for læsning';
$labels['yourmessage'] = 'Dette er en kvittering for at din besked er blevet vist';
$labels['receiptnote'] = 'Bemærk: Denne kvittering bekræfter udelukkende at beskeden blev vist på modtagerens computer. Der er ingen garanti for at modtageren har læst eller forstået beskedens indhold.';
$labels['name']         = 'Vist navn';
$labels['firstname']    = 'Fornavn';
$labels['surname']      = 'Efternavn';
$labels['middlename']   = 'Mellemnavn';
$labels['nameprefix']   = 'Præfiks';
$labels['namesuffix']   = 'Suffiks';
$labels['nickname']     = 'Alias/Kaldenavn';
$labels['jobtitle']     = 'Jobtitel';
$labels['department']   = 'Afdeling';
$labels['gender']       = 'Køn';
$labels['maidenname']   = 'Pigenavn';
$labels['email']        = 'E-mail';
$labels['phone']        = 'Telefon';
$labels['address']      = 'Adresse';
$labels['street']       = 'Vej';
$labels['locality']     = 'By';
$labels['zipcode']      = 'Postnr.';
$labels['region']       = 'Område/region';
$labels['country']      = 'Land';
$labels['birthday']     = 'Fødselsdag';
$labels['anniversary']  = 'Årsdag';
$labels['website']      = 'Hjemmeside';
$labels['instantmessenger'] = 'IM';
$labels['notes'] = 'Noter';
$labels['male']   = 'Mand';
$labels['female'] = 'Kvinde';
$labels['manager'] = 'Manager';
$labels['assistant'] = 'Assistent';
$labels['spouse'] = 'Ægtefælle/partner';
$labels['allfields'] = 'Alle felter';
$labels['search'] = 'Søg';
$labels['searchresult'] = 'Søgeresultat ';
$labels['advsearch'] = 'Avanceret søg';
$labels['advanced'] = 'Avanceret';
$labels['other'] = 'Andet';
$labels['printcontact'] = 'Udskriv kontakt';
$labels['qrcode'] = 'QR-kode';
$labels['typehome']   = 'Hjem';
$labels['typework']   = 'Arbejde';
$labels['typeother']  = 'Andet';
$labels['typemobile']  = 'Mobil';
$labels['typemain']  = 'Hovednr.';
$labels['typehomefax']  = 'Hjemme - fax';
$labels['typeworkfax']  = 'Arbejde - fax';
$labels['typecar']  = 'Bil';
$labels['typepager']  = 'Personsøger';
$labels['typevideo']  = 'Video';
$labels['typeassistant']  = 'Assistent';
$labels['typehomepage']  = 'Hjemmeside';
$labels['typeblog'] = 'Blog';
$labels['typeprofile'] = 'Profil';
$labels['addfield'] = 'Tilføj felt...';
$labels['addcontact'] = 'Tilføj kontakt';
$labels['editcontact'] = 'Redigér kontakt';
$labels['contacts'] = 'Kontakter';
$labels['contactproperties'] = 'Kontaktegenskaber';
$labels['contactnameandorg'] = 'Navn og organisation';
$labels['personalinfo'] = 'Personlig information';
$labels['personal'] = 'Personlig';
$labels['contactphoto'] = 'Kontaktfoto';
$labels['edit']   = 'Redigér';
$labels['cancel'] = 'Annullér';
$labels['save']   = 'Gem';
$labels['delete'] = 'Slet';
$labels['discard'] = 'Kasser';
$labels['rename'] = 'Omdøb';
$labels['addphoto'] = 'Tilføj';
$labels['replacephoto'] = 'Erstat';
$labels['uploadphoto'] = 'Overfør billede';
$labels['newcontact']     = 'Opret ny kontakt';
$labels['deletecontact']  = 'Slet valgte kontakter';
$labels['composeto']      = 'Skriv besked til';
$labels['contactsfromto'] = 'Kontakter $from til $to af $count';
$labels['print']          = 'Udskriv';
$labels['export']         = 'Eksportér';
$labels['exportall']      = 'Eksporter alt';
$labels['exportsel']      = 'Eksporter udvalgte';
$labels['exportvcards']   = 'Eksportér kontakter i vCard format';
$labels['newgroup']       = 'Opret gruppe';
$labels['addgroup']       = 'Tilføj gruppe';
$labels['grouprename']    = 'Omdøb gruppe';
$labels['groupdelete']    = 'Slet gruppe';
$labels['groupremoveselected'] = 'Fjern markerede kontakter fra gruppen';
$labels['uponelevel']     = 'Et niveau op';
$labels['previouspage']   = 'Vis den forrige side';
$labels['firstpage']      = 'Vis første side';
$labels['nextpage']       = 'Vis næste side';
$labels['lastpage']       = 'Vis sidste side';
$labels['group'] = 'Gruppe';
$labels['groups'] = 'Grupper';
$labels['listgroup'] = 'Vis gruppemedlemmer';
$labels['personaladrbook'] = 'Personlige adresser';
$labels['searchsave'] = 'Gem søgning';
$labels['searchdelete'] = 'Slet søgning';
$labels['import'] = 'Importér';
$labels['importcontacts'] = 'Importér kontakter';
$labels['importfromfile'] = 'Importér fra fil:';
$labels['importtarget'] = 'Tilføj kontakter til';
$labels['importreplace'] = 'Overskriv hele adressebogen';
$labels['importgroups'] = 'Importer gruppetildelinger';
$labels['importgroupsall'] = 'Alle (opret grupper hvis nødvendigt)';
$labels['importgroupsexisting'] = 'Kun for eksisterende grupper';
$labels['importdesc'] = 'Du kan uploade kontakter fra en eksisterende adressebog. <br/>I øjeblikket supportere vi import af adresser fra <a href="http://en.wikipedia.org/wiki/VCard">vCard</a> og CSV (komma-separeret) data format.';
$labels['done'] = 'Færdig';
$labels['settingsfor'] = 'Indstillinger for';
$labels['about'] = 'Om';
$labels['preferences'] = 'Indstillinger';
$labels['userpreferences'] = 'Brugerindstillinger';
$labels['editpreferences'] = 'Redigér brugerindstillinger';
$labels['identities'] = 'Identiteter';
$labels['manageidentities'] = 'Administrer identiteter ';
$labels['newidentity'] = 'Opret ny identitet ';
$labels['addidentity'] = 'Tilføj identitet';
$labels['editidentity'] = 'Rediger identitet';
$labels['preferhtml'] = 'Vis HTML';
$labels['defaultcharset'] = 'Standard tegnkodning';
$labels['htmlmessage'] = 'HTML-besked';
$labels['messagepart'] = 'Del';
$labels['digitalsig'] = 'Digital signatur';
$labels['dateformat'] = 'Datoformat';
$labels['timeformat'] = 'Tidsformat';
$labels['prettydate'] = 'Pæn datovisning';
$labels['setdefault']  = 'Sæt standard';
$labels['autodetect']  = 'Automatisk';
$labels['language']  = 'Sprog';
$labels['timezone']  = 'Tidszone';
$labels['pagesize']  = 'Rækker pr. side';
$labels['signature'] = 'Signatur';
$labels['dstactive']  = 'Sommertid';
$labels['showinextwin'] = 'Åben besked i et nyt vindue';
$labels['composeextwin'] = 'Opret besked i et nyt vindue';
$labels['htmleditor'] = 'Skriv HTML-besked';
$labels['htmlonreply'] = 'kun når jeg besvarer HTML-beskeder';
$labels['htmlonreplyandforward'] = 'ved videresendelse eller besvarelse af HTML beskeder';
$labels['htmlsignature'] = 'HTML-signatur';
$labels['showemail'] = 'Vis email-adresse med vist navn';
$labels['previewpane'] = 'Forhåndsvisning';
$labels['skin'] = 'Brugerflade';
$labels['logoutclear'] = 'Tøm Papirkurv når jeg logger af';
$labels['logoutcompact'] = 'Komprimér Indbakke når jeg logger af';
$labels['uisettings'] = 'Brugerflade';
$labels['serversettings'] = 'Serverindstillinger';
$labels['mailboxview'] = 'Mailboxvisning';
$labels['mdnrequests'] = 'Kvitteringer';
$labels['askuser'] = 'spørg mig';
$labels['autosend'] = 'send automatisk';
$labels['autosendknown'] = 'send automatisk til mine kontakter, ellers spørg mig';
$labels['autosendknownignore'] = 'send automatisk til mine kontakter, ellers ignorér';
$labels['ignorerequest'] = 'ignorer efterspørgsel';
$labels['readwhendeleted'] = 'Markér beskeden som læst ved sletning';
$labels['flagfordeletion'] = 'Markér beskeden til sletning istedet for at slette';
$labels['skipdeleted'] = 'Skjul slettede beskeder';
$labels['deletealways'] = 'Slet besked, hvis det mislykkes at flytte den til skrald';
$labels['deletejunk'] = 'Slet beskeder i Junk uden at flytte i skraldespand';
$labels['showremoteimages'] = 'Vis eksterne indlejrede billeder';
$labels['fromknownsenders'] = 'fra kendte afsendere';
$labels['always'] = 'altid';
$labels['alwaysbutplain'] = 'altid, undtagen ved besvarelse af ren-tekst';
$labels['showinlineimages'] = 'Vis vedhæftede billeder under beskeden';
$labels['autosavedraft']  = 'Gem kladde automatisk';
$labels['everynminutes']  = 'hver $n. minut';
$labels['refreshinterval']  = 'Opdater (tjek for nye beskeder m.v.)';
$labels['never']  = 'aldrig';
$labels['immediately']  = 'straks';
$labels['messagesdisplaying'] = 'Viser beskeder';
$labels['messagescomposition'] = 'Skriver nye beskeder';
$labels['mimeparamfolding'] = 'Navne på vedhæftninger';
$labels['2231folding'] = 'Fuld RFC 2231 understøttelse (Thunderbird)';
$labels['miscfolding'] = 'RFC 2047/2231 understøttelse (MS Outlook)';
$labels['2047folding'] = 'Fuld RFC 2047 understøttelse (andre)';
$labels['force7bit'] = 'Brug MIME indkodning for 8-bits tegn';
$labels['savelocalstorage'] = " ";
$labels['advancedoptions'] = 'Avancerede indstillinger';
$labels['toggleadvancedoptions'] = 'Skift avancerede indstillinger';
$labels['focusonnewmessage'] = 'Fokusér browservindue når der kommer nye beskeder';
$labels['checkallfolders'] = 'Tjek alle mapper for nye beskeder';
$labels['displaynext'] = 'Efter slet/flyt besked, vis næste besked';
$labels['defaultfont'] = 'Standard font ved HTML besked';
$labels['mainoptions'] = 'Generelle indstillinger';
$labels['browseroptions'] = 'Browserindstillinger';
$labels['section'] = 'Sektion';
$labels['maintenance'] = 'Vedligeholdelse';
$labels['newmessage'] = 'Ny besked';
$labels['signatureoptions'] = 'Signatur-indstillinger';
$labels['whenreplying'] = 'Når der svares';
$labels['replyempty'] = 'Citer ikke den originale besked';
$labels['replytopposting'] = 'begynd svar over originalen';
$labels['replytoppostingnoindent'] = 'begynd svar over originalen';
$labels['replybottomposting'] = 'begynd svar under originalen';
$labels['replyremovesignature'] = 'Fjern original signatur fra besked, når der svares';
$labels['autoaddsignature'] = 'Indsæt automatisk signatur';
$labels['newmessageonly'] = 'kun på nye beskeder';
$labels['replyandforwardonly'] = 'kun på svar og videresendelse af beskeder';
$labels['insertsignature'] = 'Indsæt signatur';
$labels['sigbelow'] = 'Placer signaturen under den citerede tekst';
$labels['afternseconds']  = 'efter $n sekunder';
$labels['reqmdn'] = 'Anmod altid om kvittering for læsning';
$labels['reqdsn'] = 'Anmod altid om at leveringsstatus';
$labels['replysamefolder'] = 'Placer svar til en besked i samme mappe som beskeden der besvares';
$labels['defaultabook'] = 'Standard adressebog';
$labels['autocompletesingle'] = 'Undgå alternative emailadresser under autofuldførelse';
$labels['listnamedisplay'] = 'Vis kontakter som';
$labels['spellcheckbeforesend'] = 'Tjek stavning inden beskeden sendes';
$labels['spellcheckoptions'] = 'Stavekontrolindstillinger';
$labels['spellcheckignoresyms'] = 'Ignorer ord med symboler';
$labels['spellcheckignorenums'] = 'Ignorer ord med tal';
$labels['spellcheckignorecaps'] = 'Ignorer ord hvor alle bogstaver er versaler';
$labels['addtodict'] = 'Tilføj til ordbog';
$labels['mailtoprotohandler'] = 'Registrer håndtering af \'mailto:\' links';
$labels['standardwindows'] = 'Behandl popups som standardvinduer';
$labels['forwardmode'] = 'Videresendelse af besked';
$labels['inline'] = 'inline';
$labels['asattachment'] = 'som vedhæftning';
$labels['replyallmode'] = 'Standardhandling til [Svar alle]-knap';
$labels['replyalldefault'] = 'Svar til alle';
$labels['replyalllist'] = 'svar kun til mail-liste (hvis fundet)';
$labels['folder'] = 'Mappe';
$labels['folders'] = 'Mapper';
$labels['foldername'] = 'Mappenavn';
$labels['subscribed'] = 'Abonneret';
$labels['messagecount'] = 'Beskeder';
$labels['create'] = 'Opret';
$labels['createfolder'] = 'Opret ny mappe';
$labels['managefolders'] = 'Administrér mapper';
$labels['specialfolders'] = 'Specielle mapper';
$labels['properties'] = 'Egenskaber';
$labels['folderproperties'] = 'Mappeegenskaber';
$labels['parentfolder'] = 'Mappe et niveau op';
$labels['location'] = 'Placering';
$labels['info'] = 'Information';
$labels['getfoldersize'] = 'Klik for at tjekke mappestørrelse';
$labels['changesubscription'] = 'Klik for at ændre abonnement';
$labels['foldertype'] = 'Mappetype';
$labels['personalfolder'] = 'Privat mappe';
$labels['otherfolder'] = 'Anden brugers mappe';
$labels['sharedfolder'] = 'Offentlig mappe';
$labels['findfolders'] = 'Find mapper';
$labels['findcontacts'] = 'Find kontakter';
$labels['findmail'] = 'Find beskeder';
$labels['namespace.personal'] = 'Personlig';
$labels['namespace.other'] = 'Andre brugere';
$labels['namespace.shared'] = 'Del';
$labels['sortby'] = 'Sortér efter';
$labels['sortasc']  = 'Ældste først';
$labels['sortdesc'] = 'Nyeste først';
$labels['undo'] = 'Fortryd';
$labels['installedplugins'] = 'Installerede udvidelser';
$labels['plugin'] = 'Plugin';
$labels['version'] = 'Version';
$labels['source'] = 'Kilde';
$labels['license'] = 'Licens';
$labels['support'] = 'Få support';
$labels['savedsearches'] = 'Gemte søgninger';
$labels['B'] = 'B';
$labels['KB'] = 'kB';
$labels['MB'] = 'MB';
$labels['GB'] = 'GB';
$labels['unicode'] = 'Unicode';
$labels['english'] = 'Engelsk';
$labels['westerneuropean'] = 'Vesteuropæisk';
$labels['easterneuropean'] = 'Østeuropæisk';
$labels['southeasterneuropean'] = 'Syd-østlig europæisk';
$labels['baltic'] = 'Baltisk';
$labels['cyrillic'] = 'Kyrillisk';
$labels['arabic'] = 'Arabisk';
$labels['greek'] = 'Græsk';
$labels['hebrew'] = 'Hebræisk';
$labels['turkish'] = 'Tyrkisk';
$labels['nordic'] = 'Nordisk';
$labels['thai'] = 'Thai';
$labels['celtic'] = 'Keltisk';
$labels['vietnamese'] = 'Vietnamesisk';
$labels['japanese'] = 'Japansk';
$labels['korean'] = 'Koreansk';
$labels['chinese'] = 'Kinesisk';
$labels['arialabeltopnav'] = 'Vindueskontrol';
$labels['arialabeltasknav'] = 'Application opgaver';
$labels['arialabeltoolbar'] = 'Program toolbar';
$labels['arialabelactivetask'] = 'Aktiv opgave';
$labels['arialabelmessagessearchfilter'] = 'E-mail filter';
$labels['arialabelmailsearchform'] = 'E-mail søgeform';
$labels['arialabelcontactsearchform'] = 'Kontakt søgeform';
$labels['arialabelmailquicksearchbox'] = 'E-mail søgeinput';
$labels['arialabelquicksearchbox'] = 'Søge input';
$labels['arialabelfoldersearchfilter'] = 'Mappevisningsfilter';
$labels['arialabelfoldersearchform'] = 'Mappe søgeform';
$labels['arialabelfolderlist'] = 'E-mail mappe valg';
$labels['arialabelmessagelist'] = 'E-mail Besked Visning';
$labels['arialabelmailpreviewframe'] = 'Beskedvisning';
$labels['arialabelmailboxmenu'] = 'Mappehandlingsmenu';
$labels['arialabellistselectmenu'] = 'Listevalgsmenu';
$labels['arialabelmessagebody'] = 'Besked indhold';
$labels['arialabelmessageactions'] = 'Beskedmuligheder';
$labels['arialabelcontactquicksearch'] = 'Kontakt søgeform';
$labels['arialabelcontactsearchbox'] = 'Kontakt søgeinput';
$labels['arialabelmessageheaders'] = 'Brevhoveder';
$labels['arialabelforwardingoptions'] = 'Videresendelsesindstillinger';
$labels['arialabelreplyalloptions'] = 'Svar-alle indstillinger';
$labels['arialabelmoremessageactions'] = 'Flere funktioner';
$labels['arialabelmarkmessagesas'] = 'Markér valgte beskeder som...';
$labels['arialabelcomposeoptions'] = 'Kompositionsindstillinger';
$labels['arialabelresponsesmenu'] = 'Forberedte-svar menu';
$labels['arialabelattachmentuploadform'] = 'Vedhæftnings uploadform';
$labels['arialabelattachmentpreview'] = 'Vedhæftnings forhåndsvisning';
$labels['arialabelsearchterms'] = 'Søgekriterier';
?>
