<?php

/*
 +-----------------------------------------------------------------------+
 | plugins/newmail_notifier/localization/<lang>.inc                      |
 |                                                                       |
 | Localization file of the Roundcube Webmail New Mail Notifier plugin   |
 | Copyright (C) 2012-2013, The Roundcube Dev Team                       |
 |                                                                       |
 | Licensed under the GNU General Public License version 3 or            |
 | any later version with exceptions for skins & plugins.                |
 | See the README file for a full license statement.                     |
 |                                                                       |
 +-----------------------------------------------------------------------+

 For translation see https://www.transifex.com/projects/p/roundcube-webmail/resource/plugin-newmail_notifier/
*/
$labels['basic'] = 'Εμφανίση ειδοποιήσεων πρόγραμματος περιήγησης στο νέο μήνυμα';
$labels['desktop'] = 'Εμφάνιση ειδοποιήσεων στην επιφάνεια εργασίας για νέο μήνυμα ';
$labels['sound'] = 'Ηχητική ειδοποίηση κατά την λήψη νέων μηνυμάτων';
$labels['test'] = 'Δοκιμή';
$labels['title'] = 'Nεο Email!';
$labels['body'] = 'Έχετε λάβει ένα νέο μήνυμα.';
$labels['testbody'] = 'Αυτή είναι μια δοκιμή ειδοποίησης.';
$labels['desktopdisabled'] = 'Οι ειδοποιήσεις στην επιφάνεια εργασίας ειναι απενεργοποιημένες στον περιηγητή σας.';
$labels['desktopunsupported'] = 'Ο περιηγητής σας δεν υποστηρίζει ειδοποιήσεις στην επιφάνεια εργασίας.';
$labels['desktoptimeout'] = 'Κλείσιμο ειδοποίησης επιφάνειας εργασίας';
?>
