<?php

/*
 +-----------------------------------------------------------------------+
 | localization/<lang>/labels.inc                                        |
 |                                                                       |
 | Localization file of the Roundcube Webmail client                     |
 | Copyright (C) 2005-2015, The Roundcube Dev Team                       |
 |                                                                       |
 | Licensed under the GNU General Public License version 3 or            |
 | any later version with exceptions for skins & plugins.                |
 | See the README file for a full license statement.                     |
 |                                                                       |
 +-----------------------------------------------------------------------+

 For translation see https://www.transifex.com/projects/p/roundcube-webmail/resource/labels/
*/
$labels['welcome']   = 'Benvingut a $product';
$labels['username']  = 'Nom d\'usuari';
$labels['password']  = 'Contrasenya';
$labels['server']    = 'Servidor';
$labels['login']     = 'Entra';
$labels['logout']   = 'Tanca sessió';
$labels['mail']     = 'Correu';
$labels['settings'] = 'Configuració';
$labels['addressbook'] = 'Contactes';
$labels['inbox']  = 'Safata d\'entrada';
$labels['drafts'] = 'Esborranys';
$labels['sent']   = 'Enviats';
$labels['trash']  = 'Paperera';
$labels['junk']   = 'Correu brossa';
$labels['show_real_foldernames'] = 'Mostra els noms reals a les carpetes especials';
$labels['subject'] = 'Assumpte';
$labels['from']    = 'Remitent';
$labels['sender']  = 'Remitent';
$labels['to']      = 'Destinatari';
$labels['cc']      = 'Cc';
$labels['bcc']     = 'Bcc';
$labels['replyto'] = 'Respon a';
$labels['followupto'] = 'Seguiment-a';
$labels['date']    = 'Data';
$labels['size']    = 'Mida';
$labels['priority'] = 'Prioritat';
$labels['organization'] = 'Organització';
$labels['readstatus'] = 'Estat de lectura';
$labels['listoptions'] = 'Llista d\'opcions...';
$labels['mailboxlist'] = 'Carpetes';
$labels['messagesfromto'] = 'Missatges $from a $to de $count';
$labels['threadsfromto'] = 'Fils $from a $to de $count';
$labels['messagenrof'] = 'Missatge $nr de $count';
$labels['fromtoshort'] = '$from - $to de $count';
$labels['copy']     = 'Copia';
$labels['move']     = 'Mou';
$labels['moveto']   = 'Mou a...';
$labels['copyto']   = 'Copia a...';
$labels['download'] = 'Descarrega';
$labels['open']     = 'Obre';
$labels['showattachment'] = 'Mostra';
$labels['showanyway'] = 'Mostra-ho de totes maneres';
$labels['filename'] = 'Nom del fitxer';
$labels['filesize'] = 'Mida del fitxer';
$labels['addtoaddressbook'] = 'Afegeix a contactes';
$labels['sun'] = 'dg';
$labels['mon'] = 'dl';
$labels['tue'] = 'dm';
$labels['wed'] = 'dc';
$labels['thu'] = 'dj';
$labels['fri'] = 'dv';
$labels['sat'] = 'ds';
$labels['sunday']    = 'Diumenge';
$labels['monday']    = 'Dilluns';
$labels['tuesday']   = 'Dimarts';
$labels['wednesday'] = 'Dimecres';
$labels['thursday']  = 'Dijous';
$labels['friday']    = 'Divendres';
$labels['saturday']  = 'Dissabte';
$labels['jan']	= 'gen';
$labels['feb']	= 'feb';
$labels['mar']	= 'mar';
$labels['apr']	= 'abr';
$labels['may']	= 'mai';
$labels['jun']	= 'jun';
$labels['jul'] 	= 'jul';
$labels['aug']	= 'ago';
$labels['sep']	= 'set';
$labels['oct']	= 'oct';
$labels['nov']	= 'nov';
$labels['dec']	= 'des';
$labels['longjan']	= 'gener';
$labels['longfeb']	= 'febrer';
$labels['longmar']	= 'març';
$labels['longapr']	= 'abril';
$labels['longmay']	= 'maig';
$labels['longjun']	= 'juny';
$labels['longjul']	= 'juliol';
$labels['longaug']	= 'agost';
$labels['longsep']	= 'setembre';
$labels['longoct']	= 'octubre';
$labels['longnov']	= 'novembre';
$labels['longdec']	= 'desembre';
$labels['today'] = 'Avui';
$labels['refresh']          = 'Actualitza';
$labels['checkmail']        = 'Comprova si hi ha missatges nous';
$labels['compose']          = 'Escriu un missatge';
$labels['writenewmessage']  = 'Crea un nou missatge';
$labels['reply']            = 'Respon';
$labels['replytomessage']   = 'Respon al remitent';
$labels['replytoallmessage'] = 'Respon a la llista o al remitent i a tots els destinataris';
$labels['replyall']         = 'Respon a tots';
$labels['replylist']        = 'Respon a la llista';
$labels['forward']          = 'Reenvia';
$labels['forwardinline']    = 'Reenvia com en línia';
$labels['forwardattachment'] = 'Reenvia com a adjunt';
$labels['forwardmessage']   = 'Reenvia el missatge';
$labels['deletemessage']    = 'Suprimeix el missatge';
$labels['movemessagetotrash'] = 'Mou el missatge a la paperera';
$labels['printmessage']     = 'Imprimeix aquest missatge';
$labels['previousmessage']  = 'Mostra el missatge anterior';
$labels['firstmessage']     = 'Mostra el primer missatge';
$labels['nextmessage']      = 'Mostra el missatge següent';
$labels['lastmessage']      = 'Mostra l\'últim missatge';
$labels['backtolist']       = 'Torna a la llista de missatges';
$labels['viewsource']       = 'Mostra el codi font';
$labels['mark']             = 'Marca';
$labels['markmessages']     = 'Marca missatges';
$labels['markread']         = 'Com a llegits';
$labels['markunread']       = 'Com a no llegits';
$labels['markflagged']      = 'Com a marcat';
$labels['markunflagged']    = 'Com a no marcat';
$labels['moreactions']      = 'Més accions...';
$labels['markallread']      = 'Marca-ho tot com a llegit';
$labels['folders-cur']      = 'Només la carpeta seleccionada';
$labels['folders-sub']      = 'Selecciona la carpeta i les seves subcarpetes';
$labels['folders-all']      = 'Totes les carpetes';
$labels['more']             = 'Més';
$labels['back']             = 'Torna';
$labels['options']          = 'Opcions';
$labels['first'] = 'Primer';
$labels['last'] = 'Darrer';
$labels['previous'] = 'Anterior';
$labels['next'] = 'Següent';
$labels['select'] = 'Selecciona';
$labels['all'] = 'Tots';
$labels['none'] = 'Cap';
$labels['currpage'] = 'Pàgina actual';
$labels['isread'] = 'Llegeix';
$labels['unread'] = 'No llegit';
$labels['flagged'] = 'Marcat';
$labels['unflagged'] = 'No marcat';
$labels['unanswered'] = 'No respost';
$labels['withattachment'] = 'Amb fitxer adjunt';
$labels['deleted'] = 'Suprimit';
$labels['undeleted'] = 'No s\'ha suprimit';
$labels['replied'] = 'Respost';
$labels['forwarded'] = 'Reenviat';
$labels['invert'] = 'Inverteix';
$labels['filter'] = 'Filtre';
$labels['list'] = 'Llista';
$labels['threads'] = 'Fils de discussió';
$labels['expand-all'] = 'Expandeix tot';
$labels['expand-unread'] = 'Expandeix No llegits';
$labels['collapse-all'] = 'Redueix tot';
$labels['threaded'] = 'Encadenat';
$labels['autoexpand_threads'] = 'Expandeix els missatges encadenats';
$labels['do_expand'] = 'tots els fils de discussió';
$labels['expand_only_unread'] = 'només amb missatges no llegits';
$labels['fromto'] = 'Remitent/Destinatari';
$labels['flag'] = 'Marca';
$labels['attachment'] = 'Adjunt';
$labels['nonesort'] = 'Cap';
$labels['sentdate'] = 'Data d\'enviament';
$labels['arrival'] = 'Data d\'arribada';
$labels['asc'] = 'ascendent';
$labels['desc'] = 'descendent';
$labels['listcolumns'] = 'Llista les columnes';
$labels['listsorting'] = 'Columna d\'ordenació';
$labels['listorder'] = 'Ordre d\'ordenació';
$labels['listmode'] = 'Mode de vista de llista';
$labels['layout'] = 'Disposició';
$labels['layoutwidescreen'] = 'Pantalla panoràmica';
$labels['layoutdesktop'] = 'Escriptori';
$labels['layoutlist'] = 'Llista';
$labels['folderactions'] = 'Accions de carpeta...';
$labels['compact'] = 'Compacta';
$labels['empty'] = 'Buida';
$labels['importmessages'] = 'Importa missatges';
$labels['quota'] = 'Ús del disc';
$labels['unknown']  = 'desconegut';
$labels['unlimited']  = 'il·limitat';
$labels['quotatype'] = 'Tipus de quota';
$labels['quotatotal'] = 'Límit';
$labels['quotaused'] = 'Utilitzat';
$labels['quotastorage'] = 'Espai de disc';
$labels['quotamessage'] = 'Comptador de missatges';
$labels['quicksearch']  = 'Cerca ràpida';
$labels['resetsearch']  = 'Neteja cerca';
$labels['searchmod']  = 'Cerca modificadors';
$labels['msgtext']  = 'Missatge sencer';
$labels['body']  = 'Cos';
$labels['type'] = 'Tipus';
$labels['namex'] = 'Nom';
$labels['searchscope'] = 'Abast';
$labels['currentfolder'] = 'Carpeta actual';
$labels['subfolders'] = 'Aquesta i les seves subcarpetes';
$labels['allfolders'] = 'Totes les carpetes';
$labels['searchinterval-1W'] = 'Més antic d\'una setmana';
$labels['searchinterval-1M'] = 'Més antic d\'un mes';
$labels['searchinterval-1Y'] = 'Més antic d\'un any';
$labels['searchinterval1W'] = 'Menor d\'una setmana';
$labels['searchinterval1M'] = 'Menor d\'un mes';
$labels['searchinterval1Y'] = 'Menor d\'un any';
$labels['openinextwin'] = 'Obre a una nova finestra';
$labels['emlsave'] = 'Descarrega (.eml)';
$labels['changeformattext'] = 'Mostra en format de text net';
$labels['changeformathtml'] = 'Mostra en format HTML';
$labels['editasnew']      = 'Edita com a nou';
$labels['send']           = 'Envia';
$labels['sendmessage']    = 'Envia el missatge';
$labels['savemessage']    = 'Desa com a esborrany';
$labels['addattachment']  = 'Adjunta un fitxer';
$labels['charset']        = 'Codificació de caràcters';
$labels['editortype']     = 'Tipus d\'editor';
$labels['returnreceipt']  = 'Confirmació de recepció';
$labels['dsn']            = 'Notificació d\'estat de lliurament';
$labels['mailreplyintro'] = 'A $date, $sender escrigué:';
$labels['originalmessage'] = 'Missatge Original';
$labels['selectimage']    = 'Selecciona una imatge';
$labels['addimage']       = 'Afegeix una imatge';
$labels['selectmedia']    = 'Selecciona pel·lícula';
$labels['addmedia']       = 'Afegeix pel·lícula';
$labels['encrypt']        = 'Xifrar';
$labels['encryptmessage'] = 'Xifrar missatge';
$labels['encryptmessagemailvelope'] = 'Xifrar missatge amb Mailvelope';
$labels['importpubkeys']  = 'Importar claus públiques';
$labels['encryptedsendialog'] = 'Enviar missatge xifrat';
$labels['keyid']          = 'ID de la clau';
$labels['keylength']      = 'Bits';
$labels['keyexpired']     = 'Caducat';
$labels['keyrevoked']     = 'Revocat';
$labels['bccinstead']     = 'Fes servir Bcc';
$labels['editidents']    = 'Edita identitats';
$labels['spellcheck']    = 'Ortografia';
$labels['checkspelling'] = 'Comprova l\'ortografia';
$labels['resumeediting'] = 'Reprèn l\'edició';
$labels['revertto']      = 'Torna a';
$labels['restore'] = 'Recupera';
$labels['restoremessage'] = 'Recupera el missatge?';
$labels['ignore'] = 'Ignora';
$labels['responses'] = 'Respostes';
$labels['insertresponse'] = 'Introduïu una resposta';
$labels['manageresponses'] = 'Gestiona respostes';
$labels['newresponse'] = 'Crea una nova resposta';
$labels['addresponse'] = 'Afegeix una resposta';
$labels['editresponse'] = 'Edita la resposta';
$labels['editresponses'] = 'Edita respostes';
$labels['responsename'] = 'Nom';
$labels['responsetext'] = 'Text de resposta';
$labels['attach'] = 'Adjunta';
$labels['attachments'] = 'Adjunts';
$labels['upload'] = 'Afegeix';
$labels['uploadprogress'] = '$percent ($current de $total)';
$labels['close']  = 'Tanca';
$labels['messageoptions']  = 'Opcions de missatge...';
$labels['togglecomposeoptions'] = 'Commuta les opcions de composició';
$labels['attachmentrename']  = 'Reanomena el fitxer adjunt';
$labels['low']     = 'Baixa';
$labels['lowest']  = 'La més baixa';
$labels['normal']  = 'Normal';
$labels['high']    = 'Alta';
$labels['highest'] = 'La més alta';
$labels['nosubject']  = '(sense assumpte)';
$labels['showimages'] = 'Mostra les imatges';
$labels['alwaysshow'] = 'Mostra sempre les imatges de $sender';
$labels['isdraft']    = 'Aquest és un missatge esborrany.';
$labels['andnmore']   = '$nr més...';
$labels['togglemoreheaders'] = 'Mostra més capçaleres del missatge';
$labels['togglefullheaders'] = 'Commuta les capçaleres del missatge en brut';
$labels['htmltoggle'] = 'HTML';
$labels['plaintoggle'] = 'Text net';
$labels['savesentmessagein'] = 'Desa el missatge enviat a';
$labels['dontsave'] = 'no ho desis';
$labels['maxuploadsize'] = 'La mida màxima permesa del fitxer és $size';
$labels['addcc'] = 'Afegeix Cc';
$labels['addbcc'] = 'Afegeix Bcc';
$labels['addreplyto'] = 'Afegeix Respon-A';
$labels['addfollowupto'] = 'Afegir Seguiment-A';
$labels['mdnrequest'] = 'El remitent d\'aquest missatge ha demanat ser notificat quan llegiu aquest missatge. Voleu notificar al remitent?';
$labels['receiptread'] = 'Confirmació de recepció (llegit)';
$labels['yourmessage'] = 'Això és una confirmació de recepció per al vostre missatge';
$labels['receiptnote'] = 'Nota: Aquesta confirmació només indica que el missatge ha estat mostrat a l\'ordinador del destinatari. No hi ha garantia que el destinatari hagi llegit o entès el contingut del missatge.';
$labels['name']         = 'Nom a mostrar';
$labels['firstname']    = 'Nom';
$labels['surname']      = 'Cognom';
$labels['middlename']   = 'Segon Nom';
$labels['nameprefix']   = 'Prefix';
$labels['namesuffix']   = 'Sufix';
$labels['nickname']     = 'Àlies';
$labels['jobtitle']     = 'Càrrec';
$labels['department']   = 'Departament';
$labels['gender']       = 'Sexe';
$labels['maidenname']   = 'Cognom de Solter/a';
$labels['email']        = 'Correu electrònic';
$labels['phone']        = 'Telèfon';
$labels['address']      = 'Adreça';
$labels['street']       = 'Carrer';
$labels['locality']     = 'Ciutat';
$labels['zipcode']      = 'Codi postal';
$labels['region']       = 'Estat/Província';
$labels['country']      = 'País';
$labels['birthday']     = 'Data de naixement';
$labels['anniversary']  = 'Aniversari';
$labels['website']      = 'Pàgina web';
$labels['instantmessenger'] = 'IM';
$labels['notes'] = 'Notes';
$labels['male']   = 'home';
$labels['female'] = 'dona';
$labels['manager'] = 'Gerent';
$labels['assistant'] = 'Assistent';
$labels['spouse'] = 'Cònjuge';
$labels['allfields'] = 'Tots els camps';
$labels['search'] = 'Cerca';
$labels['searchresult'] = 'Resultat de la cerca';
$labels['advsearch'] = 'Cerca Avançada';
$labels['advanced'] = 'Paràmetres avançats';
$labels['other'] = 'Un altre';
$labels['printcontact'] = 'Imprimeix el contacte';
$labels['qrcode'] = 'Codi QR';
$labels['typehome']   = 'Casa';
$labels['typework']   = 'Feina';
$labels['typeother']  = 'Un altre';
$labels['typemobile']  = 'Mòbil';
$labels['typemain']  = 'Principal';
$labels['typehomefax']  = 'Fax particular';
$labels['typeworkfax']  = 'Fax de la feina';
$labels['typecar']  = 'Cotxe';
$labels['typepager']  = 'Cercapersones';
$labels['typevideo']  = 'Vídeo';
$labels['typeassistant']  = 'Assistent';
$labels['typehomepage']  = 'Pàgina web personal';
$labels['typeblog'] = 'Bloc';
$labels['typeprofile'] = 'Perfil';
$labels['addfield'] = 'Afegeix camp...';
$labels['addcontact'] = 'Afegeix un contacte';
$labels['editcontact'] = 'Edita el contacte';
$labels['contacts'] = 'Contactes';
$labels['contactproperties'] = 'Propietats del contacte';
$labels['contactnameandorg'] = 'Nom i Organització';
$labels['personalinfo'] = 'Informació personal';
$labels['personal'] = 'Personal';
$labels['contactphoto'] = 'Foto de contacte';
$labels['edit']   = 'Edita';
$labels['cancel'] = 'Cancel·la';
$labels['save']   = 'Desa';
$labels['delete'] = 'Suprimeix';
$labels['discard'] = 'Descarta';
$labels['rename'] = 'Reanomena';
$labels['addphoto'] = 'Afegeix';
$labels['replacephoto'] = 'Reemplaça';
$labels['uploadphoto'] = 'Afegeix una fotografia';
$labels['newcontact']     = 'Crea un nou contacte';
$labels['deletecontact']  = 'Suprimeix els contactes seleccionats';
$labels['composeto']      = 'Redacta correu per a';
$labels['contactsfromto'] = 'Contactes $from a $to de $count';
$labels['print']          = 'Imprimeix';
$labels['export']         = 'Exporta';
$labels['exportall']      = 'Exporta\'ls tots';
$labels['exportsel']      = 'Exporta els seleccionats';
$labels['exportvcards']   = 'Exporta contactes en format vCard';
$labels['newgroup']       = 'Crea un grup nou';
$labels['addgroup']       = 'Afegeix un grup';
$labels['grouprename']    = 'Reanomena el grup';
$labels['groupdelete']    = 'Suprimeix el grup';
$labels['groupremoveselected'] = 'Suprimeix els contactes seleccionats del grup';
$labels['uponelevel']     = 'Un nivell amunt';
$labels['previouspage']   = 'Mostra la pàgina anterior';
$labels['firstpage']      = 'Mostra la primera pàgina';
$labels['nextpage']       = 'Mostra la pàgina següent';
$labels['lastpage']       = 'Mostra la darrera pàgina';
$labels['group'] = 'Grup';
$labels['groups'] = 'Grups';
$labels['listgroup'] = 'Llista els membres del grup';
$labels['personaladrbook'] = 'Llibreta d\'adreces personals';
$labels['searchsave'] = 'Desa la cerca';
$labels['searchdelete'] = 'Suprimeix la cerca';
$labels['import'] = 'Importa';
$labels['importcontacts'] = 'Importa contactes';
$labels['importfromfile'] = 'Importa des d\'un fitxer:';
$labels['importtarget'] = 'Afegeix contactes a';
$labels['importreplace'] = 'Substitueix la llibreta d\'adreces sencera';
$labels['importgroups'] = 'Importa assignacions de grup';
$labels['importgroupsall'] = 'Tot (crea grups si és necessari)';
$labels['importgroupsexisting'] = 'Només per a grups existents';
$labels['importdesc'] = 'Podeu afegir contactes des d\'una llibreta d\'adreces.<br/>Actualment donem suport a la importació d\'adreces des de fitxers de tipus <a href="http://ca.wikipedia.org/wiki/VCard">vCard</a> o CSV (valors separats per comes).';
$labels['done'] = 'Fet';
$labels['settingsfor'] = 'Configuració per a';
$labels['about'] = 'Quant a';
$labels['preferences'] = 'Preferències';
$labels['userpreferences'] = 'Preferències de l\'usuari';
$labels['editpreferences'] = 'Edita les preferències de l\'usuari';
$labels['identities'] = 'Identitats';
$labels['manageidentities'] = 'Gestiona les identitats';
$labels['newidentity'] = 'Crea una nova identitat';
$labels['addidentity'] = 'Afegeix una identitat';
$labels['editidentity'] = 'Edita la identitat';
$labels['preferhtml'] = 'Mostra HTML';
$labels['defaultcharset'] = 'Joc de caràcters per defecte';
$labels['htmlmessage'] = 'Missatge HTML';
$labels['messagepart'] = 'Part';
$labels['digitalsig'] = 'Signatura digital';
$labels['dateformat'] = 'Format de la data';
$labels['timeformat'] = 'Format horari';
$labels['prettydate'] = 'Dates curtes';
$labels['setdefault']  = 'Posa-ho per defecte';
$labels['autodetect']  = 'Auto';
$labels['language']  = 'Idioma';
$labels['timezone']  = 'Fus horari';
$labels['pagesize']  = 'Files per pàgina';
$labels['signature'] = 'Signatura';
$labels['dstactive']  = 'Horari d\'estiu';
$labels['showinextwin'] = 'Obre el missatge en una nova finestra';
$labels['composeextwin'] = 'Redacta en una nova finestra';
$labels['htmleditor'] = 'Escriu missatges en HTML';
$labels['htmlonreply'] = 'només en resposta a missatges en HTML';
$labels['htmlonreplyandforward'] = 'quan es reenviï o es respongui un missatge en HTML';
$labels['htmlsignature'] = 'Signatura en HTML';
$labels['showemail'] = 'Mostra l\'adreça electrònica amb el nom';
$labels['previewpane'] = 'Mostra el panell de previsualització';
$labels['skin'] = 'Aparença d\'interfície';
$labels['logoutclear'] = 'Buida la paperera al tancar la sessió';
$labels['logoutcompact'] = 'Compacta la safata d\'entrada al tancar la sessió';
$labels['uisettings'] = 'Interfície de l\'usuari';
$labels['serversettings'] = 'Configuració del servidor';
$labels['mailboxview'] = 'Vista de la bústia';
$labels['mdnrequests'] = 'Quan es demani confirmació de recepció';
$labels['askuser'] = 'demana\'m què vull fer';
$labels['autosend'] = 'envia la confirmació de recepció';
$labels['autosendknown'] = 'envia la confirmació de recepció als meus contactes, pels demés demana-m\'ho';
$labels['autosendknownignore'] = 'envia la confirmació als meus contactes, pels demés ignora-ho';
$labels['ignorerequest'] = 'Ignora la petició';
$labels['readwhendeleted'] = 'Marca el missatge com a llegit quan se suprimeixi';
$labels['flagfordeletion'] = 'Marca el missatge com a suprimit en comptes de suprimir-lo';
$labels['skipdeleted'] = 'No mostris els missatges suprimits';
$labels['deletealways'] = 'Si falla quan es mou un missatge a la Paperera, aleshores suprimeix-lo';
$labels['deletejunk'] = 'Suprimeix directament els missatges de Correu brossa';
$labels['showremoteimages'] = 'Mostra les imatges remotes del missatge';
$labels['fromknownsenders'] = 'de remitents coneguts';
$labels['always'] = 'sempre';
$labels['alwaysbutplain'] = 'Sempre, excepte quan es respon en text net';
$labels['showinlineimages'] = 'Mostra les imatges adjuntes sota el missatge';
$labels['autosavedraft']  = 'Desa l\'esborrany automàticament';
$labels['everynminutes']  = 'cada $n minut(s)';
$labels['refreshinterval']  = 'Actualitza (comprova nous missatges, etc.)';
$labels['never']  = 'mai';
$labels['immediately']  = 'immediatament';
$labels['messagesdisplaying'] = 'Vista de missatges';
$labels['messagescomposition'] = 'Composició de missatges';
$labels['mimeparamfolding'] = 'Noms dels adjunts';
$labels['2231folding'] = 'Compleix RFC 2231 (Thunderbird)';
$labels['miscfolding'] = 'RFC 2047/2231 (MS Outlook)';
$labels['2047folding'] = 'Compleix RFC 2047 (un altre)';
$labels['force7bit'] = 'Fes servir la codificació MIME per a caràcters de 8-bits';
$labels['savelocalstorage'] = "Desa-ho (temporalment) a l'espai local del navegador";
$labels['advancedoptions'] = 'Opcions avançades';
$labels['toggleadvancedoptions'] = 'Commuta les opcions avançades';
$labels['focusonnewmessage'] = 'Activa la finestra del navegador quan hi hagi un nou missatge';
$labels['checkallfolders'] = 'Comprova totes les carpetes per missatges nous';
$labels['displaynext'] = 'Mostra el missatge següent després de suprimir-ne o moure\'n un';
$labels['defaultfont'] = 'Font de lletra per defecte de missatge en HTML';
$labels['mainoptions'] = 'Opcions principals';
$labels['browseroptions'] = 'Opcions del navegador';
$labels['section'] = 'Secció';
$labels['maintenance'] = 'Manteniment';
$labels['newmessage'] = 'Missatge nou';
$labels['signatureoptions'] = 'Opcions de signatura';
$labels['whenreplying'] = 'Quan es respongui';
$labels['replyempty'] = 'no citis el missatge original';
$labels['replytopposting'] = 'comença el missatge nou per sobre de l\'original';
$labels['replybottomposting'] = 'comença el missatge nou per sota de l\'original';
$labels['replyremovesignature'] = 'Quan es respongui suprimeix la signatura original del missatge';
$labels['autoaddsignature'] = 'Afegeix la signatura automàticament';
$labels['newmessageonly'] = 'només si és un missatge nou';
$labels['replyandforwardonly'] = 'només a respostes i reenviaments';
$labels['insertsignature'] = 'Inclou la signatura';
$labels['sigbelow'] = 'Posa la signatura a sota del missatge que es respon';
$labels['sigseparator'] = 'Força el separador estàndard de signatures';
$labels['afternseconds']  = 'després de $n segons';
$labels['reqmdn'] = 'Demana sempre la confirmació de recepció';
$labels['reqdsn'] = 'Demana sempre una notificació d\'estat de lliurament';
$labels['replysamefolder'] = 'Posa les respostes a la carpeta del missatge que es respon';
$labels['defaultabook'] = 'Llibreta d\'adreces per defecte';
$labels['autocompletesingle'] = 'Omet adreces alternatives quan s\'autocompleti';
$labels['listnamedisplay'] = 'Llista contactes com a';
$labels['spellcheckbeforesend'] = 'Comprova l\'ortografia abans d\'enviar un missatge';
$labels['spellcheckoptions'] = 'Opcions del corrector ortogràfic';
$labels['spellcheckignoresyms'] = 'Ignora paraules amb símbols';
$labels['spellcheckignorenums'] = 'Ignora paraules amb números';
$labels['spellcheckignorecaps'] = 'Ignora paraules amb lletres capitalitzades';
$labels['addtodict'] = 'Afegeix al diccionari';
$labels['mailtoprotohandler'] = 'Registra controlador de protocol pels enllaços mailto:';
$labels['standardwindows'] = 'Gestiona les finestres emergents com si fossin finestres normals';
$labels['forwardmode'] = 'Reenviament de missatges';
$labels['inline'] = 'en línia';
$labels['asattachment'] = 'com un adjunt';
$labels['replyallmode'] = 'Acció per defecte del botó [Respon a tots]';
$labels['replyalldefault'] = 'respon a tots';
$labels['replyalllist'] = 'respon només a la llista de missatges (si n\'hi ha cap)';
$labels['folder'] = 'Carpeta';
$labels['folders'] = 'Carpetes';
$labels['foldername'] = 'Nom de la carpeta';
$labels['subscribed'] = 'Subscrit';
$labels['messagecount'] = 'Missatges';
$labels['create'] = 'Crea';
$labels['createfolder'] = 'Crea una carpeta nova';
$labels['managefolders'] = 'Gestiona carpetes';
$labels['specialfolders'] = 'Carpetes especials';
$labels['properties'] = 'Propietats';
$labels['folderproperties'] = 'Propietats de la carpeta';
$labels['parentfolder'] = 'Carpeta superior';
$labels['location'] = 'Ubicació';
$labels['info'] = 'Informació';
$labels['getfoldersize'] = 'Feu clic per veure la mida de la carpeta';
$labels['changesubscription'] = 'Feu clic per canviar la subscripció';
$labels['foldertype'] = 'Tipus de Carpeta';
$labels['personalfolder'] = 'Carpeta privada';
$labels['otherfolder'] = 'Carpeta d\'un altre usuari';
$labels['sharedfolder'] = 'Carpeta pública';
$labels['findfolders'] = 'Cerca carpetes';
$labels['namespace.personal'] = 'Personal';
$labels['namespace.other'] = 'Altres usuaris';
$labels['namespace.shared'] = 'Compartit';
$labels['sortby'] = 'Ordena per';
$labels['sortasc']  = 'Ordena ascendentment';
$labels['sortdesc'] = 'Ordena descendentment';
$labels['undo'] = 'Desfés';
$labels['installedplugins'] = 'Complements Instal·lats';
$labels['plugin'] = 'Complement';
$labels['version'] = 'Versió';
$labels['source'] = 'Font';
$labels['license'] = 'Llicència';
$labels['support'] = 'Obtingueu ajuda';
$labels['B'] = 'B';
$labels['KB'] = 'KB';
$labels['MB'] = 'MB';
$labels['GB'] = 'GB';
$labels['unicode'] = 'Unicode';
$labels['english'] = 'Anglès';
$labels['westerneuropean'] = 'Europeu occidental';
$labels['easterneuropean'] = 'Europeu oriental';
$labels['southeasterneuropean'] = 'Europeu Sud-Oriental';
$labels['baltic'] = 'Bàltic';
$labels['cyrillic'] = 'Ciríl·lic';
$labels['arabic'] = 'Àrab';
$labels['greek'] = 'Grec';
$labels['hebrew'] = 'Hebreu';
$labels['turkish'] = 'Turc';
$labels['nordic'] = 'Nòrdic';
$labels['thai'] = 'Tailandès';
$labels['celtic'] = 'Cèltic';
$labels['vietnamese'] = 'Vietnamita';
$labels['japanese'] = 'Japonès';
$labels['korean'] = 'Coreà';
$labels['chinese'] = 'Xinès';
$labels['arialabeltopnav'] = 'Finestra de control';
$labels['arialabeltasknav'] = 'Aplicació de tasques';
$labels['arialabeltoolbar'] = 'Aplicació de barra d\'eines';
$labels['arialabelactivetask'] = 'Tasca activa';
$labels['arialabelmessagessearchfilter'] = 'Filtre de llistat de correus electrònics';
$labels['arialabelmailsearchform'] = 'Formulari de cerca de correus electrònics';
$labels['arialabelcontactsearchform'] = 'Formulari de cerca de contactes';
$labels['arialabelmailquicksearchbox'] = 'Entrada per la cerca de correus electrònics';
$labels['arialabelquicksearchbox'] = 'Entrada de cerca';
$labels['arialabelfoldersearchfilter'] = 'Filtre de llistat de carpetes';
$labels['arialabelfoldersearchform'] = 'Formulari de cerca de carpetes';
$labels['arialabelfolderlist'] = 'Selecció de carpeta de correu electrònic';
$labels['arialabelmessagelist'] = 'Llistat de missatges de correu electrònic';
$labels['arialabelmailpreviewframe'] = 'Previsualitza el missatge';
$labels['arialabelmailboxmenu'] = 'Menú d\'accions de carpeta';
$labels['arialabellistselectmenu'] = 'Menú de seleccions de la llista';
$labels['arialabelthreadselectmenu'] = 'Menú de llistat de fils';
$labels['arialabelmessagelistoptions'] = 'Opcions de visualització de llista de missatges i ordenació';
$labels['arialabelmailimportdialog'] = 'Diàleg per importar missatges';
$labels['arialabelmessagenav'] = 'Missatge de navegació';
$labels['arialabelmessagebody'] = 'Cos del missatge';
$labels['arialabelmessageactions'] = 'Accions del missatge';
$labels['arialabelcontactquicksearch'] = 'Formulari per la cerca de contactes';
$labels['arialabelcontactsearchbox'] = 'Entrada per la cerca de contactes';
$labels['arialabelmessageheaders'] = 'Capçaleres del missatge';
$labels['arialabelforwardingoptions'] = 'Opcions de re-enviament';
$labels['arialabelreplyalloptions'] = 'Opcions per respondre a tots';
$labels['arialabelmoremessageactions'] = 'Més accions de missatge';
$labels['arialabelmarkmessagesas'] = 'Marca els missatges seleccionats com a...';
$labels['arialabelcomposeoptions'] = 'Opcions de composició';
$labels['arialabelresponsesmenu'] = 'Menú de respostes \'enllaunades\' o establertes';
$labels['arialabelattachmentuploadform'] = 'Formulari per pujar adjunts';
$labels['arialabelattachmentpreview'] = 'Previsualitza l\'ajunt';
$labels['ariasummarycomposecontacts'] = 'Llista de contactes i grups per seleccionar com a destinataris';
$labels['arialabelcontactexportoptions'] = 'Opcions per exportar contactes';
$labels['arialabelabookgroupoptions'] = 'Opcions de llibreta d\'adreces/grup';
$labels['arialabelpreferencesform'] = 'Formulari de preferències';
$labels['arialabelidentityeditfrom'] = 'Formulari d\'edició d\'identitats';
$labels['arialabelresonseeditfrom'] = 'Formulari d\'edició de respostes';
$labels['arialabelsearchterms'] = 'Cerca termes';
$labels['helplistnavigation'] = 'Llista la navegació per teclat';
$labels['helplistkeyboardnavigation'] = "Fletxes amunt/avall: Mou la fila seleccionada/activa.
Espai: Selecciona la fila activa.
Majús + amunt/avall: Selecciona una fila addicional de sobre/sota.
Ctrl + Espai: Afegeix la fila activa a la selecció/Suprimeix de la selecció.";
$labels['helplistkeyboardnavmessages'] = "Fletxes dreta/esquerra: expandeix/contrau fils del missatge (només en mode fils).
Retorn: Obre el missatge seleccionat/actiu.
Suprimeix: Mou els missatges seleccionats a la Paperera.";
$labels['helplistkeyboardnavcontacts'] = "Retorn: Obre el contacte seleccionat/actiu";
?>
