<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Transitional//EN" "http://www.w3.org/TR/xhtml1/DTD/xhtml1-transitional.dtd">
<html xmlns="http://www.w3.org/1999/xhtml">
<head>
<title><roundcube:object name="pagetitle" /></title>
<roundcube:include file="/includes/links.html" />
</head>
<body>

<roundcube:include file="/includes/taskbar.html" />
<roundcube:include file="/includes/header.html" />

<div id="mainscreen" class="box darkbg">
<div class="boxtitle"><roundcube:label name="importcontacts" /></div>

<div class="boxcontent">
<roundcube:object name="importstep" />

<p><br />
<roundcube:object name="importnav" class="button" />
</p>

</div>
</div>

</body>
</html>
