
p.vcardattachment {
	margin: 0.5em 1em;
	width: auto;
	background: #f9f9f9;
	border: 1px solid #d3d3d3;
	border-radius: 4px;
}

p.vcardattachment a {
	display: block;
	background: url(vcard_add_contact.png) 6px 2px no-repeat;
	padding: 1.2em 0.5em 0.7em 46px;
}

a.listbutton.vcard .inner
{
	background-position: center -2107px;
}
