<?php

/*
 +-----------------------------------------------------------------------+
 | localization/<lang>/labels.inc                                        |
 |                                                                       |
 | Localization file of the Roundcube Webmail client                     |
 | Copyright (C) 2005-2015, The Roundcube Dev Team                       |
 |                                                                       |
 | Licensed under the GNU General Public License version 3 or            |
 | any later version with exceptions for skins & plugins.                |
 | See the README file for a full license statement.                     |
 |                                                                       |
 +-----------------------------------------------------------------------+

 For translation see https://www.transifex.com/projects/p/roundcube-webmail/resource/labels/
*/
$labels['welcome']   = 'به $product خوش آمدید';
$labels['username']  = 'نام‌کاربری';
$labels['password']  = 'گذرواژه';
$labels['server']    = 'سرور';
$labels['login']     = 'ورود';
$labels['menu']     = 'فهرست';
$labels['logout']   = 'خروج';
$labels['mail']     = 'پست';
$labels['settings'] = 'تنظیمات';
$labels['addressbook'] = 'دفتر نشانی';
$labels['inbox']  = 'صندوق ورودی';
$labels['drafts'] = 'پیش‌نویس‌ها';
$labels['sent']   = 'ارسال شده';
$labels['trash']  = 'زباله‌دان';
$labels['junk']   = 'بنجل';
$labels['show_real_foldernames'] = 'نمایش نام واقعی برای پوشه‌های ویژه';
$labels['subject'] = 'موضوع';
$labels['from']    = 'از';
$labels['sender']  = 'فرستنده';
$labels['to']      = 'به';
$labels['cc']      = 'رونوشت';
$labels['bcc']     = 'رونوشت مخفی';
$labels['replyto'] = 'پاسخ-به';
$labels['followupto'] = 'پیگیری-در';
$labels['date']    = 'تاریخ';
$labels['size']    = 'اندازه';
$labels['priority'] = 'اولویت';
$labels['organization'] = 'سازمان';
$labels['readstatus'] = 'وضعیت خوانده شدن';
$labels['listoptions'] = 'فهرست گزینه‌ها...';
$labels['listoptionstitle'] = 'گزینه‌های لیست';
$labels['mailboxlist'] = 'پوشه‌ها';
$labels['messagesfromto'] = 'پیغام‌های $from تا $to از $count';
$labels['threadsfromto'] = 'رشته‌های $from تا $to از $count';
$labels['messagenrof'] = 'پیغام $nr از $count';
$labels['fromtoshort'] = '$from - $to از $count';
$labels['copy']     = 'رونوشت';
$labels['move']     = 'انتقال';
$labels['moveto']   = 'انتقال به...';
$labels['copyto']   = 'رونوشت به...';
$labels['download'] = 'بارگیری';
$labels['open']     = 'باز کردن';
$labels['showattachment'] = 'نمایش';
$labels['showanyway'] = 'نمایش آن در هر صورت';
$labels['filename'] = 'نام پرونده';
$labels['filesize'] = 'اندازه پرونده';
$labels['addtoaddressbook'] = 'افزودن به دفتر نشانی‌ها';
$labels['sun'] = 'یک‌شنبه';
$labels['mon'] = 'دوش';
$labels['tue'] = 'سه‌شنبه';
$labels['wed'] = 'چهارشنبه';
$labels['thu'] = 'پنج‌شنبه';
$labels['fri'] = 'جمعه';
$labels['sat'] = 'شنبه';
$labels['sunday']    = 'یک‌شنبه';
$labels['monday']    = 'دوشنبه';
$labels['tuesday']   = 'سه‌شنبه';
$labels['wednesday'] = 'چهارشنبه';
$labels['thursday']  = 'پنج‌شنبه';
$labels['friday']    = 'جمعه';
$labels['saturday']  = 'شنبه';
$labels['jan']	= 'ژان';
$labels['feb']	= 'فور';
$labels['mar']	= 'مار';
$labels['apr']	= 'آور';
$labels['may']	= 'مه';
$labels['jun']	= 'ژون';
$labels['jul'] 	= 'ژوی';
$labels['aug']	= 'اوت';
$labels['sep']	= 'سپت';
$labels['oct']	= 'اُکت';
$labels['nov']	= 'نوا';
$labels['dec']	= 'دسا';
$labels['longjan']	= 'ژانویه';
$labels['longfeb']	= 'فوریه';
$labels['longmar']	= 'مارس';
$labels['longapr']	= 'آوریل';
$labels['longmay']	= 'می';
$labels['longjun']	= 'ژوئن';
$labels['longjul']	= 'جولای';
$labels['longaug']	= 'آگوست';
$labels['longsep']	= 'سپتامبر';
$labels['longoct']	= 'اکتبر';
$labels['longnov']	= 'نوامبر';
$labels['longdec']	= 'دسامبر';
$labels['today'] = 'امروز';
$labels['refresh']          = 'نوسازی';
$labels['checkmail']        = 'بررسی برای پیام‌های جدید';
$labels['compose']          = 'نوشتن پیام';
$labels['writenewmessage']  = 'ایجاد پیام جدید';
$labels['reply']            = 'پاسخ';
$labels['replytomessage']   = 'پاسخ به فرستنده';
$labels['replytoallmessage'] = 'پاسخ به فهرست یا به فرستنده و تمام گیرنده‌ها';
$labels['replyall']         = 'پاسخ به همه';
$labels['replylist']        = 'پاسخ به فهرست';
$labels['forward']          = 'ارجاع';
$labels['forwardinline']    = 'ارجاع خطی';
$labels['forwardattachment'] = 'ارجاع به صورت پیوست';
$labels['forwardmessage']   = 'ارجاع پیام';
$labels['deletemessage']    = 'حذف پیغام';
$labels['movemessagetotrash'] = 'انتقال پیغام به زباله‌دان';
$labels['printmessage']     = 'چاپ این پیغام';
$labels['previousmessage']  = 'نمایش پیغام قبلی';
$labels['firstmessage']     = 'نمایش پیغام اول';
$labels['nextmessage']      = 'نمایش پیغام بعدی';
$labels['lastmessage']      = 'نمایش پیغام آخر';
$labels['backtolist']       = 'بازگشت به فهرست پیغام';
$labels['viewsource']       = 'نمایش منبع';
$labels['mark']             = 'نشانه‌گذاری';
$labels['markmessages']     = 'نشانه‌گذاری پیغام‌ها';
$labels['markread']         = 'به عنوان خوانده‌شده';
$labels['markunread']       = 'به عنوان خوانده‌نشده';
$labels['markflagged']      = 'به عنوان پرچم‌دار';
$labels['markunflagged']    = 'به عنوان بدون پرچم';
$labels['moreactions']      = 'کارهای دیگر...';
$labels['folders-all']      = 'همه پوشه‌ها';
$labels['more']             = 'بيشتر';
$labels['back']             = 'بازگشت';
$labels['options']          = 'گزینه‌ها';
$labels['first'] = 'اول';
$labels['last'] = 'آخر';
$labels['previous'] = 'قبل';
$labels['next'] = 'بعد';
$labels['select'] = 'انتخاب';
$labels['all'] = 'همه';
$labels['none'] = 'هیچ‌کدام';
$labels['currpage'] = 'صفحه جاری';
$labels['isread'] = 'خوانده شده';
$labels['unread'] = 'خوانده‌نشده';
$labels['flagged'] = 'پرچم‌دار';
$labels['unflagged'] = 'بدون پرچم';
$labels['unanswered'] = 'پاسخ داده نشده';
$labels['withattachment'] = 'با پیوست';
$labels['deleted'] = 'حذف شده';
$labels['undeleted'] = 'حذف نشده';
$labels['replied'] = 'پاسخ داده شده';
$labels['forwarded'] = 'ارجاع داده شده';
$labels['invert'] = 'وارونه';
$labels['filter'] = 'صافی';
$labels['list'] = 'فهرست';
$labels['threads'] = 'رشته‌ها';
$labels['expand-all'] = 'باز کردن همه';
$labels['expand-unread'] = 'بازکردن خوانده نشده‌ها';
$labels['collapse-all'] = 'جمع کردن همه';
$labels['threaded'] = 'رشته شده';
$labels['autoexpand_threads'] = 'باز کردن رشته‌های پیام';
$labels['do_expand'] = 'همه رشته‌ها';
$labels['expand_only_unread'] = 'فقط با پیام‌های خوانده نشده';
$labels['fromto'] = 'از/به';
$labels['flag'] = 'پرچم';
$labels['attachment'] = 'پیوست';
$labels['nonesort'] = 'هیچ‌کدام';
$labels['sentdate'] = 'تاریخ ارسال';
$labels['arrival'] = 'تاریخ ورود';
$labels['asc'] = 'صعودی';
$labels['desc'] = 'نزولی';
$labels['listcolumns'] = 'ستون‌های فهرست';
$labels['listsorting'] = 'ستون مرتب‌سازی';
$labels['listorder'] = 'ترتیب مرتب‌سازی';
$labels['listmode'] = 'نوع مشاهده فهرست';
$labels['layout'] = 'چیدمان';
$labels['layoutwidescreen'] = 'عریض';
$labels['layoutdesktop'] = 'رومیزی';
$labels['layoutlist'] = 'لیست';
$labels['folderactions'] = 'اعمال پوشه...';
$labels['compact'] = 'فشرده';
$labels['empty'] = 'خالی';
$labels['importmessages'] = 'وارد کردن پیام‌ها';
$labels['quota'] = 'فضای استفاده شده';
$labels['unknown']  = 'ناشناخته';
$labels['unlimited']  = 'نامحدود';
$labels['quotatype'] = 'نوع سهمیه';
$labels['quotatotal'] = 'محدود کردن';
$labels['quotaused'] = 'استفاده شده';
$labels['quotastorage'] = 'فضای دیسک';
$labels['quotamessage'] = 'تعداد پیغام‌ها';
$labels['quicksearch']  = 'جستجوی سریع';
$labels['searchplaceholder']  = 'جستجو...';
$labels['resetsearch']  = 'جستجوی دوباره';
$labels['searchmod']  = 'اصلاحات جستجو';
$labels['msgtext']  = 'کل پیام';
$labels['body']  = 'بدنه';
$labels['type'] = 'نوع';
$labels['namex'] = 'نام';
$labels['searchscope'] = 'حوزه';
$labels['currentfolder'] = 'پوشه جاری';
$labels['allfolders'] = 'همه پوشه‌ها';
$labels['openinextwin'] = 'باز کردن در پنجره‌ی جدید';
$labels['emlsave'] = 'بارگیری (.eml)';
$labels['changeformattext'] = 'نمایش در قالب متنی';
$labels['changeformathtml'] = 'نمایش در قالب اچ‌تی‌ام‌ال';
$labels['editasnew']      = 'ویرایش به عنوان جدید';
$labels['send']           = 'ارسال';
$labels['sendmessage']    = 'ارسال پیغام';
$labels['savemessage']    = 'ذخیره پیش‌نویس';
$labels['addattachment']  = 'پیوست کردن یک پرونده';
$labels['charset']        = 'مجموعه‌نمایه';
$labels['editortype']     = 'نوع ویرایش‌گر';
$labels['returnreceipt']  = 'رسید دریافت';
$labels['dsn']            = 'اعلام وضعیت دریافت';
$labels['mailreplyintro'] = 'در $date، $sender نوشته است:';
$labels['originalmessage'] = 'پیام اصلی';
$labels['selectimage']    = 'انتخاب تصویر';
$labels['addimage']       = 'افزودن تصویر';
$labels['addmedia']       = 'افزودن رسانه';
$labels['encrypt']        = 'رمزگذاری';
$labels['encryptmessage'] = 'رمزگذاری پیغام';
$labels['keyid']          = 'کلید شناسه';
$labels['keyexpired']     = 'منقضی شده';
$labels['editidents']    = 'ویرایش شناسه‌ها';
$labels['spellcheck']    = 'املاء';
$labels['checkspelling'] = 'بررسی املایی';
$labels['resumeediting'] = 'ادامه‌ی ویرایش';
$labels['revertto']      = 'برگرداندن به';
$labels['restore'] = 'بازیابی';
$labels['restoremessage'] = 'بازیابی پیام؟';
$labels['ignore'] = 'نادیده گرفتن';
$labels['responses'] = 'پاسخ‌ها';
$labels['insertresponse'] = 'درج پاسخ';
$labels['manageresponses'] = 'مدیریت پاسخ‌ها';
$labels['addresponse'] = 'افزودن پاسخ';
$labels['editresponse'] = 'ویرایش پاسخ';
$labels['editresponses'] = 'ویرایش پاسخ‌ها';
$labels['responsename'] = 'نام';
$labels['responsetext'] = 'متن پاسخ';
$labels['attach'] = 'پیوست کردن';
$labels['attachments'] = 'پیوست‌ها';
$labels['upload'] = 'بارگذاری';
$labels['uploadprogress'] = '$percent ($current از $total)';
$labels['close']  = 'بستن';
$labels['messageoptions']  = 'گزینه‌های پیام...';
$labels['low']     = 'کم';
$labels['lowest']  = 'کم‌ترین';
$labels['normal']  = 'معمولی';
$labels['high']    = 'زیاد';
$labels['highest'] = 'بیش‌ترین';
$labels['nosubject']  = '(بدون موضوع)';
$labels['showimages'] = 'نمایش عکس‌ها';
$labels['alwaysshow'] = 'همیشه عکس‌های دریافتی از $sender را نمایش داده شود';
$labels['isdraft']    = 'این یک پیغام پیش‌نویس است.';
$labels['andnmore']   = '$nr بیشتر...';
$labels['togglemoreheaders'] = 'نمایش سربرگ‌های بیشتر پیام';
$labels['togglefullheaders'] = 'تعویض سربرگ‌های پیام خام';
$labels['htmltoggle'] = 'HTML';
$labels['plaintoggle'] = 'متن ساده';
$labels['savesentmessagein'] = 'ذخیره پیام ارسالی در';
$labels['dontsave'] = 'ذخیره نکن';
$labels['maxuploadsize'] = 'حجم پرونده حداکثر تا میزان $size می‌باشد';
$labels['addcc'] = 'افزودن رونوشت';
$labels['addbcc'] = 'افزودن رونوشت مخفی';
$labels['addreplyto'] = 'افزودن پاسخ-به';
$labels['addfollowupto'] = 'افزودن پیگیری-به';
$labels['mdnrequest'] = 'فرستنده‌ی این پیام خواسته است که وقتی شما این پیام را می‌خوانید، آگاه شود. آیا مایلید فرستنده را آگاه سازید؟';
$labels['receiptread'] = 'رسید دریافت (خواندن)';
$labels['yourmessage'] = 'این یک رسید دریافت برای پیام شماست';
$labels['receiptnote'] = 'تذکر: این رسید فقط تصدیق می‌کند که پیام، روی رایانه گیرنده نمایش داده شده است. هیچ تضمینی نیست که گیرنده، محتوای پیام را خوانده یا فهمیده باشد.';
$labels['name']         = 'نمایش نام';
$labels['firstname']    = 'نام';
$labels['surname']      = 'نام خانوادگی';
$labels['middlename']   = 'نام وسط';
$labels['nameprefix']   = 'پیشوند';
$labels['namesuffix']   = 'پسوند';
$labels['nickname']     = 'نام مستعار';
$labels['jobtitle']     = 'عنوان شغل';
$labels['department']   = 'بخش';
$labels['gender']       = 'جنسیت';
$labels['maidenname']   = 'نام خانوادگی زن قبل از ازدواج';
$labels['email']        = 'پست‌الکترونیک';
$labels['phone']        = 'تلفن';
$labels['address']      = 'نشانی';
$labels['street']       = 'خیابان';
$labels['locality']     = 'شهر';
$labels['zipcode']      = 'کدپستی';
$labels['region']       = 'ایالت/استان';
$labels['country']      = 'کشور';
$labels['birthday']     = 'زادروز';
$labels['anniversary']  = 'سالگرد';
$labels['website']      = 'وب‌سایت';
$labels['instantmessenger'] = 'پیام‌رسان';
$labels['notes'] = 'یادداشت‌ها';
$labels['male']   = 'مرد';
$labels['female'] = 'زن';
$labels['manager'] = 'مدیر';
$labels['assistant'] = 'دستیار';
$labels['spouse'] = 'همسر';
$labels['allfields'] = 'همه زمینه‌ها';
$labels['search'] = 'جستجو';
$labels['searchresult'] = 'نتیجه جستجو';
$labels['advsearch'] = 'جستجوی پیشرفته';
$labels['advanced'] = 'پیشرفته';
$labels['other'] = 'سایر';
$labels['qrcode'] = 'کد کیوآر';
$labels['typehome']   = 'خانه';
$labels['typework']   = 'کار';
$labels['typeother']  = 'سایر';
$labels['typemobile']  = 'تلفن همراه';
$labels['typemain']  = 'اصلی';
$labels['typehomefax']  = 'فاکس خانگی';
$labels['typeworkfax']  = 'فاکس کاری';
$labels['typecar']  = 'اتومبیل';
$labels['typepager']  = 'پیجر';
$labels['typevideo']  = 'ویدئو';
$labels['typeassistant']  = 'دستیار';
$labels['typehomepage']  = 'صفحه خانگی';
$labels['typeblog'] = 'بلاگ';
$labels['typeprofile'] = 'نمایه';
$labels['addfield'] = 'افزودن زمینه...';
$labels['addcontact'] = 'افزودن تماس';
$labels['editcontact'] = 'ویرایش تماس';
$labels['contacts'] = 'تماس‌ها';
$labels['contactproperties'] = 'خصوصیات تماس';
$labels['personalinfo'] = 'اطلاعات شخصی';
$labels['personal'] = 'شخصی';
$labels['contactphoto'] = 'تصویر تماس';
$labels['edit']   = 'ویرایش';
$labels['cancel'] = 'لغو';
$labels['save']   = 'ذخیره';
$labels['delete'] = 'حذف';
$labels['discard'] = 'دور انداختن';
$labels['rename'] = 'تغییر نام';
$labels['addphoto'] = 'افزودن';
$labels['replacephoto'] = 'جایگزینی';
$labels['uploadphoto'] = 'بارگذاری تصویر';
$labels['deletecontact']  = 'حذف تماس‌های انتخاب شده';
$labels['composeto']      = 'نوشتن پست به';
$labels['contactsfromto'] = 'تماس‌های $from تا $to از $count';
$labels['print']          = 'چاپ';
$labels['export']         = 'صدور';
$labels['exportall']      = 'خارج کردن همه';
$labels['exportsel']      = 'خارج کردن انتخاب شده‌ها';
$labels['exportvcards']   = 'صدور اطلاعات تماس‌ها با فرمت vCard';
$labels['newgroup']       = 'ایجاد گروه جدید';
$labels['addgroup']       = 'افزودن گروه';
$labels['grouprename']    = 'تغییر نام گروه';
$labels['groupdelete']    = 'حذف گروه';
$labels['groupremoveselected'] = 'حذف نشانی‌های انتخاب شده از گروه';
$labels['previouspage']   = 'نمایش صفحه قبلی';
$labels['firstpage']      = 'نمایش صفحه اول';
$labels['nextpage']       = 'نمایش صفحه بعدی';
$labels['lastpage']       = 'نمایش صفحه آخر';
$labels['group'] = 'گروه';
$labels['groups'] = 'گروه‌ها';
$labels['listgroup'] = 'فهرست اعضاء گروه';
$labels['personaladrbook'] = 'نشانی‌های شخصی';
$labels['searchsave'] = 'ذخیره جستجو';
$labels['searchdelete'] = 'حذف جستجو';
$labels['import'] = 'وارد کردن';
$labels['importcontacts'] = 'وارد کردن تماس‌ها';
$labels['importfromfile'] = 'وارد کردن از پرونده‌ی:';
$labels['importtarget'] = 'افزودن تماس‌ها به';
$labels['importreplace'] = 'جایگیزینی کامل دفتر نشانی';
$labels['importgroups'] = 'وارد کردن وظایف گروه';
$labels['importgroupsall'] = 'همه (ایجاد گروه‌ها در صورت نیاز)';
$labels['importgroupsexisting'] = 'فقط برای گروه‌های موجود';
$labels['importdesc'] = 'شما می‌توانید تماس‌ها را از یک دفتر نشانی موجود بارگذاری نمایید.<br/> هم اکنون ما وارد کردن نشانی‌ها را از <a href="http://en.wikipedia.org/wiki/VCard">vCard</a> یا قالب داده CVS (جدا شده با کاما) پشتیبانی می‌کنیم.';
$labels['done'] = 'انجام شد';
$labels['settingsfor'] = 'تنظیمات برای';
$labels['about'] = 'درباره';
$labels['preferences'] = 'ترجیحات';
$labels['userpreferences'] = 'ترجیحات کاربر';
$labels['editpreferences'] = 'ویرایش ترجیحات کاربر';
$labels['identities'] = 'شناسه‌ها';
$labels['addidentity'] = 'افزودن هویت';
$labels['editidentity'] = 'ویرایش شناسه';
$labels['preferhtml'] = 'HTML نمایش';
$labels['defaultcharset'] = 'مجموعه نمایه پیش‌فرض';
$labels['htmlmessage'] = 'پیغام HTML';
$labels['messagepart'] = 'قسمت';
$labels['digitalsig'] = 'امضای دیجیتال';
$labels['dateformat'] = 'قالب تاریخ';
$labels['timeformat'] = 'قالب زمان';
$labels['prettydate'] = 'تاریخ‌های زیبا';
$labels['setdefault']  = 'پیش‌فرض کن';
$labels['autodetect']  = 'خودکار';
$labels['language']  = 'زبان';
$labels['timezone']  = 'محدوده‌ی زمانی';
$labels['pagesize']  = 'سطر در صفحه';
$labels['signature'] = 'امضاء';
$labels['dstactive']  = 'ساعت تابستانی';
$labels['showinextwin'] = 'نمایش پیام در پنجره جدید';
$labels['composeextwin'] = 'نوشتن پیام  در پنجره جدید';
$labels['htmleditor'] = 'نوشتن پیام‌های HTML';
$labels['htmlonreply'] = 'فقط در پاسخ به پیام HTML';
$labels['htmlonreplyandforward'] = 'در بازگردانی یا پاسخ به پیام‌های HTML';
$labels['htmlsignature'] = 'امضای HTML';
$labels['showemail'] = 'نمایش نشانی رایانامه با نام نمایشی';
$labels['previewpane'] = 'نمایش قاب پیش‌نمایش';
$labels['skin'] = 'پوسته ظاهری';
$labels['logoutclear'] = 'تمیز کردن زباله دان هنگام برون‌رفت';
$labels['logoutcompact'] = 'فشرده‌سازی صندوق در هنگام خروچ';
$labels['uisettings'] = 'محیط کاربری';
$labels['serversettings'] = 'تنظیمات سرور';
$labels['mailboxview'] = 'نمای صندوق پستی';
$labels['mdnrequests'] = 'تاییدهای فرستنده';
$labels['askuser'] = 'پرسش از کاربر';
$labels['autosend'] = 'ارسال رسید';
$labels['autosendknown'] = 'ارسال رسید به تماس‌های من، در غیر این صورت سوال کن';
$labels['autosendknownignore'] = 'ارسال رسید به تماس‌های من، درغیر این صورت چشم‌پوشی کن';
$labels['readwhendeleted'] = 'در هنگام پاک کردن، پیام را به عنوان خوانده شده علامت بزن';
$labels['flagfordeletion'] = 'پیام را به جای پاک کردن، با پرچم نشانه‌گذاری کن';
$labels['skipdeleted'] = 'پیام‌های حذف شده را نمایش نده';
$labels['deletealways'] = 'اگر انتقال پیام به زباله‌دان ناموفق بود، آن‌ها را حذف کن';
$labels['deletejunk'] = 'حذف مستقیم پیام‌های زباله';
$labels['showremoteimages'] = 'تصاویر پیوند شده را نمایش بده';
$labels['fromknownsenders'] = 'از فرستنده شناس';
$labels['always'] = 'همواره';
$labels['showinlineimages'] = 'نمایش عکس‌های پیوست شده در پایین پیام';
$labels['autosavedraft']  = 'ذخیره‌ی خودکار پیش‌نویس';
$labels['everynminutes']  = 'در هر $n دقیقه';
$labels['refreshinterval']  = 'تازه کردن (بررسی برای پیام‌های جدید، مثلا)';
$labels['never']  = 'هرگز';
$labels['immediately']  = 'بلافاصله';
$labels['messagesdisplaying'] = 'نمای پیام‌ها';
$labels['messagescomposition'] = 'نوشتن پیام‌ها';
$labels['mimeparamfolding'] = 'عناوین پیوستی';
$labels['2231folding'] = 'Full RFC 2231 (Thunderbird)';
$labels['miscfolding'] = 'RFC 2047/2231 (MS Outlook)';
$labels['2047folding'] = 'Full RFC 2047 (سایر)';
$labels['force7bit'] = 'از MIME encoding برای کارکترهای ۸-بیتی استفاده کن';
$labels['advancedoptions'] = 'گزینه‌های پیشرفته';
$labels['focusonnewmessage'] = 'مشخص نمودن پیام جدید';
$labels['checkallfolders'] = 'همه پوشه‌ها را برای مشاهده پیام‌های جدید بررسی کن';
$labels['displaynext'] = 'بعد از انتقال/حذف پیام، پیام بعدی نمایش داده شود';
$labels['defaultfont'] = 'فونت پیش فرض برای پیام HTML';
$labels['mainoptions'] = 'گزینه‌های اصلی';
$labels['browseroptions'] = 'گزینه‌‌های مرورگر';
$labels['section'] = 'بخش';
$labels['maintenance'] = 'نگهداشت';
$labels['newmessage'] = 'پیام جدید';
$labels['signatureoptions'] = 'گزینه‌های امضاء';
$labels['whenreplying'] = 'هنگام پاسخ';
$labels['replyempty'] = 'نقل قول نکردن پیام اصلی';
$labels['replytopposting'] = 'شروع پیام جدید بالای اصلی';
$labels['replybottomposting'] = 'شروع پیام جدید پایین اصلی';
$labels['replyremovesignature'] = 'هنگام پاسخ امضاء اصلی را از پیام پاک کن';
$labels['autoaddsignature'] = 'اضافه کردن خودکار امضاء';
$labels['newmessageonly'] = 'فقط پیام جدید';
$labels['replyandforwardonly'] = 'فقط پاسخ‌ها و ارجاع‌ها';
$labels['insertsignature'] = 'درج امضاء';
$labels['afternseconds']  = 'بعد از $s ثانیه';
$labels['reqmdn'] = 'درخواست همیشگی رسید برگشت';
$labels['reqdsn'] = 'درخواست همیشگی تذکر وضعیت تحویل';
$labels['replysamefolder'] = 'پاسخ‌ها را در پوشه‌ای پیام‌هایی که باید پاسخ داده شود گرفته بده.';
$labels['defaultabook'] = 'دفترچه نشانی پیش‌فرض';
$labels['autocompletesingle'] = 'رد کردن نشانی‌های رایانامه دیگر در تکمیل خودکار';
$labels['listnamedisplay'] = 'فهرست تماس‌ها به عنوان';
$labels['spellcheckbeforesend'] = 'بررسی املایی قبل از ارسال پیام';
$labels['spellcheckoptions'] = 'گزینه‌های بررسی املاء';
$labels['spellcheckignoresyms'] = 'نادیده گرفتن کلمات دارای نماد';
$labels['spellcheckignorenums'] = 'نادیده گرفتن کلمات دارای عدد';
$labels['spellcheckignorecaps'] = 'نادیده گرفتن کلمات با حروف بزرگ';
$labels['addtodict'] = 'اضافه کردن به واژه‌نامه';
$labels['mailtoprotohandler'] = 'ثبت نگه‌دارنده پروتوکل برای mailto: پیوندها';
$labels['standardwindows'] = 'بکار بردن پاپ‌آپ‌ها به صورت پنجره‌ی استاندارد';
$labels['forwardmode'] = 'بازگردانی پیام';
$labels['inline'] = 'خطی';
$labels['asattachment'] = 'به عنوان پیوست';
$labels['replyallmode'] = 'عمل پیش‌فرض برای دکمه [پاسخ به همه]';
$labels['replyalldefault'] = 'پاسخ به همه';
$labels['replyalllist'] = 'پاسخ به فقط لیست پستی (در صورت یافتن)';
$labels['folder'] = 'پوشه';
$labels['folders'] = 'پوشه‌ها';
$labels['foldername'] = 'نام پوشه';
$labels['subscribed'] = 'مشترک شد';
$labels['messagecount'] = 'پیام‌ها';
$labels['create'] = 'ایجاد';
$labels['createfolder'] = 'ایجاد پوشه‌ی جدید';
$labels['managefolders'] = 'مدیریت پوشه‌ها';
$labels['specialfolders'] = 'پوشه‌های ویژه';
$labels['properties'] = 'خصوصیات';
$labels['folderproperties'] = 'خصوصیات پوشه';
$labels['parentfolder'] = 'پوشه والد';
$labels['location'] = 'موقعیت';
$labels['info'] = 'اطلاعات';
$labels['getfoldersize'] = 'برای فهمیدن حجم پوشه کلیک کنید';
$labels['changesubscription'] = 'برای تغییر اشتراک کلیک کنید';
$labels['foldertype'] = 'نوع پوشه';
$labels['personalfolder'] = 'پوشه خصوصی';
$labels['otherfolder'] = 'پوشه کاربران دیگر';
$labels['sharedfolder'] = 'پوشه عمومی';
$labels['findfolders'] = 'پیدا کردن پوشه';
$labels['namespace.personal'] = 'شخصی';
$labels['dualusefolder'] = 'پوشه‌ها';
$labels['sortby'] = 'مرتب‌سازی بر اساس';
$labels['sortasc']  = 'مرتب‌سازی صعودی';
$labels['sortdesc'] = 'مرتب‌سازی نزولی';
$labels['undo'] = 'برگردان';
$labels['installedplugins'] = 'افزونه‌های نصب شده';
$labels['plugin'] = 'افزونه';
$labels['version'] = 'نسخه';
$labels['source'] = 'منبع';
$labels['license'] = 'گواهینامه';
$labels['support'] = 'پشتیبانی';
$labels['B'] = 'B';
$labels['KB'] = 'KB';
$labels['MB'] = 'MB';
$labels['GB'] = 'GB';
$labels['unicode'] = 'یونیکد';
$labels['english'] = 'انگلیسی';
$labels['westerneuropean'] = 'اروپای غربی';
$labels['easterneuropean'] = 'اروپای شرقی';
$labels['southeasterneuropean'] = 'اروپای جنوب شرقی';
$labels['baltic'] = 'بالتیک';
$labels['cyrillic'] = 'سیریلیک';
$labels['arabic'] = 'عربی';
$labels['greek'] = 'یونانی';
$labels['hebrew'] = 'عبری';
$labels['turkish'] = 'ترکی استانبولی';
$labels['nordic'] = 'شمالی';
$labels['thai'] = 'تایلندی';
$labels['celtic'] = 'سلتی';
$labels['vietnamese'] = 'ویتنامی';
$labels['japanese'] = 'ژاپنی';
$labels['korean'] = 'کره‌ای';
$labels['chinese'] = 'چینی';
$labels['arialabeltopnav'] = 'کنترل پنجره';
$labels['arialabelactivetask'] = 'وظیفه فعال';
$labels['arialabelmessagessearchfilter'] = 'پالایه فهرست‌گیری رایانامه';
$labels['arialabelmailsearchform'] = 'فرم جستجوی پیام رایانامه';
$labels['arialabelcontactsearchform'] = 'فرم جستجوی تماس‌ها';
$labels['arialabelmailquicksearchbox'] = 'ورودی جستجوی رایانامه';
$labels['arialabelquicksearchbox'] = 'وردوی جستجو';
$labels['arialabelfoldersearchfilter'] = 'پالایه فهرست‌گیری پوشه';
$labels['arialabelfoldersearchform'] = 'فرم جستجوی پوشه';
$labels['arialabelfolderlist'] = 'انتخاب پوشه رایانامه';
$labels['arialabelmessagelist'] = 'فهرست‌گیری پیام‌های رایانامه';
$labels['arialabelmailpreviewframe'] = 'پیش‌نمایش پیام';
$labels['arialabelmessagenav'] = 'ناوبری پیام';
$labels['arialabelmessagebody'] = 'بدنه پیام';
$labels['arialabelmessageactions'] = 'کنش‌های پیام';
$labels['arialabelcontactquicksearch'] = 'فرم جستجوی تماس‌ها';
$labels['arialabelcontactsearchbox'] = 'ورودی جستجوی تماس';
$labels['arialabelmessageheaders'] = 'سربرگ‌های پیام';
$labels['arialabelforwardingoptions'] = 'گزینه‌های بازگردانی';
$labels['arialabelreplyalloptions'] = 'گزینه‌های پاسخ به همه';
$labels['arialabelcomposeoptions'] = 'گزینه‌های انشاء';
$labels['arialabelattachmentuploadform'] = 'فرم بارگذاری پیوست';
$labels['arialabelattachmentpreview'] = 'پیش‌نمایش پیوست';
$labels['arialabelabookgroupoptions'] = 'گزینه‌های دفترنشانی/گروه';
$labels['arialabelpreferencesform'] = 'فرم تنظیمات';
$labels['arialabelidentityeditfrom'] = 'فرم ویرایش هویت';
$labels['arialabelresonseeditfrom'] = 'فرم ویرایش واکنش‌گرا';
$labels['arialabelsearchterms'] = 'شرایط جستجو';
?>
