<?php

/*
 +-----------------------------------------------------------------------+
 | localization/<lang>/labels.inc                                        |
 |                                                                       |
 | Localization file of the Roundcube Webmail client                     |
 | Copyright (C) 2005-2015, The Roundcube Dev Team                       |
 |                                                                       |
 | Licensed under the GNU General Public License version 3 or            |
 | any later version with exceptions for skins & plugins.                |
 | See the README file for a full license statement.                     |
 |                                                                       |
 +-----------------------------------------------------------------------+

 For translation see https://www.transifex.com/projects/p/roundcube-webmail/resource/labels/
*/
$labels['welcome']   = 'Bienvenido a $product';
$labels['username']  = 'Usuario';
$labels['password']  = 'Contraseña';
$labels['server']    = 'Servidor';
$labels['login']     = 'Ingresar';
$labels['logout']   = 'Salir';
$labels['mail']     = 'Correo';
$labels['settings'] = 'Configuraciones';
$labels['addressbook'] = 'Libreta de direcciones';
$labels['inbox']  = 'Bandeja de entrada';
$labels['drafts'] = 'Borradores';
$labels['sent']   = 'Enviados';
$labels['trash']  = 'Papelera';
$labels['junk']   = 'No deseado';
$labels['show_real_foldernames'] = 'Mostrar el nombre real para carpetas especiales';
$labels['subject'] = 'Asunto';
$labels['from']    = 'De';
$labels['sender']  = 'Remitente';
$labels['to']      = 'Para';
$labels['cc']      = 'Cc';
$labels['bcc']     = 'Bcc';
$labels['replyto'] = 'Responder a';
$labels['followupto'] = 'Seguir a';
$labels['date']    = 'Fecha';
$labels['size']    = 'Tamaño';
$labels['priority'] = 'Prioridad';
$labels['organization'] = 'Organización';
$labels['readstatus'] = 'Leído';
$labels['listoptions'] = 'Listar opciones...';
$labels['mailboxlist'] = 'Carpetas';
$labels['messagesfromto'] = 'Mensajes $from a $to de $count';
$labels['threadsfromto'] = 'Hilo $from a $to de $count';
$labels['messagenrof'] = 'Mensaje $nr de $count';
$labels['fromtoshort'] = '$from - $to de $count';
$labels['copy']     = 'Copiar';
$labels['move']     = 'Mover';
$labels['moveto']   = 'Mover a...';
$labels['copyto']   = 'Copiar a...';
$labels['download'] = 'Descargar';
$labels['open']     = 'Abrir';
$labels['showattachment'] = 'Mostrar';
$labels['showanyway'] = 'Mostrar de todos modos';
$labels['filename'] = 'Nombre del archivo';
$labels['filesize'] = 'Tamaño del archivo';
$labels['addtoaddressbook'] = 'Agregar a la libreta de direcciones';
$labels['sun'] = 'Dom';
$labels['mon'] = 'Lun';
$labels['tue'] = 'Mar';
$labels['wed'] = 'Mié';
$labels['thu'] = 'Jue';
$labels['fri'] = 'Vie';
$labels['sat'] = 'Sáb';
$labels['sunday']    = 'Domingo';
$labels['monday']    = 'Lunes';
$labels['tuesday']   = 'Martes';
$labels['wednesday'] = 'Miércoles';
$labels['thursday']  = 'Jueves';
$labels['friday']    = 'Viernes';
$labels['saturday']  = 'Sábado';
$labels['jan']	= 'Ene';
$labels['feb']	= 'Feb';
$labels['mar']	= 'Mar';
$labels['apr']	= 'Abr';
$labels['may']	= 'May';
$labels['jun']	= 'Jun';
$labels['jul'] 	= 'Jul';
$labels['aug']	= 'Ago';
$labels['sep']	= 'Set';
$labels['oct']	= 'Oct';
$labels['nov']	= 'Nov';
$labels['dec']	= 'Dic';
$labels['longjan']	= 'Enero';
$labels['longfeb']	= 'Febrero';
$labels['longmar']	= 'Marzo';
$labels['longapr']	= 'Abril';
$labels['longmay']	= 'Mayo';
$labels['longjun']	= 'Junio';
$labels['longjul']	= 'Julio';
$labels['longaug']	= 'Agosto';
$labels['longsep']	= 'Setiembre';
$labels['longoct']	= 'Octubre';
$labels['longnov']	= 'Noviembre';
$labels['longdec']	= 'Diciembre';
$labels['today'] = 'Hoy';
$labels['refresh']          = 'Actualizar';
$labels['checkmail']        = 'Revisar si hay nuevos mensajes';
$labels['compose']          = 'Escribir';
$labels['writenewmessage']  = 'Crear mensaje nuevo';
$labels['reply']            = 'Responder';
$labels['replytomessage']   = 'Responder al remitente';
$labels['replytoallmessage'] = 'Responder a la lista o al remitente y a todos los destinatarios';
$labels['replyall']         = 'Responder a todos';
$labels['replylist']        = 'Responder a la lista';
$labels['forward']          = 'Reenviar';
$labels['forwardinline']    = 'Reenviar en el mensaje';
$labels['forwardattachment'] = 'Reenviar como archivo adjunto';
$labels['forwardmessage']   = 'Reenviar el mensaje';
$labels['deletemessage']    = 'Eliminar el mensaje';
$labels['movemessagetotrash'] = 'Mover a la papelera';
$labels['printmessage']     = 'Imprimir este mensaje';
$labels['previousmessage']  = 'Mostrar mensaje anterior';
$labels['firstmessage']     = 'Mostrar primer mensaje';
$labels['nextmessage']      = 'Mostrar el siguiente mensaje ';
$labels['lastmessage']      = 'Mostrar el último mensaje';
$labels['backtolist']       = 'Volver a la lista de mensajes';
$labels['viewsource']       = 'Mostrar fuente';
$labels['mark']             = 'Marcar';
$labels['markmessages']     = 'Macar mensajes';
$labels['markread']         = 'Como leido';
$labels['markunread']       = 'Como no leido';
$labels['markflagged']      = 'Como marcado';
$labels['markunflagged']    = 'Como no marcado';
$labels['moreactions']      = 'Más acciones...';
$labels['folders-all']      = 'Todas las carpetas';
$labels['more']             = 'Más';
$labels['back']             = 'Atrás';
$labels['options']          = 'Opciones';
$labels['first'] = 'Primero';
$labels['last'] = 'Último';
$labels['previous'] = 'Anterior';
$labels['next'] = 'Siguiente';
$labels['select'] = 'Seleccionar';
$labels['all'] = 'Todos';
$labels['none'] = 'Ninguno';
$labels['currpage'] = 'Página actual';
$labels['isread'] = 'Leido';
$labels['unread'] = 'No leido';
$labels['flagged'] = 'Marcado';
$labels['unflagged'] = 'No marcado';
$labels['unanswered'] = 'No respondido';
$labels['withattachment'] = 'Con archivo adjunto';
$labels['deleted'] = 'Eliminado';
$labels['undeleted'] = 'No eliminado';
$labels['replied'] = 'Respondido';
$labels['forwarded'] = 'Reenviado';
$labels['invert'] = 'Invertir';
$labels['filter'] = 'Filtrar';
$labels['list'] = 'Enumerar';
$labels['threads'] = 'Hilos';
$labels['expand-all'] = 'Expandir todos';
$labels['expand-unread'] = 'Expandir no leídos';
$labels['collapse-all'] = 'Colapsar todos';
$labels['threaded'] = 'En hilo';
$labels['autoexpand_threads'] = 'Expandir hilos';
$labels['do_expand'] = 'todos los hilos';
$labels['expand_only_unread'] = 'solo con mensajes no leidos';
$labels['fromto'] = 'De/Para';
$labels['flag'] = 'Marcar';
$labels['attachment'] = 'Archivo adjunto';
$labels['nonesort'] = 'Ninguno';
$labels['sentdate'] = 'Fecha de envío';
$labels['arrival'] = 'Fecha de recepción';
$labels['asc'] = 'ascendente';
$labels['desc'] = 'descendente';
$labels['listcolumns'] = 'Enumerar columnas';
$labels['listsorting'] = 'Ordenar columnas';
$labels['listorder'] = 'Ordenado por';
$labels['listmode'] = 'Modo de visualización de lista';
$labels['layoutlist'] = 'Enumerar';
$labels['folderactions'] = 'Acciones de carpeta...';
$labels['compact'] = 'Comprimir';
$labels['empty'] = 'Vaciar';
$labels['importmessages'] = 'Importar mensajes';
$labels['quota'] = 'Uso de disco';
$labels['unknown']  = 'desconocido';
$labels['unlimited']  = 'ilimitado';
$labels['quotatype'] = 'Tipo de cuota';
$labels['quotatotal'] = 'Límite';
$labels['quotaused'] = 'Usado';
$labels['quotastorage'] = 'Espacio en disco';
$labels['quotamessage'] = 'Conteo de mensajes';
$labels['quicksearch']  = 'Búsqueda rápida';
$labels['resetsearch']  = 'Eliminar busqueda';
$labels['searchmod']  = 'Modificadores de búsqueda';
$labels['msgtext']  = 'Mensaje completo';
$labels['body']  = 'Cuerpo';
$labels['type'] = 'Tipo';
$labels['namex'] = 'Nombre';
$labels['searchscope'] = 'Alcance';
$labels['currentfolder'] = 'Carpeta actual';
$labels['subfolders'] = 'Esta y subcarpetas';
$labels['allfolders'] = 'Todas las carpetas';
$labels['openinextwin'] = 'Abrir en una ventana nueva';
$labels['emlsave'] = 'Descargar (.eml)';
$labels['changeformattext'] = 'Mostrar en texto plano';
$labels['changeformathtml'] = 'Mostrar en formato HTML';
$labels['editasnew']      = 'Editar como nuevo';
$labels['send']           = 'Enviar';
$labels['sendmessage']    = 'Enviar mensaje';
$labels['savemessage']    = 'Guardar como borrador';
$labels['addattachment']  = 'Adjuntar un archivo';
$labels['charset']        = 'Tipo de codificación de caracteres';
$labels['editortype']     = 'Tipo de editor';
$labels['returnreceipt']  = 'Confirmación de recepción';
$labels['dsn']            = 'Notificación de estado del envío';
$labels['mailreplyintro'] = 'El $date, $sender escribió:';
$labels['originalmessage'] = 'Mensaje original';
$labels['selectimage']    = 'Seleccionar imagen';
$labels['addimage']       = 'Agregar imagen';
$labels['selectmedia']    = 'Seleccionar película';
$labels['addmedia']       = 'Agregar película';
$labels['editidents']    = 'Editar identidades';
$labels['spellcheck']    = 'Corrección ortográfica';
$labels['checkspelling'] = 'Verificar ortografía';
$labels['resumeediting'] = 'Continuar con la edición';
$labels['revertto']      = 'Revertir a';
$labels['restore'] = 'Restaurar';
$labels['restoremessage'] = '¿Restaurar mensaje?';
$labels['responses'] = 'Respuestas';
$labels['insertresponse'] = 'Insertar una respuesta';
$labels['manageresponses'] = 'Administrar respuestas';
$labels['newresponse'] = 'Crear nueva respuesta';
$labels['addresponse'] = 'Agregar respuesta';
$labels['editresponse'] = 'Editar respuesta';
$labels['editresponses'] = 'Editar respuestas';
$labels['responsename'] = 'Nombre';
$labels['responsetext'] = 'Texto de respuesta';
$labels['attach'] = 'Adjuntar';
$labels['attachments'] = 'Archivos adjuntos';
$labels['upload'] = 'Subir';
$labels['close']  = 'Cerrar';
$labels['messageoptions']  = 'Opciones de mensaje...';
$labels['togglecomposeoptions'] = 'Cambiar opciones de escritura';
$labels['low']     = 'Bajo';
$labels['lowest']  = 'Más bajo';
$labels['normal']  = 'Normal';
$labels['high']    = 'Alto';
$labels['highest'] = 'Más alto';
$labels['nosubject']  = '(sin asunto)';
$labels['showimages'] = 'Mostrar imágenes';
$labels['alwaysshow'] = 'Mostrar siempre las imagenes de $sender';
$labels['isdraft']    = 'Este mensaje es un borrador.';
$labels['andnmore']   = '$nr más...';
$labels['togglemoreheaders'] = 'Mostrar más encabezados';
$labels['togglefullheaders'] = 'Mostrar todos los encabezados';
$labels['htmltoggle'] = 'HTML';
$labels['plaintoggle'] = 'Texto plano';
$labels['savesentmessagein'] = 'Guardar mensaje enviado en ';
$labels['dontsave'] = 'no guardar';
$labels['maxuploadsize'] = 'El tamaño máximo permitido por archivo es $size';
$labels['addcc'] = 'Agregar Cc';
$labels['addbcc'] = 'Agregar Bcc';
$labels['addreplyto'] = 'Agregar Responder a';
$labels['addfollowupto'] = 'Agregar Seguir a';
$labels['mdnrequest'] = 'El remitente de este mensaje a pedido ser notificado cuando lea el mensaje. ¿Quiere notificar al remitente?';
$labels['receiptread'] = 'Confirmación del recepción (leído)';
$labels['yourmessage'] = 'Esta es una confirmación de recepción de tu mensaje';
$labels['receiptnote'] = 'Nota: esta confirmación solo prueba que el mensaje se ha mostrado en la computadora del destinatario. No es garantía de que el destinatario haya leído o entendido el contenido del mensaje.';
$labels['name']         = 'Nombre para mostrar';
$labels['firstname']    = 'Primer nombre';
$labels['surname']      = 'Apellido';
$labels['middlename']   = 'Segundo Nombre';
$labels['nameprefix']   = 'Prefijo';
$labels['namesuffix']   = 'Sufijo';
$labels['nickname']     = 'Sobrenombre';
$labels['jobtitle']     = 'Puesto';
$labels['department']   = 'Departamento';
$labels['gender']       = 'Sexo';
$labels['maidenname']   = 'Apellido de soltera';
$labels['email']        = 'Dirección de correo electrónico';
$labels['phone']        = 'Teléfono';
$labels['address']      = 'Dirección';
$labels['street']       = 'Calle';
$labels['locality']     = 'Ciudad';
$labels['zipcode']      = 'Código Postal';
$labels['region']       = 'Estado/Provincia';
$labels['country']      = 'País';
$labels['birthday']     = 'Cumpleaños';
$labels['anniversary']  = 'Aniversario';
$labels['website']      = 'Sitio web';
$labels['instantmessenger'] = 'Mensajería instantánea';
$labels['notes'] = 'Notas';
$labels['male']   = 'masculino';
$labels['female'] = 'femenino';
$labels['manager'] = 'Administrador';
$labels['assistant'] = 'Asistente';
$labels['spouse'] = 'Cónyuge';
$labels['allfields'] = 'Todos los campos';
$labels['search'] = 'Buscar';
$labels['searchresult'] = 'Resultado de búsqueda';
$labels['advsearch'] = 'Búsqueda avanzada';
$labels['advanced'] = 'Avanzada';
$labels['other'] = 'Otro';
$labels['typehome']   = 'Casa';
$labels['typework']   = 'Trabajo';
$labels['typeother']  = 'Otro';
$labels['typemobile']  = 'Celular';
$labels['typemain']  = 'Principal';
$labels['typehomefax']  = 'Fax (casa)';
$labels['typeworkfax']  = 'Fax (oficina)';
$labels['typecar']  = 'Auto';
$labels['typepager']  = 'Pager';
$labels['typevideo']  = 'Video';
$labels['typeassistant']  = 'Asistente';
$labels['typehomepage']  = 'Página web';
$labels['typeblog'] = 'Blog';
$labels['typeprofile'] = 'Perfil';
$labels['addfield'] = 'Agregar campo...';
$labels['addcontact'] = 'Agregar contacto';
$labels['editcontact'] = 'Editar contacto';
$labels['contacts'] = 'Contactos';
$labels['contactproperties'] = 'Propiedades del contacto';
$labels['contactnameandorg'] = 'Nombre y organización';
$labels['personalinfo'] = 'Información personal';
$labels['personal'] = 'Personal';
$labels['contactphoto'] = 'Foto del contacto';
$labels['edit']   = 'Editar';
$labels['cancel'] = 'Cancelar';
$labels['save']   = 'Guardar';
$labels['delete'] = 'Eliminar';
$labels['discard'] = 'Descartar';
$labels['rename'] = 'Renombrar';
$labels['addphoto'] = 'Agregar';
$labels['replacephoto'] = 'Remplazar';
$labels['uploadphoto'] = 'Subir foto';
$labels['newcontact']     = 'Crear nuevo contacto';
$labels['deletecontact']  = 'Eliminar contactos seleccionados';
$labels['composeto']      = 'Escribir a ';
$labels['contactsfromto'] = 'Contactos $from a $to de $count';
$labels['print']          = 'Imprimir';
$labels['export']         = 'Exportar';
$labels['exportall']      = 'Exportar todo';
$labels['exportsel']      = 'Exportar lo seleccionado';
$labels['exportvcards']   = 'Exportar contactos en formato vCard';
$labels['newgroup']       = 'Crear grupo nuevo';
$labels['addgroup']       = 'Agregar grupo';
$labels['grouprename']    = 'Renombrar grupo';
$labels['groupdelete']    = 'Eliminar grupo';
$labels['groupremoveselected'] = 'Eliminar contactos seleccionados del grupo';
$labels['uponelevel']     = 'Arriba un nivel';
$labels['previouspage']   = 'Mostrar página anterior';
$labels['firstpage']      = 'Mostrar primera página';
$labels['nextpage']       = 'Mostrar página siguiente';
$labels['lastpage']       = 'Mostrar última página';
$labels['group'] = 'Grupo';
$labels['groups'] = 'Grupos';
$labels['listgroup'] = 'Mostrar miembros del grupo';
$labels['personaladrbook'] = 'Direcciones personales';
$labels['searchsave'] = 'Guardar búsqueda';
$labels['searchdelete'] = 'Eliminar búsqueda';
$labels['import'] = 'Importar';
$labels['importcontacts'] = 'Importar contactos';
$labels['importfromfile'] = 'Importar desde archivo:';
$labels['importtarget'] = 'Agregar contactos a';
$labels['importreplace'] = 'Remplazar toda la libreta de direcciones';
$labels['importgroups'] = 'Importar asignaciones del grupo';
$labels['importgroupsall'] = 'Todo (crear grupos si es necesario)';
$labels['importgroupsexisting'] = 'Solo para grupos existentes';
$labels['importdesc'] = 'Puede subir contactos desde una libreta de direcciones existente. .<br/>Actualmente soportamos importar direcciones de los formatos <a href="http://en.wikipedia.org/wiki/VCard">vCard</a> o CSV (separado por comas).';
$labels['done'] = 'Listo';
$labels['settingsfor'] = 'Configuraciones para';
$labels['about'] = 'Acerca de';
$labels['preferences'] = 'Preferencias';
$labels['userpreferences'] = 'Preferencias de usuario ';
$labels['editpreferences'] = 'Editar preferencias de usuario ';
$labels['identities'] = 'Identidades';
$labels['manageidentities'] = 'Administrar identidades';
$labels['newidentity'] = 'Crear nueva identidad';
$labels['addidentity'] = 'Agregar identidad';
$labels['editidentity'] = 'Editar identidad';
$labels['preferhtml'] = 'Mostrar HTML ';
$labels['defaultcharset'] = 'Caracteres predeterminados';
$labels['htmlmessage'] = 'Mensaje HTML ';
$labels['messagepart'] = 'Parte';
$labels['digitalsig'] = 'Firma digital';
$labels['dateformat'] = 'Formato de fecha';
$labels['timeformat'] = 'Formato de hora';
$labels['prettydate'] = 'Fechas bonitas';
$labels['setdefault']  = 'Predeterminar';
$labels['autodetect']  = 'Automático';
$labels['language']  = 'Idioma';
$labels['timezone']  = 'Zona horaria';
$labels['pagesize']  = 'Filas por página ';
$labels['signature'] = 'Firma';
$labels['dstactive']  = 'Horario de ahorro de energía';
$labels['showinextwin'] = 'Abrir mensaje en una ventana nueva ';
$labels['composeextwin'] = 'Escribir en una ventana nueva ';
$labels['htmleditor'] = 'Escribir mensajes HTML';
$labels['htmlonreply'] = 'al responder un mensaje HTML';
$labels['htmlonreplyandforward'] = 'al renviar o responder un mensaje HTML';
$labels['htmlsignature'] = 'Firma HTML ';
$labels['showemail'] = 'Mostrar dirección de correo electrónico junto al nombre a mostrar';
$labels['previewpane'] = 'Mostrar vista previa ';
$labels['skin'] = 'Tipo de interfaz';
$labels['logoutclear'] = 'Vaciar la papelera al salir';
$labels['logoutcompact'] = 'Comprimir la Bandeja de entrada al salir';
$labels['uisettings'] = 'Interfaz de usuario';
$labels['serversettings'] = 'Configuración del servidor';
$labels['mailboxview'] = 'Visualización de la bandeja';
$labels['mdnrequests'] = 'Al solicitarse confirmación de recepción';
$labels['askuser'] = 'preguntarme';
$labels['autosend'] = 'enviar confirmación de recepción';
$labels['autosendknown'] = 'enviar confirmación de recepción a mis contactos; de lo contrario, preguntarme';
$labels['autosendknownignore'] = 'enviar confirmación de recepción a mis contactos; de lo contrario, ignorar';
$labels['readwhendeleted'] = 'Marcar mensaje como leído al eliminarlo ';
$labels['flagfordeletion'] = 'Marcar el mensaje para eliminación en lugar de eliminarlo';
$labels['skipdeleted'] = 'No mostrar mensajes eliminados';
$labels['deletealways'] = 'Si falla el mover los mensajes a la Papelera, eliminarlos';
$labels['deletejunk'] = 'Eliminar directamente los mensajes en No deseado';
$labels['showremoteimages'] = 'Mostrar imágenes remotas en el mensaje';
$labels['fromknownsenders'] = 'de remitentes conocidos';
$labels['always'] = 'siempre ';
$labels['showinlineimages'] = 'Mostrar imágenes adjuntas debajo del mensaje';
$labels['autosavedraft']  = 'Guardar borrador automáticamente';
$labels['everynminutes']  = 'cada $n minuto(s)';
$labels['refreshinterval']  = 'Actualizar (buscar nuevos mensajes, etc.)';
$labels['never']  = 'nunca';
$labels['immediately']  = 'inmediatamente';
$labels['messagesdisplaying'] = 'Mostrando mensajes';
$labels['messagescomposition'] = 'Escribiendo mensajes';
$labels['mimeparamfolding'] = 'Nombres de archivos adjuntos';
$labels['2231folding'] = 'RFC 2231 completo (Thunderbird)';
$labels['miscfolding'] = 'RFC 2047/2231 (MS Outlook)';
$labels['2047folding'] = 'RFC 2047 completo (otros)';
$labels['force7bit'] = 'Usar codificación MIME para caracteres de 8 bits';
$labels['savelocalstorage'] = "Guardar en el almacenamiento local del navegador (temporalmente)";
$labels['advancedoptions'] = 'Opciones avanzadas';
$labels['toggleadvancedoptions'] = 'Cambiar opciones avanzadas';
$labels['focusonnewmessage'] = 'Enfocar la ventana del navegador en el nuevo mensaje';
$labels['checkallfolders'] = 'Buscar nuevos mensajes en todas las carpetas';
$labels['displaynext'] = 'Luego de eliminar/mover mensajes, mostrar el próximo';
$labels['defaultfont'] = 'Tipo de letra predeterminado en mensajes HTML';
$labels['mainoptions'] = 'Opciones principales';
$labels['browseroptions'] = 'Opciones del navegador';
$labels['section'] = 'Sección';
$labels['maintenance'] = 'Mantenimiento';
$labels['newmessage'] = 'Mensaje nuevo';
$labels['signatureoptions'] = 'Opciones de firma';
$labels['whenreplying'] = 'Al responder';
$labels['replyempty'] = 'no citar el mensaje original ';
$labels['replytopposting'] = 'comenzar mensaje nuevo arriba de la cita';
$labels['replybottomposting'] = 'comenzar mensaje nuevo debajo de la cita';
$labels['replyremovesignature'] = 'Al responder, borrar la firma original del mensaje';
$labels['autoaddsignature'] = 'Agregar firma automáticamente';
$labels['newmessageonly'] = 'solo mensaje nuevo';
$labels['replyandforwardonly'] = 'solo responde y reenvía';
$labels['insertsignature'] = 'insertar firma';
$labels['afternseconds']  = 'luego de $n segundos';
$labels['reqmdn'] = 'Solicitar siempre una confirmación de recepción';
$labels['reqdsn'] = 'Solicitar siempre una notificación de estado de envío';
$labels['replysamefolder'] = 'Colocar respuestas en la carpeta del mensaje que ha sido respondido';
$labels['defaultabook'] = 'Libreta de direcciones predeterminada';
$labels['autocompletesingle'] = 'Al autocompletar, omitir direcciones de correo electrónico alternativas';
$labels['listnamedisplay'] = 'Enumerar contactos como';
$labels['spellcheckbeforesend'] = 'Verificar ortografía antes de enviar un mensaje';
$labels['spellcheckoptions'] = 'Opciones de la corrección ortográfica';
$labels['spellcheckignoresyms'] = 'Ignorar palabras con símbolos';
$labels['spellcheckignorenums'] = 'Ignorar palabras con números';
$labels['spellcheckignorecaps'] = 'Ignorar palabras con todas las letras en mayúsculas';
$labels['addtodict'] = 'Agregar al diccionario';
$labels['mailtoprotohandler'] = 'Registrar manejador de protocolo para enlaces mailto:';
$labels['standardwindows'] = 'Tratar ventanas emergentes como ventanas comunes';
$labels['forwardmode'] = 'Reenvío de mensajes';
$labels['inline'] = 'en el mensaje';
$labels['asattachment'] = 'como adjunto';
$labels['replyallmode'] = 'Acción predeterminada del botón [Responder a todos]';
$labels['replyalldefault'] = 'responder a todos';
$labels['replyalllist'] = 'responder solamente a la lista de correos (si hay una)';
$labels['folder'] = 'Carpeta';
$labels['folders'] = 'Carpetas';
$labels['foldername'] = 'Nombre de carpeta';
$labels['subscribed'] = 'Suscrita(s)';
$labels['messagecount'] = 'Mensajes';
$labels['create'] = 'Crear';
$labels['createfolder'] = 'Crear carpeta nueva';
$labels['managefolders'] = 'Administrar carpetas';
$labels['specialfolders'] = 'Capetas especiales';
$labels['properties'] = 'Propiedades';
$labels['folderproperties'] = 'Propiedades de la carpeta';
$labels['parentfolder'] = 'Carpeta madre';
$labels['location'] = 'Ubicación';
$labels['info'] = 'Información';
$labels['getfoldersize'] = 'Haga clic para obtener el tamaño de la carpeta';
$labels['changesubscription'] = 'Haga clic para cambiar la subscripción';
$labels['foldertype'] = 'Tipo de carpeta';
$labels['personalfolder'] = 'Carpeta privada';
$labels['otherfolder'] = 'Carpeta de otro usuario';
$labels['sharedfolder'] = 'Carpeta pública';
$labels['findfolders'] = 'Buscar carpetas';
$labels['namespace.personal'] = 'Personal';
$labels['namespace.other'] = 'Otros usuarios';
$labels['namespace.shared'] = 'Compartido';
$labels['sortby'] = 'Ordenar por';
$labels['sortasc']  = 'Ordenar de forma ascendente';
$labels['sortdesc'] = 'Ordenar de forma descendente';
$labels['undo'] = 'Deshacer';
$labels['installedplugins'] = 'Extensiones instaladas';
$labels['plugin'] = 'Extensión';
$labels['version'] = 'Versión';
$labels['source'] = 'Fuente';
$labels['license'] = 'Licencia';
$labels['support'] = 'Obtener soporte técnico';
$labels['B'] = 'B';
$labels['KB'] = 'KB';
$labels['MB'] = 'MB';
$labels['GB'] = 'GB';
$labels['unicode'] = 'Unicode';
$labels['english'] = 'Inglés';
$labels['westerneuropean'] = 'Europeo Occidental';
$labels['easterneuropean'] = 'Europeo Oriental';
$labels['southeasterneuropean'] = 'Europeo Sur-Oriental';
$labels['baltic'] = 'Baltico';
$labels['cyrillic'] = 'Cirílico';
$labels['arabic'] = 'Arábe';
$labels['greek'] = 'Griego';
$labels['hebrew'] = 'Hebreo';
$labels['turkish'] = 'Turco';
$labels['nordic'] = 'Nórdico';
$labels['thai'] = 'Tailandés';
$labels['celtic'] = 'Celta';
$labels['vietnamese'] = 'Vietnamita';
$labels['japanese'] = 'Japonés';
$labels['korean'] = 'Coreano';
$labels['chinese'] = 'Chino';
$labels['arialabeltopnav'] = 'Control de ventana';
$labels['arialabeltasknav'] = 'Tareas de la aplicación';
$labels['arialabeltoolbar'] = 'Barra de herramientas de la aplicación';
$labels['arialabelactivetask'] = 'Tarea activa';
$labels['arialabelmessagessearchfilter'] = 'Listado de filtros de correo electrónico';
$labels['arialabelmailsearchform'] = 'Formulario de búsqueda de mensajes de correo electrónico';
$labels['arialabelcontactsearchform'] = 'Formulario de búsqueda de contactos';
$labels['arialabelmailquicksearchbox'] = 'Ingreso de búsqueda de correo electrónico';
$labels['arialabelquicksearchbox'] = 'Ingreso de búsqueda';
$labels['arialabelfoldersearchfilter'] = 'Filtro de lista de carpetas';
$labels['arialabelfoldersearchform'] = 'Formulario de busqueda de carpetas';
$labels['arialabelfolderlist'] = 'Selección de carpeta de correo electrónico';
$labels['arialabelmessagelist'] = 'Listado de mensajes de correo electrónico';
$labels['arialabelmailpreviewframe'] = 'Previsualización del mensaje';
$labels['arialabelmailboxmenu'] = 'Menú de acciones de carpeta';
$labels['arialabellistselectmenu'] = 'Menú de lista de selección';
$labels['arialabelthreadselectmenu'] = 'Menú de listado de hilos';
$labels['arialabelmessagelistoptions'] = 'Opciones de organización y visualización de mensajes';
$labels['arialabelmailimportdialog'] = 'Diálogo de importación de mensajes';
$labels['arialabelmessagenav'] = 'Navegación de mensajes';
$labels['arialabelmessagebody'] = 'Cuerpo del mensaje';
$labels['arialabelmessageactions'] = 'Acciones del mensaje';
$labels['arialabelcontactquicksearch'] = 'Formulario de búsqueda de contactos';
$labels['arialabelcontactsearchbox'] = 'Ingreso de búsqueda de contacto';
$labels['arialabelmessageheaders'] = 'Encabezados del mensaje';
$labels['arialabelforwardingoptions'] = 'Opciones de reenvío';
$labels['arialabelreplyalloptions'] = 'Opciones de Responder a todos';
$labels['arialabelmoremessageactions'] = 'Más acciones de mensaje';
$labels['arialabelmarkmessagesas'] = 'Marcar mensajes seleccionados como...';
$labels['arialabelcomposeoptions'] = 'Opciones de escritura';
$labels['arialabelresponsesmenu'] = 'Menú de respuestas enlatadas';
$labels['arialabelattachmentuploadform'] = 'Formulario para subir archivos adjuntos';
$labels['arialabelattachmentpreview'] = 'Previsualización de archivos adjuntos';
$labels['ariasummarycomposecontacts'] = 'Lista de contactos y grupos para seleccionar como destinatarios';
$labels['arialabelcontactexportoptions'] = 'Opciones de exportación de contactos';
$labels['arialabelabookgroupoptions'] = 'Opciones de libreta de direcciones/grupos';
$labels['arialabelpreferencesform'] = 'Formulario de preferencias';
$labels['arialabelidentityeditfrom'] = 'Formulario de edición de identidad';
$labels['arialabelresonseeditfrom'] = 'Formulario de edición de respuestas';
$labels['arialabelsearchterms'] = 'Términos de busqueda';
$labels['helplistnavigation'] = 'Listar navegación por teclado';
$labels['helplistkeyboardnavigation'] = "Flechas arriba/abajo: Mover la selección/enfoque de la fila.
Espacio: Seleccionar fila enfocada.
Mayús + arriba/abajo: Seleccionar más filas arriba/debajo.
Ctrl + Espacio: Agregar/eliminar la fila enfocada a/de la selección.";
$labels['helplistkeyboardnavmessages'] = "Flechas derecha/izquierda: Expandir/colapsar mensajes en hilo (solo en modo en hilo).
Intro: Abrir el mensaje seleccionado/enfocado.
Eliminar: Mover los mensajes seleccionados a la Papelera.";
$labels['helplistkeyboardnavcontacts'] = "Intro: Abrir el contacto seleccionado/enfocado.";
?>
