
p.vcardattachment {
	margin: 0.5em 1em;
	border: 1px solid #999;
	border-radius:4px;
	-moz-border-radius: 4px;
	-webkit-border-radius: 4px;
	border-radius: 4px;
	width: auto;
}

p.vcardattachment a {
	display: block;
	background: url(vcard_add_contact.png) 4px 0px no-repeat;
	padding: 0.7em 0.5em 0.3em 42px;
	height: 22px;
}

#abookactions a.vcard span {
	text-indent: -5000px;
	display: inline-block;
	height: 22px;
	width: 15px;
	background: url(../../../../skins/classic/images/messageicons.png) 0 -168px no-repeat;
}

#abookactions a.vcard.disabled span {
	opacity: 0.5;
}
