/** Styles for the new-user-dialog box */

#newuserdialog {
	display: none;
}

#newuserdialog h3 {
	color: #333;
	font-size: normal;
	margin-top: 0;
	margin-bottom: 0;
}

#newuserdialog p.hint {
	margin-top: 0.5em;
	margin-bottom: 1em;
	font-style: italic;
}

#newuserdialog table td.title {
	color: #666;
	text-align: right;
	padding-right: 1em;
	white-space: nowrap;
}

#newuserdialog table td input,
#newuserdialog table td textarea {
	width: 20em;
}

#newuserdialog .formbuttons {
	margin-top: 1.5em;
	text-align: center;
}

.ui-dialog-titlebar-close {
	display: none;
}