<?php

/*
 +-----------------------------------------------------------------------+
 | localization/<lang>/labels.inc                                        |
 |                                                                       |
 | Localization file of the Roundcube Webmail client                     |
 | Copyright (C) 2005-2015, The Roundcube Dev Team                       |
 |                                                                       |
 | Licensed under the GNU General Public License version 3 or            |
 | any later version with exceptions for skins & plugins.                |
 | See the README file for a full license statement.                     |
 |                                                                       |
 +-----------------------------------------------------------------------+

 For translation see https://www.transifex.com/projects/p/roundcube-webmail/resource/labels/
*/
$labels['welcome']   = '$product E-Posta Sistemine Hoş Geldiniz';
$labels['username']  = 'Kullanıcı Adı';
$labels['password']  = 'Parola';
$labels['server']    = 'Sunucu';
$labels['login']     = 'Oturum Aç';
$labels['menu']     = 'Menü';
$labels['logout']   = 'Kapat';
$labels['mail']     = 'İletiler';
$labels['settings'] = 'Ayarlar';
$labels['addressbook'] = 'Adresler';
$labels['inbox']  = 'Gelen';
$labels['drafts'] = 'Taslak';
$labels['sent']   = 'Giden';
$labels['trash']  = 'Çöp';
$labels['junk']   = 'İstenmeyen';
$labels['show_real_foldernames'] = 'Özel klasörlerin gerçek adları görüntülensin';
$labels['subject'] = 'Konu';
$labels['from']    = 'Gönderen';
$labels['sender']  = 'Gönderici';
$labels['to']      = 'Alıcı';
$labels['cc']      = 'Kopya';
$labels['bcc']     = 'Gizli Kopya';
$labels['replyto'] = 'Yanıt Adresi';
$labels['followupto'] = 'İzleme adresi';
$labels['date']    = 'Tarih';
$labels['size']    = 'Boyut';
$labels['priority'] = 'Öncelik';
$labels['organization'] = 'Kuruluş';
$labels['readstatus'] = 'Okunma durumu';
$labels['listoptions'] = 'Seçenekleri listele...';
$labels['listoptionstitle'] = 'Liste seçenekleri';
$labels['mailboxlist'] = 'Klasörler';
$labels['messagesfromto'] = 'İletiler: $from - $to , Toplam: $count';
$labels['threadsfromto'] = 'Sohbetler: $from - $to, Toplam $count';
$labels['messagenrof'] = 'İleti: $nr / $count';
$labels['fromtoshort'] = '$from - $to , Toplam: $count';
$labels['copy']     = 'Kopyala';
$labels['move']     = 'Taşı';
$labels['moveto']   = 'Şuraya Taşı...';
$labels['copyto']   = 'Şuraya Kopyala...';
$labels['download'] = 'İndir';
$labels['open']     = 'Aç';
$labels['showattachment'] = 'Görüntüle';
$labels['showanyway'] = 'Yine de görüntülensin';
$labels['filename'] = 'Dosya Adı';
$labels['filesize'] = 'Dosya Boyutu';
$labels['addtoaddressbook'] = 'Adres Defterine Ekle';
$labels['sun'] = 'Paz';
$labels['mon'] = 'Pzt';
$labels['tue'] = 'Sal';
$labels['wed'] = 'Çrş';
$labels['thu'] = 'Per';
$labels['fri'] = 'Cum';
$labels['sat'] = 'Cts';
$labels['sunday']    = 'Pazar';
$labels['monday']    = 'Pazartesi';
$labels['tuesday']   = 'Salı';
$labels['wednesday'] = 'Çarşamba';
$labels['thursday']  = 'Perşembe';
$labels['friday']    = 'Cuma';
$labels['saturday']  = 'Cumartesi';
$labels['jan']	= 'Oca';
$labels['feb']	= 'Şub';
$labels['mar']	= 'Mar';
$labels['apr']	= 'Nis';
$labels['may']	= 'May';
$labels['jun']	= 'Haz';
$labels['jul'] 	= 'Tem';
$labels['aug']	= 'Ağu';
$labels['sep']	= 'Eyl';
$labels['oct']	= 'Eki';
$labels['nov']	= 'Kas';
$labels['dec']	= 'Ara';
$labels['longjan']	= 'Ocak';
$labels['longfeb']	= 'Şubat';
$labels['longmar']	= 'Mart';
$labels['longapr']	= 'Nisan';
$labels['longmay']	= 'Mayıs';
$labels['longjun']	= 'Haziran';
$labels['longjul']	= 'Temmuz';
$labels['longaug']	= 'Ağustos';
$labels['longsep']	= 'Eylül';
$labels['longoct']	= 'Ekim';
$labels['longnov']	= 'Kasım';
$labels['longdec']	= 'Aralık';
$labels['today'] = 'Bugün';
$labels['refresh']          = 'Yenile';
$labels['checkmail']        = 'İletileri Denetle';
$labels['compose']          = 'İleti Gönder';
$labels['writenewmessage']  = 'Yeni İleti ';
$labels['reply']            = 'Yanıtla';
$labels['replytomessage']   = 'Gönderene Yanıtla';
$labels['replytoallmessage'] = 'Gönderen ve Tüm Alıcılara Yanıtla';
$labels['replyall']         = 'Toplu Yanıtla';
$labels['replylist']        = 'Listeye Yanıtla';
$labels['forward']          = 'İlet';
$labels['forwardinline']    = 'Posta İçinde İlet';
$labels['forwardattachment'] = 'Ek Olarak İlet';
$labels['forwardmessage']   = 'İlet';
$labels['bouncemsg']        = 'Yeniden gönder (sektir)';
$labels['bounce']           = 'Yeniden gönder';
$labels['deletemessage']    = 'İletiyi Sil';
$labels['movemessagetotrash'] = 'Çöpe Taşı';
$labels['printmessage']     = 'Yazdır';
$labels['previousmessage']  = 'Önceki ileti';
$labels['firstmessage']     = 'İlk İleti';
$labels['nextmessage']      = 'Sonraki İleti';
$labels['lastmessage']      = 'Son İleti';
$labels['backtolist']       = 'İleti Listesine Dön';
$labels['viewsource']       = 'Kaynağı Görüntüle';
$labels['mark']             = 'İşaretle';
$labels['markmessages']     = 'İletileri işaretle';
$labels['markread']         = 'Okunmuş ';
$labels['markunread']       = 'Okunmamış Olarak';
$labels['markflagged']      = 'İşaretlenmiş Olarak';
$labels['markunflagged']    = 'İşaretlenmemiş Olarak';
$labels['moreactions']      = 'Diğer İşlemler...';
$labels['markallread']      = 'Tümünü Okundu Olarak İşaretle';
$labels['folders-cur']      = 'Yalnız Seçilmiş Klasör';
$labels['folders-sub']      = 'Seçilmiş Klasör ve Alt Klasörleri';
$labels['folders-all']      = 'Tüm Klasörler';
$labels['more']             = 'Diğer';
$labels['back']             = 'Geri';
$labels['options']          = 'Ayarlar';
$labels['composeoptions']   = 'İleti Oluşturma Ayarları';
$labels['optionsandattachments'] = 'Ayarlar ve Ek Dosyalar';
$labels['actions']          = 'İşlemler';
$labels['first'] = 'İlk';
$labels['last'] = 'Son';
$labels['previous'] = 'Önceki';
$labels['next'] = 'Sonraki';
$labels['select'] = 'Seç';
$labels['all'] = 'Tümü';
$labels['none'] = 'Yok';
$labels['currpage'] = 'Geçerli Sayfa';
$labels['isread'] = 'Oku';
$labels['unread'] = 'Okunmamışları';
$labels['flagged'] = 'İşaretlenmişler';
$labels['unflagged'] = 'İşaretlenmemişleri';
$labels['unanswered'] = 'Yanıtlanmamışları';
$labels['withattachment'] = 'Eki Olanlar';
$labels['deleted'] = 'Silinmişler';
$labels['undeleted'] = 'Silinmemişler';
$labels['replied'] = 'Yanıtlandı';
$labels['forwarded'] = 'İletildi';
$labels['invert'] = 'Seçimi Ters Çevir';
$labels['filter'] = 'Süz';
$labels['list'] = 'Liste';
$labels['threads'] = 'Sohbetler';
$labels['expand-all'] = 'Tümünü Genişlet';
$labels['expand-unread'] = 'Okunmamışları Genişlet';
$labels['collapse-all'] = 'Tümünü Daralt';
$labels['threaded'] = 'Sohbet Görünümü';
$labels['autoexpand_threads'] = 'Sohbet iletileri genişletilsin';
$labels['do_expand'] = 'tüm sohbetler';
$labels['expand_only_unread'] = 'yalnız okunmamış iletiler bulunan dizilimler';
$labels['fromto'] = 'Gönderici/Alıcı';
$labels['flag'] = 'İşaret';
$labels['attachment'] = 'Dosya Eki';
$labels['nonesort'] = 'Yok';
$labels['sentdate'] = 'Gönderim Tarihi';
$labels['arrival'] = 'Alınma Tarihi';
$labels['asc'] = 'artan';
$labels['desc'] = 'azalan';
$labels['listcolumns'] = 'Sütunları Listele';
$labels['listsorting'] = 'Sıralama Sütunu';
$labels['listorder'] = 'Sıralama Düzeni';
$labels['listmode'] = 'Liste Görünümü';
$labels['lmode'] = 'Liste Kipi';
$labels['layout'] = 'Görünüm';
$labels['layoutwidescreen'] = 'Geniş Ekran';
$labels['layoutdesktop'] = 'Masaüstü';
$labels['layoutlist'] = 'Liste';
$labels['layoutwidescreendesc'] = 'Geniş ekran (3 sütun görünümü)';
$labels['layoutdesktopdesc'] = 'Masaüstü (geniş liste ile aşağıda e-posta önizlemesi)';
$labels['layoutlistdesc'] = 'Liste (e-posta önizlemesi olmadan)';
$labels['folderactions'] = 'Klasör İşlemleri...';
$labels['compact'] = 'Sıkıştır';
$labels['empty'] = 'Boşalt';
$labels['importmessages'] = 'İçe Aktar';
$labels['quota'] = 'Disk Kullanımı';
$labels['unknown']  = 'bilinmeyen';
$labels['unlimited']  = 'sınırsız';
$labels['quotatype'] = 'Kota türü';
$labels['quotatotal'] = 'Sınır';
$labels['quotaused'] = 'Kullanılan';
$labels['quotastorage'] = 'Disk Boyutu';
$labels['quotamessage'] = 'İleti Sayısı';
$labels['shortheaderdate'] = '$date tarihinde';
$labels['shortheaderto'] = '$to alıcısına $date tarihinde';
$labels['shortheaderfrom'] = '$from göndericisinden $date tarihinde';
$labels['quicksearch']  = 'Hızlı Arama';
$labels['searchplaceholder']  = 'Arama...';
$labels['resetsearch']  = 'Aramayı Sıfırla';
$labels['searchmod']  = 'Arama Alanları';
$labels['msgtext']  = 'Tüm İleti Alanları';
$labels['body']  = 'Metin';
$labels['type'] = 'Tür';
$labels['namex'] = 'Ad';
$labels['searchscope'] = 'Kapsam';
$labels['currentfolder'] = 'Bu klasör';
$labels['subfolders'] = 'Bu ve alt klasörler';
$labels['allfolders'] = 'Tüm klasörler';
$labels['searchinterval-1W'] = 'Bir haftadan eski';
$labels['searchinterval-1M'] = 'Bir aydan eski';
$labels['searchinterval-1Y'] = 'Bir yıldan eski';
$labels['searchinterval1W'] = 'Bir haftadan yeni';
$labels['searchinterval1M'] = 'Bir aydan yeni';
$labels['searchinterval1Y'] = 'Bir yıldan yeni';
$labels['openinextwin'] = 'Yeni Pencerede Aç';
$labels['emlsave'] = 'İndir (.eml)';
$labels['changeformattext'] = 'Düz metin biçiminde görüntülensin';
$labels['changeformathtml'] = 'HTML biçiminde görüntülensin';
$labels['editasnew']      = 'Yeni Olarak Düzenle';
$labels['send']           = 'Gönder';
$labels['sendmessage']    = 'İletiyi Gönder';
$labels['savemessage']    = 'Taslak Olarak Kaydet';
$labels['addattachment']  = 'Dosya Ekle';
$labels['charset']        = 'Karakter Kodlaması';
$labels['editortype']     = 'Düzenleyici';
$labels['returnreceipt']  = 'Alındı Onayı';
$labels['dsn']            = 'Teslim Onayı';
$labels['mailreplyintro'] = '$date, $sender yazmış:';
$labels['originalmessage'] = 'Özgün İleti';
$labels['selectimage']    = 'Görsel Seç';
$labels['addimage']       = 'Görsel Ekle';
$labels['selectmedia']    = 'Görüntü Seç';
$labels['addmedia']       = 'Görüntü Ekle';
$labels['encrypt']        = 'Şifrele';
$labels['encryptmessage'] = 'İletiyi Şifrele';
$labels['encryptmessagemailvelope'] = 'İletinizi Mailvelope ile şifreleyin';
$labels['importpubkeys']  = 'Genel Anahtarları İçeri Aktar';
$labels['encryptedsendialog'] = 'Şifreli ileti gönderiliyor';
$labels['keyid']          = 'Kimlik Anahtarı';
$labels['keylength']      = 'Bit';
$labels['keyexpired']     = 'Süre Doldu';
$labels['keyrevoked']     = 'İptal Edilen';
$labels['bccinstead']     = 'Gizli Kopya Kullanılsın';
$labels['addheader']      = 'Alıcı Ekle (üst Bilgi)';
$labels['editidents']    = 'Kimlikleri Düzenle';
$labels['spellcheck']    = 'Yazım Denetimi';
$labels['checkspelling'] = 'Yazımı Denetle';
$labels['resumeediting'] = 'Düzenlemeyi Sürdür';
$labels['revertto']      = 'Geri Al:';
$labels['restore'] = 'Geri Yükle';
$labels['restoremessage'] = 'İleti geri yüklensin mi?';
$labels['ignore'] = 'Yoksay';
$labels['responses'] = 'Hazır Yanıtlar';
$labels['insertresponse'] = 'Hazır Yanıt Ekle';
$labels['manageresponses'] = 'Hazır Yanıt Yönetimi';
$labels['newresponse'] = 'Yeni Hazır Yanıt Ekle';
$labels['addresponse'] = 'Hazır Yanıt Ekle';
$labels['editresponse'] = 'Hazır Cevabı Düzenle';
$labels['editresponses'] = 'Hazır Yanıtları Düzenle';
$labels['responsename'] = 'Ad';
$labels['responsetext'] = 'Hazır Yanıt Metni';
$labels['attach'] = 'Dosya Ekle';
$labels['attachments'] = 'Ek Dosyalar';
$labels['upload'] = 'Yükle';
$labels['uploadprogress'] = '$percent($current / $total)';
$labels['close']  = 'Kapat';
$labels['messageoptions']  = 'İleti Ayarları...';
$labels['togglecomposeoptions'] = 'Oluşturma ayarlarını görüntüle/gizle';
$labels['attachmentrename']  = 'Ek Dosyaları Yeniden Adlandır.';
$labels['low']     = 'Düşük';
$labels['lowest']  = 'En Düşük';
$labels['normal']  = 'Normal';
$labels['high']    = 'Yüksek';
$labels['highest'] = 'En yüksek';
$labels['nosubject']  = '(Konu Belirtilmemiş)';
$labels['showimages'] = 'Görselleri Görüntüle';
$labels['allow']      = 'İzin Ver';
$labels['alwaysshow'] = '$sender tarafından gönderilen görseller her zaman görüntülensin';
$labels['alwaysallow'] = '$sender tarafından gönderilen iletiler her zaman alınsın';
$labels['isdraft']    = 'Bu ileti henüz taslak.';
$labels['andnmore']   = '$nr daha...';
$labels['headers']    = 'Üst Bilgiler';
$labels['envelope']   = 'Zarf';
$labels['togglemoreheaders'] = 'Daha fazla ileti başlığı görüntüle';
$labels['togglefullheaders'] = 'İleti başlıklarını görüntüle/gizle';
$labels['htmltoggle'] = 'HTML';
$labels['plaintoggle'] = 'Düz Metin';
$labels['savesentmessagein'] = 'Gönderilen İleti Şuraya Kaydedilsin';
$labels['dontsave'] = 'kaydedilmesin';
$labels['maxuploadsize'] = 'İzin verilen en büyük dosya boyutu $size';
$labels['addcc'] = 'Kopya Ekle';
$labels['addbcc'] = 'Gizli Kopya Ekle';
$labels['addreplyto'] = 'Yanıtlama Adresi Ekle';
$labels['addfollowupto'] = 'İzleme Adresi Ekle';
$labels['mdnrequest'] = 'Bu iletiyi gönderen kişi, okuduğunuza dair onay istedi. Onay göndermek ister misiniz ?';
$labels['receiptread'] = 'Alındı Onayı (okundu)';
$labels['yourmessage'] = 'İletinizin Okundu Onayı';
$labels['receiptnote'] = 'Not: Bu okundu onayı iletinizin yalnız alıcının bilgisayarında görüntülendiğini belirtir. Alıcının ileti içeriğini okuduğunu ya da anladığını kanıtlamaz.';
$labels['name']         = 'Görüntülenecek Ad';
$labels['firstname']    = 'Ad';
$labels['surname']      = 'Soyad';
$labels['middlename']   = 'İkinci Ad';
$labels['nameprefix']   = 'Ön Ek';
$labels['namesuffix']   = 'Son Ek';
$labels['nickname']     = 'Takma Ad';
$labels['jobtitle']     = 'İş Unvanı';
$labels['department']   = 'Bölüm';
$labels['gender']       = 'Cinsiyet';
$labels['maidenname']   = 'Kızlık Soyadı';
$labels['email']        = 'E-Posta';
$labels['phone']        = 'Telefon';
$labels['address']      = 'Adres';
$labels['street']       = 'Sokak';
$labels['locality']     = 'Şehir';
$labels['zipcode']      = 'Posta Kodu';
$labels['region']       = 'Bölge';
$labels['country']      = 'Ülke';
$labels['birthday']     = 'Doğum Günü';
$labels['anniversary']  = 'Yıl Dönümü';
$labels['website']      = 'Web Sayfası';
$labels['instantmessenger'] = 'Anlık İletişim';
$labels['notes'] = 'Notlar';
$labels['male']   = 'Erkek';
$labels['female'] = 'Kadın';
$labels['manager'] = 'Yönetici';
$labels['assistant'] = 'Yardımcı';
$labels['spouse'] = 'Eş';
$labels['allfields'] = 'Tüm Alanlar';
$labels['search'] = 'Ara';
$labels['searchresult'] = 'Arama Sonucu';
$labels['advsearch'] = 'Gelişmiş Arama';
$labels['advanced'] = 'Gelişmiş';
$labels['other'] = 'Diğer';
$labels['printcontact'] = 'Kişiyi yazdır';
$labels['qrcode'] = 'QR Kodu';
$labels['typehome']   = 'Ev';
$labels['typework']   = 'İş';
$labels['typeother']  = 'Diğer';
$labels['typemobile']  = 'Cep Telefonu';
$labels['typemain']  = 'Ana';
$labels['typehomefax']  = 'Ev Faksı';
$labels['typeworkfax']  = 'İş Faksı';
$labels['typecar']  = 'Araç';
$labels['typepager']  = 'Çağrı Cihazı';
$labels['typevideo']  = 'Görüntülü';
$labels['typeassistant']  = 'Yardımcı';
$labels['typehomepage']  = 'Web Sitesi';
$labels['typeblog'] = 'Günlük';
$labels['typeprofile'] = 'Profil';
$labels['addfield'] = 'Alan Ekle...';
$labels['addcontact'] = 'Kişi Ekle';
$labels['editcontact'] = 'Kişiyi Düzenle';
$labels['contacts'] = 'Kişiler';
$labels['contactproperties'] = 'Kişi Bilgileri';
$labels['contactnameandorg'] = 'Ad ve Kuruluş';
$labels['personalinfo'] = 'Kişisel Bilgiler';
$labels['personal'] = 'Kişisel';
$labels['contactphoto'] = 'Fotoğraf';
$labels['edit']   = 'Düzenle';
$labels['cancel'] = 'İptal';
$labels['save']   = 'Kaydet';
$labels['delete'] = 'Sil';
$labels['discard'] = 'Yoksay';
$labels['continue'] = 'Devam et';
$labels['ok'] = 'Tamam';
$labels['rename'] = 'Yeniden Adlandır';
$labels['addphoto'] = 'Ekle';
$labels['replacephoto'] = 'Değiştir';
$labels['uploadphoto'] = 'Fotoğraf Yükle';
$labels['newcontact']     = 'Yeni Kişi Ekle';
$labels['deletecontact']  = 'Seçilmiş Kişileri Sil';
$labels['composeto']      = 'Şu Kişiye İleti Gönder';
$labels['contactsfromto'] = 'Kişiler: $from - $to , Toplam: $count';
$labels['print']          = 'Yazdır';
$labels['export']         = 'Dışa Aktar';
$labels['exportall']      = 'Tümünü Dışa Aktar';
$labels['exportsel']      = 'Seçilmişleri Dışa Aktar';
$labels['exportvcards']   = 'Kişileri vCard Biçiminde Dışa Aktar';
$labels['newgroup']       = 'Yeni Grup Ekle';
$labels['addgroup']       = 'Grup Ekle';
$labels['grouprename']    = 'Grubu Yeniden Adlandır';
$labels['groupdelete']    = 'Grubu Sil';
$labels['groupremoveselected'] = 'Seçilmiş Kişileri Gruptan Çıkar';
$labels['uponelevel']     = 'Bir Düzey Yukarı';
$labels['previouspage']   = 'Önceki Sayfayı Görüntüle';
$labels['firstpage']      = 'İlk Sayfayı Görüntüle';
$labels['nextpage']       = 'Sonraki Sayfayı Görüntüle';
$labels['lastpage']       = 'Son Sayfayı Görüntüle';
$labels['group'] = 'Grup';
$labels['groups'] = 'Gruplar';
$labels['listgroup'] = 'Grup Üyelerini Listele';
$labels['personaladrbook'] = 'Adresler';
$labels['searchsave'] = 'Aramayı Kaydet';
$labels['searchdelete'] = 'Aramayı Sil';
$labels['import'] = 'İçe Aktar';
$labels['importcontacts'] = 'Kişileri İçe Aktar';
$labels['importfromfile'] = 'Dosyadan İçe Aktar:';
$labels['importtarget'] = 'Kişileri Ekle';
$labels['importreplace'] = 'Tüm adres defterinin yerine geçsin';
$labels['importgroups'] = 'Grup Atamalarını İçe Aktar';
$labels['importgroupsall'] = 'Tümü (Gerekirse Gruplar Eklensin)';
$labels['importgroupsexisting'] = 'Yalnız Varolan Gruplar';
$labels['importdesc'] = 'Varolan bir adres defterinden kişileri yükleyebilirsiniz.<br/> Şu anda <a href="http://en.wikipedia.org/wiki/VCard">vCard</a> ya da CSV (virgülle ayrılmış) veri biçimleri desteklenmektedir.';
$labels['done'] = 'Tamam';
$labels['settingsfor'] = 'Şunun Ayarları';
$labels['about'] = 'Hakkında';
$labels['preferences'] = 'Ayarlar';
$labels['userpreferences'] = 'Kullanıcı Ayarları';
$labels['editpreferences'] = 'Kullanıcı Ayarlarını Düzenle';
$labels['identities'] = 'Kimlikler';
$labels['manageidentities'] = 'Kimlik Yönetimi';
$labels['newidentity'] = 'Yeni Kimlik Ekle';
$labels['addidentity'] = 'Kimlik Ekle';
$labels['editidentity'] = 'Kimliği Düzenle';
$labels['preferhtml'] = 'HTML Görünüm Kullanılsın';
$labels['defaultcharset'] = 'Varsayılan Karakter Kümesi';
$labels['htmlmessage'] = 'HTML İleti';
$labels['messagepart'] = 'Parça';
$labels['digitalsig'] = 'Dijital İmza';
$labels['dateformat'] = 'Tarih Biçimi';
$labels['timeformat'] = 'Saat Biçimi';
$labels['prettydate'] = 'Tarihler Kısa Görüntülensin';
$labels['setdefault']  = 'Varsayılan Olarak Atansın';
$labels['autodetect']  = 'Otomatik';
$labels['language']  = 'Dil';
$labels['timezone']  = 'Saat Dilimi';
$labels['pagesize']  = 'Bir Sayfadaki Satır Sayısı';
$labels['signature'] = 'İmza';
$labels['dstactive']  = 'Yaz Saati Uygulaması';
$labels['showinextwin'] = 'İleti Yeni Pencerede Açılsın';
$labels['composeextwin'] = 'İleti Yeni Pencerede Oluşturulsun';
$labels['htmleditor'] = 'HTML İleti Kullanımı';
$labels['htmlonreply'] = 'yalnız HTML biçimindeki iletiler yanıtlanırken';
$labels['htmlonreplyandforward'] = 'HTML biçimindeki iletiler yanıtlanırken ya da iletilirken';
$labels['htmlsignature'] = 'HTML İmza';
$labels['showemail'] = 'E-posta adresi görüntülenecek ad ile birlikte görüntülensin';
$labels['previewpane'] = 'Önizleme Panosu Görüntülensin';
$labels['skin'] = 'Arayüz Görünümü';
$labels['logoutclear'] = 'Oturum Kapatıldığında Çöp Boşaltılsın';
$labels['logoutcompact'] = 'Oturum Kapatıldığında Gelen Kutusu Sıkıştırılsın';
$labels['uisettings'] = 'Kullanıcı Arayüzü';
$labels['serversettings'] = 'Sunucu Ayarları';
$labels['mailboxview'] = 'Posta Kutusu Görünümü';
$labels['mdnrequests'] = 'Alındı Onayları';
$labels['askuser'] = 'ne yapılacağı bana sorulsun';
$labels['autosend'] = 'otomatik olarak gönderilsin';
$labels['autosendknown'] = 'adres defterimdekilere gönderilsin, diğerleri bana sorulsun';
$labels['autosendknownignore'] = 'adres defterimdekilere gönderilsin, diğerleri yoksayılsın';
$labels['ignorerequest'] = 'yoksayılsın';
$labels['readwhendeleted'] = 'Silinen İletiler Okunmuş Olarak İşaretlensin';
$labels['flagfordeletion'] = 'İletiler Silinmek Yerine Silinecek Olarak İşaretlensin';
$labels['skipdeleted'] = 'Silinmiş İletiler Görüntülenmesin';
$labels['deletealways'] = 'İletiler Çöpe Atılırken Sorun Çıkarsa Tamamen Silinsin';
$labels['deletejunk'] = 'İstenmeyenler Klasöründeki İletiler Doğrudan Silinsin';
$labels['showremoteimages'] = 'Uzaktan Yüklenen Görseller Görüntülensin';
$labels['allowremoteresources'] = 'Uzak kaynaklar (görseller, biçemler) kullanılabilsin';
$labels['fromknownsenders'] = 'bilinen göndericilerden';
$labels['always'] = 'her zaman';
$labels['alwaysbutplain'] = 'her zaman, düz metin biçiminde yanıtlama dışında';
$labels['showinlineimages'] = 'İleti Ekindeki Görseller İletinin Altında Görüntülensin';
$labels['autosavedraft']  = 'Taslaklar Otomatik Olarak Kaydedilsin';
$labels['everynminutes']  = '$n dakikada bir';
$labels['refreshinterval']  = 'Yenileme (yeni iletileri denetle, vb.)';
$labels['never']  = 'asla';
$labels['immediately']  = 'hemen';
$labels['messagesdisplaying'] = 'İleti Görünümü';
$labels['messagescomposition'] = 'Yeni İleti Oluşturma';
$labels['mimeparamfolding'] = 'Ek Dosya Adları';
$labels['2231folding'] = 'Tam RFC 2231 (Thunderbird)';
$labels['miscfolding'] = 'RFC 2047/2231 (MS Outlook)';
$labels['2047folding'] = 'Tam RFC 2047 (diğer)';
$labels['force7bit'] = '8 Bitlik Karakterler İçin MIME Kodlaması Kullanılsın';
$labels['savelocalstorage'] = "Tarayıcının Yerel Disk Alanına Kaydedilsin (geçiçi olarak)";
$labels['advancedoptions'] = 'Gelişmiş Ayarlar';
$labels['toggleadvancedoptions'] = 'Gelişmiş ayarları görüntüle/gizle';
$labels['focusonnewmessage'] = 'Yeni İleti Geldiğinde Web Tarayıcı Penceresine Odaklanılsın';
$labels['checkallfolders'] = 'Tüm Klasörler İçin Yeni İletiler Denetlensin';
$labels['displaynext'] = 'İleti Silindiğinde ya da Taşındığında Sonraki İleti Görüntülensin';
$labels['defaultfont'] = 'HTML İletiler İçin Varsayılan Yazı Türü';
$labels['mainoptions'] = 'Temel Ayarlar';
$labels['browseroptions'] = 'Tarayıcı Ayarları';
$labels['section'] = 'Bölüm';
$labels['maintenance'] = 'Bakım';
$labels['newmessage'] = 'Yeni İleti';
$labels['signatureoptions'] = 'İmza Ayarları';
$labels['whenreplying'] = 'Yanıtlarken özgün ileti';
$labels['replyempty'] = 'alıntılanmasın';
$labels['replytopposting'] = 'yeni postayı alıntı metninin üstünden başlat';
$labels['replytoppostingnoindent'] = 'yeni ileti alıntı metninin üzerinden başlatılsın (girinti olmadan)';
$labels['replybottomposting'] = 'yeni postayı alıntı metninden sonra başlat';
$labels['replyremovesignature'] = 'Yanıtlarken önceki imzaları sil';
$labels['autoaddsignature'] = 'İmza Otomatik Olarak Eklensin';
$labels['newmessageonly'] = 'yalnız yeni iletilere';
$labels['replyandforwardonly'] = 'yalnız yanıt ve iletmelere';
$labels['insertsignature'] = 'İmza ekle';
$labels['sigbelow'] = 'İmza Alıntı Metninin Altına Eklensin';
$labels['sigseparator'] = 'İmza Eklenirken Standart Ayıraç Kullanılsın';
$labels['automarkread']  = 'İletileri okunmuş olarak işaretle';
$labels['afternseconds']  = '$n saniye sonra';
$labels['reqmdn'] = 'Her Zaman Alındı Onayı İstensin';
$labels['reqdsn'] = 'Her Zaman Teslim Edildi Onayı İstensin';
$labels['replysamefolder'] = 'Yanıtlar İletinin Bulunduğu Klasöre Kaydedilsin';
$labels['defaultabook'] = 'Varsayılan Adres Defteri';
$labels['autocompletesingle'] = 'Otomatik Tamamlamalarda Alternatif E-posta Adresleri Atlansın';
$labels['listnamedisplay'] = 'Kişi Görünümü';
$labels['spellcheckbeforesend'] = 'İleti Gönderilmeden Önce Yazımı Denetlensin';
$labels['spellcheckoptions'] = 'Yazım Denetimi Ayarları';
$labels['spellcheckignoresyms'] = 'İçinde Simge Geçen Sözcükler Yoksayılsın';
$labels['spellcheckignorenums'] = 'İçinde Rakam Geçen Sözcükler Yoksayılsın';
$labels['spellcheckignorecaps'] = 'Tümü Büyük Harf Olan Sözcükler Yoksayılsın';
$labels['addtodict'] = 'Sözlüğe Ekle';
$labels['mailtoprotohandler'] = 'mailto: Bağlantıları İçin Kullanılacak İşleyici';
$labels['standardwindows'] = 'Açılır Pencereler Standart Pencere Olarak Kabul Edilsin';
$labels['forwardmode'] = 'İletiler İletilirken';
$labels['inline'] = 'iletinin içinde';
$labels['asattachment'] = 'dosya eki olarak eklensin';
$labels['replyallmode'] = '[Toplu Yanıt] Düğmesi Varsayılan Olarak';
$labels['replyalldefault'] = 'Toplu yanıtlasın';
$labels['replyalllist'] = 'Yalnız postalama listesindekileri yanıtlasın (varsa)';
$labels['folder'] = 'Klasör';
$labels['folders'] = 'Klasörler';
$labels['foldername'] = 'Klasör Adı';
$labels['subscribed'] = 'Abonelik';
$labels['messagecount'] = 'İletiler';
$labels['create'] = 'Ekle';
$labels['createfolder'] = 'Yeni Klasör Ekle';
$labels['managefolders'] = 'Klasör Yönetimi';
$labels['specialfolders'] = 'Özel Klasörler';
$labels['properties'] = 'Özellikler';
$labels['folderproperties'] = 'Klasör Özellikleri';
$labels['parentfolder'] = 'Üst Klasör';
$labels['location'] = 'Konum';
$labels['info'] = 'Bilgiler';
$labels['getfoldersize'] = 'Klasör büyüklüğünü öğrenmek için tıklayın';
$labels['changesubscription'] = 'Abonelik durumunu değiştirmek için tıklayın';
$labels['foldertype'] = 'Klasör Türü';
$labels['personalfolder'] = 'Kişisel Klasör';
$labels['otherfolder'] = 'Diğer Kullanıcıların Klasörü';
$labels['sharedfolder'] = 'Herkese Açık Klasör';
$labels['findfolders'] = 'Klasör Arama';
$labels['findcontacts'] = 'Kişi arama';
$labels['findmail'] = 'E-posta arama';
$labels['namespace.personal'] = 'Kişisel';
$labels['namespace.other'] = 'Diğer Kullanıcılar';
$labels['namespace.shared'] = 'Paylaşılan';
$labels['dualuselabel'] = 'Yalnız şunu içerebilir';
$labels['dualusemail'] = 'iletiler';
$labels['dualusefolder'] = 'klasörler';
$labels['sortby'] = 'Sıralama';
$labels['sortasc']  = 'Artan';
$labels['sortdesc'] = 'Azalan';
$labels['undo'] = 'Geri Al';
$labels['installedplugins'] = 'Yüklü Uygulama Ekleri';
$labels['plugin'] = 'Uygulama Eki';
$labels['version'] = 'Sürüm';
$labels['source'] = 'Kaynak';
$labels['license'] = 'Lisans';
$labels['support'] = 'Destek İsteyin';
$labels['savedsearches'] = 'Kaydedilmiş aramalar';
$labels['dateformatY'] = 'YYYY';
$labels['dateformaty'] = 'YY';
$labels['dateformatm'] = 'AA';
$labels['dateformatd'] = 'GG';
$labels['dateformatj'] = 'G';
$labels['dateformatn'] = 'A';
$labels['B'] = 'B';
$labels['KB'] = 'KB';
$labels['MB'] = 'MB';
$labels['GB'] = 'GB';
$labels['unicode'] = 'Unicode';
$labels['english'] = 'İngilizce';
$labels['westerneuropean'] = 'Batı Avrupa';
$labels['easterneuropean'] = 'Doğu Avrupa';
$labels['southeasterneuropean'] = 'Güneydoğu Avrupa';
$labels['baltic'] = 'Baltık';
$labels['cyrillic'] = 'Kiril';
$labels['arabic'] = 'Arapça';
$labels['greek'] = 'Yunanca';
$labels['hebrew'] = 'İbranice';
$labels['turkish'] = 'Türkçe';
$labels['nordic'] = 'İskandinav';
$labels['thai'] = 'Tay Dili';
$labels['celtic'] = 'Keltik';
$labels['vietnamese'] = 'Vietnamca';
$labels['japanese'] = 'Japonca';
$labels['korean'] = 'Korece';
$labels['chinese'] = 'Çince';
$labels['arialabeltopnav'] = 'Pencere Denetimi';
$labels['arialabeltasknav'] = 'Uygulama Görevleri';
$labels['arialabeltoolbar'] = 'Uygulama Araç Çubuğu';
$labels['arialabelactivetask'] = 'Etkin Görevler';
$labels['arialabelmessagessearchfilter'] = 'İleti Listeleme Süzgeci';
$labels['arialabelmailsearchform'] = 'İleti Arama Formu';
$labels['arialabelcontactsearchform'] = 'Kişi Arama Formu';
$labels['arialabelmailquicksearchbox'] = 'İleti Arama İfadesi';
$labels['arialabelquicksearchbox'] = 'Arama İfadesi';
$labels['arialabelfoldersearchfilter'] = 'Klasör Listeleme Süzgeci';
$labels['arialabelfoldersearchform'] = 'Klasör Arama Formu';
$labels['arialabelfolderlist'] = 'İleti Klasörü Seçimi';
$labels['arialabelmessagelist'] = 'İletileri Listele';
$labels['arialabelmailpreviewframe'] = 'İleti Önizle';
$labels['arialabelmailboxmenu'] = 'Klasör İşlemleri Menüsü';
$labels['arialabellistselectmenu'] = 'Liste Seçme Menüsü';
$labels['arialabelthreadselectmenu'] = 'Sohbet Listeleme Menüsü';
$labels['arialabelmessagelistoptions'] = 'İleti Liste Görünümü ve Sıralama Ayarları';
$labels['arialabelmailimportdialog'] = 'İleti İçe Aktarma Formu';
$labels['arialabelmessagenav'] = 'İleti Gezinmesi';
$labels['arialabelmessagebody'] = 'İleti Metni';
$labels['arialabelmessageactions'] = 'İleti İşlemleri';
$labels['arialabelcontactquicksearch'] = 'Kişi Arama Formu';
$labels['arialabelcontactsearchbox'] = 'Kişi Arama İfadesi';
$labels['arialabelmessageheaders'] = 'İleti Üst Bilgileri';
$labels['arialabelforwardingoptions'] = 'İletme Ayarları';
$labels['arialabelreplyalloptions'] = 'Toplu Yanıt Ayarları';
$labels['arialabelmoremessageactions'] = 'Diğer İleti İşlemleri';
$labels['arialabelmarkmessagesas'] = 'Seçilmiş iletileri şu şekilde işaretle...';
$labels['arialabelcomposeoptions'] = 'İleti Oluşturma Ayarları';
$labels['arialabelresponsesmenu'] = 'Hazır Yanıtlar Menüsü';
$labels['arialabelattachmentuploadform'] = 'Ek Dosya Yükleme Formu';
$labels['arialabelattachmentmenu'] = 'Ek dosya ayarları';
$labels['arialabelmailtomenu'] = 'E-posta Adres Ayarları';
$labels['arialabelattachmentpreview'] = 'Ek Dosya Önizleme';
$labels['ariasummarycomposecontacts'] = 'Kişileri ve grupları alıcı olarak seçmek için listeleme';
$labels['arialabelcontactexportoptions'] = 'Kişi Dışa Aktarma Ayarları';
$labels['arialabelabookgroupoptions'] = 'Adres Defteri/Grubu Ayarları';
$labels['arialabelpreferencesform'] = 'Ayarlar Formu';
$labels['arialabelidentityeditfrom'] = 'Kimlik Düzenleme Formu';
$labels['arialabelresonseeditfrom'] = 'Hazır Yanıt Düzenleme Formu';
$labels['arialabelsearchterms'] = 'Arama İfadeleri';
$labels['arialabeldropactionmenu'] = 'Sürükle Bırak işlem menüsü';
$labels['arialabelheadersmenu'] = 'Alıcı (Üst Bilgi) Ekleme Menüsü';
$labels['helplistnavigation'] = 'Tuştakımı ile gezinme listesi';
$labels['helplistkeyboardnavigation'] = "Yukarı / Aşağı Oklar: Satırı odağa ya da seçime taşır.
Boşluk: Odaklanılmış satırı seçer.
Shift + Yukarı/Aşağı Oklar: Yukarı ya da aşağı ek satır seçer.
Ctrl + Boşluk: Odaklanılmış satırı seçime ekler ya da çıkarır.";
$labels['helplistkeyboardnavmessages'] = "Sağ/Sol Oklar: İleti gruplarını genişletir ya da daraltır (yalnız sohbet kipinde).
Enter: Seçilmiş ya da odaklanılmış iletiyi açar.
Delete: Seçilmiş iletiyi çöpe atar.";
$labels['helplistkeyboardnavcontacts'] = "Enter: Seçilmiş ya da odaklanılmış kişiyi açar.";
?>
