<?php

/*
 +-----------------------------------------------------------------------+
 | localization/<lang>/messages.inc                                      |
 |                                                                       |
 | Localization file of the Roundcube Webmail client                     |
 | Copyright (C) 2005-2015, The Roundcube Dev Team                       |
 |                                                                       |
 | Licensed under the GNU General Public License version 3 or            |
 | any later version with exceptions for skins & plugins.                |
 | See the README file for a full license statement.                     |
 |                                                                       |
 +-----------------------------------------------------------------------+

 For translation see https://www.transifex.com/projects/p/roundcube-webmail/resource/messages/
*/
$messages['errortitle']  = 'Hi ha hagut un error!';
$messages['loginfailed']  = 'L\'accés ha fallat.';
$messages['cookiesdisabled'] = 'El vostre navegador no accepta cookies.';
$messages['sessionerror'] = 'La vostra sessió no existeix o ha expirat.';
$messages['storageerror'] = 'Error de connexió amb el servidor IMAP.';
$messages['servererror'] = 'Error del Servidor!';
$messages['servererrormsg'] = 'Error del Servidor: $msg';
$messages['accountlocked'] = 'Hi ha hagut masses intents d\'entrada erronis. Prova-ho més tard.';
$messages['connerror'] = 'Error de connexió (no s\'ha pogut establir la connexió amb el servidor)!';
$messages['dberror'] = 'Error a la Base de Dades!';
$messages['windowopenerror'] = 'La finestra emergent ha estat bloquejada!';
$messages['requesttimedout'] = 'S\'ha esgotat el temps de la sol·licitud';
$messages['errorreadonly'] = 'No s\'ha pogut de realitzar l\'operació. La carpeta és de només lectura.';
$messages['errornoperm'] = 'No s\'ha pogut realitzar l\'operació. Permís denegat.';
$messages['erroroverquota'] = 'No s\'ha pogut completar l\'operació. No hi ha prou espai lliure al disc dur.';
$messages['erroroverquotadelete'] = 'No hi ha prou espai lliure. Feu servir MAJÚS+SUPR per suprimir el missatge.';
$messages['invalidrequest'] = 'Petició no vàlida! No s\'han desat les dades.';
$messages['invalidhost'] = 'Nom de servidor no vàlid.';
$messages['nomessagesfound'] = 'No s\'han trobat missatges en aquesta bústia.';
$messages['loggedout'] = 'Heu tancat la sessió correctament. A reveure!';
$messages['mailboxempty'] = 'La bústia és buida';
$messages['nomessages'] = 'No hi ha missatges';
$messages['refreshing'] = 'S\'està actualitzant...';
$messages['loading'] = 'S\'està carregant…';
$messages['uploading'] = 'S\'està pujant el fitxer...';
$messages['attaching'] = 'S\'està adjuntant el fitxer...';
$messages['uploadingmany'] = 'S\'estan pujant els fitxers...';
$messages['loadingdata'] = 'S\'estan carregant les dades...';
$messages['checkingmail'] = 'S’està comprovant si hi ha missatges nous…';
$messages['sendingmessage'] = 'S’està enviant el missatge…';
$messages['messagesent'] = 'Missatge enviat correctament.';
$messages['savingmessage'] = 'S\'està desant el missatge...';
$messages['messagesaved'] = 'Missatge desat a Esborranys.';
$messages['successfullysaved'] = 'Desat correctament.';
$messages['savingresponse'] = 'S\'està desant el text de resposta...';
$messages['deleteresponseconfirm'] = 'Esteu segurs de voler suprimir aquest text de resposta?';
$messages['addedsuccessfully'] = 'Contacte afegit correctament a la llibreta d\'adreces.';
$messages['contactexists'] = 'Ja existeix un contacte amb la mateixa adreça de correu electrònic.';
$messages['contactnameexists'] = 'Ja existeix un contacte amb el mateix nom.';
$messages['blockedimages'] = 'Per protegir la vostra privadesa, les imatges remotes han estat bloquejades en aquest missatge.';
$messages['encryptedmessage'] = 'Aquest és un missatge xifrat i no pot ser mostrat. Ho sento!';
$messages['externalmessagedecryption'] = 'Aquest és un missatge encriptat i pot se desencriptat amb un complement del vostre navegador.';
$messages['nopubkeyfor'] = 'No s\'ha trobat una clau pública vàlida per $email';
$messages['nopubkeyforsender'] = 'No s\'ha trobat una clau pública vàlida per la identitat del vostre remitent. Voleu encriptar el missatge només pels destinataris?';
$messages['encryptnoattachments'] = 'No s\'han pogut encriptar els adjunts ja carregats. Si us plau, afegiu-los de nou a l\'editor d\'encriptació.';
$messages['searchpubkeyservers'] = 'Voleu cercar en servidors de claus públiques les vostres claus no trobades?';
$messages['encryptpubkeysfound'] = 'S\'han trobat les següents claus públiques:';
$messages['keyservererror'] = 'No s\'ha pogut obtenir la clau del servidor de claus';
$messages['keyimportsuccess'] = 'La clau pública $key s\'ha important correctament al vostre anell de claus local';
$messages['nocontactsfound'] = 'No s\'ha trobat cap contacte.';
$messages['contactnotfound'] = 'No s\'ha trobat el contacte sol·licitat.';
$messages['contactsearchonly'] = 'Introduïu termes de cerca per trobar contactes';
$messages['sendingfailed'] = 'Error enviant el missatge.';
$messages['senttooquickly'] = 'Si us plau, espereu $sec segon(s) abans d\'enviar aquest missatge.';
$messages['errorsavingsent'] = 'S\'ha produït un error mentre es desava el missatge enviat.';
$messages['errorsaving'] = 'S\'ha produït un error mentre es desava.';
$messages['errormoving'] = 'No s\'ha pogut moure el(s) missatge(s).';
$messages['errorcopying'] = 'No s\'ha pogut copiar el(s) missatge(s).';
$messages['errordeleting'] = 'No s\'ha pogut suprimir el(s) missatge(s).';
$messages['errormarking'] = 'No s\'ha pogut marcar el(s) missatge(s).';
$messages['deletecontactconfirm']  = 'Esteu segurs de voler suprimir el(s) contacte(s) seleccionat(s)?';
$messages['deletegroupconfirm']  = 'Esteu segurs de voler suprimir el grup seleccionat?';
$messages['deletemessagesconfirm'] = 'Esteu segurs de voler suprimir el(s) missatge(s) seleccionat(s)?';
$messages['deletefolderconfirm']  = 'Esteu segurs de voler suprimir aquesta carpeta?';
$messages['purgefolderconfirm']  = 'Esteu segurs de voler suprimir tots els missatges d\'aquesta carpeta?';
$messages['contactdeleting'] = 'S\'està suprimint els contacte(s)...';
$messages['groupdeleting'] = 'S\'està suprimint el grup...';
$messages['folderdeleting'] = 'S\'està suprimint la carpeta...';
$messages['foldermoving'] = 'S\'està movent la carpeta...';
$messages['foldersubscribing'] = 'S\'està subscrivint la carpeta...';
$messages['folderunsubscribing'] = 'S\'està cancel·lant la subscripció de la carpeta...';
$messages['formincomplete'] = 'El formulari no ha estat emplenat completament.';
$messages['noemailwarning'] = 'Si us plau, introduïu una adreça de correu electrònic vàlida.';
$messages['nonamewarning']  = 'Si us plau, introduïu un nom.';
$messages['nopagesizewarning'] = 'Si us plau, introduïu una mida de pàgina.';
$messages['nosenderwarning'] = 'Si us plau, introduïu l\'adreça de correu electrònic del remitent.';
$messages['norecipientwarning'] = 'Si us plau, introduïu com a mínim un destinatari.';
$messages['disclosedreciptitle'] = 'Hi ha masses destinataris públics';
$messages['nosubjectwarning']  = 'El camp "Assumpte" és buit. Voleu introduir-ne un ara?';
$messages['nosubjecttitle']  = 'Sense assumpte';
$messages['nobodywarning'] = 'Voleu enviar aquest missatge sense text?';
$messages['notsentwarning'] = 'El missatge no s\'ha pogut enviar i té canvis no desats. Voleu descartar aquests canvis?';
$messages['restoresavedcomposedata'] = 'S\'ha trobat un missatge començat però que no ha estat enviat.\n\nAssumpte: $subject\nDesat: $date\n\nVoleu recuperar aquest missatge?';
$messages['nosearchname'] = 'Si us plau, introduïu un nom de contacte o una adreça de correu.';
$messages['notuploadedwarning'] = 'Encara no s\'han pujat tots els adjunts. Si us plau, espereu o cancel·leu la pujada.';
$messages['searchsuccessful'] = '$nr missatges trobats.';
$messages['contactsearchsuccessful'] = '$nr contactes trobats.';
$messages['searchnomatch'] = 'No s\'ha trobat cap coincidència.';
$messages['searching'] = 'S\'està cercant...';
$messages['checking'] = 'S\'està comprovant...';
$messages['stillsearching'] = 'Encara s\'està cercant...';
$messages['nospellerrors'] = 'No s\'han trobat errors d\'ortografia.';
$messages['folderdeleted'] = 'Carpeta suprimida correctament.';
$messages['foldersubscribed'] = 'Carpeta subscrita correctament.';
$messages['folderunsubscribed'] = 'Carpeta de-subscrita correctament.';
$messages['folderpurged'] = 'La carpeta ha estat buidada correctament.';
$messages['folderexpunged'] = 'La carpeta ha estat compactada correctament.';
$messages['deletedsuccessfully'] = 'Suprimit correctament.';
$messages['converting'] = 'S\'està traient el format del missatge...';
$messages['messageopenerror'] = 'No s\'ha pogut carregar el missatge del servidor.';
$messages['fileuploaderror'] = 'La pujada del fitxer ha fallat.';
$messages['filesizeerror'] = 'El fitxer pujat excedeix la mida màxima de $size.';
$messages['filecounterror'] = 'Podeu carregar un màxim de $count fitxers alhora.';
$messages['msgsizeerror'] = 'No s\'ha pogut adjuntar el fitxer. S\'ha sobrepassat la mida màxima del missatge ($size).';
$messages['copysuccess'] = 'S\'han copiat $nr contactes correctament.';
$messages['movesuccess'] = 'S\'han mogut $nr contactes correctament.';
$messages['copyerror'] = 'No s\'ha pogut copiar cap contacte.';
$messages['moveerror'] = 'No s\'ha pogut moure cap contacte.';
$messages['sourceisreadonly'] = 'Aquesta adreça és només de lectura.';
$messages['errorsavingcontact'] = 'No s\'ha pogut desar l\'adreça de contacte.';
$messages['movingmessage'] = 'S\'està movent missatge(s)...';
$messages['copyingmessage'] = 'S\'està copiant missatge(s)...';
$messages['copyingcontact'] = 'S\'està copiant contacte(s)...';
$messages['movingcontact'] = 'S\'estan movent els contacte(s)...';
$messages['deletingmessage'] = 'S\'està suprimint missatge(s)...';
$messages['markingmessage'] = 'S\'està marcant missatge(s)...';
$messages['addingmember'] = 'S\'està afegint contacte(s) al grup...';
$messages['removingmember'] = 'S\'està suprimint contacte(s) del grup...';
$messages['receiptsent'] = 'Confirmació de lectura enviada correctament.';
$messages['errorsendingreceipt'] = 'No s\'ha pogut enviar la confirmació.';
$messages['deleteidentityconfirm'] = 'Esteu segurs de voler suprimir aquesta identitat?';
$messages['nodeletelastidentity'] = 'No podeu suprimir aquesta identitat, és l\'última.';
$messages['forbiddencharacter'] = 'El nom de carpeta conté un caràcter no permès.';
$messages['selectimportfile'] = 'Si us plau, seleccioneu un fitxer per pujar.';
$messages['addresswriterror'] = 'La llibreta d\'adreces seleccionada no és modificable.';
$messages['contactaddedtogroup'] = 'S\'han afegit correctament els contactes a aquest grup.';
$messages['contactremovedfromgroup'] = 'S\'han suprimit correctament els contactes d\'aquest grup.';
$messages['nogroupassignmentschanged'] = 'No s\'ha canviat cap assignació de grup.';
$messages['importwait'] = 'S\'està important, espereu si us plau...';
$messages['importformaterror'] = 'La importació ha fallat. El fitxer pujat no és un fitxer de dades vàlid.';
$messages['importconfirm'] = '<b>S\'han importat $inserted contactes correctament</b>';
$messages['importconfirmskipped'] = '<b>S\'han descartat $skipped entrades ja existents</b>';
$messages['importmessagesuccess'] = '<b>S\'han importat $nr missatges correctament</b>';
$messages['importmessageerror'] = 'La importació ha fallat. El fitxer que heu pujat no és un fitxer de missatges vàlid o no és un fitxer de bústia.';
$messages['opnotpermitted'] = 'Operació no permesa!';
$messages['nofromaddress'] = 'No s\'ha trobat l\'adreça de correu electrònic a la identitat seleccionada.';
$messages['editorwarning'] = 'Si canvieu el tipus d\'editor pot ser que perdreu tot el format del text. Voleu continuar?';
$messages['httpreceivedencrypterror'] = 'Hi ha hagut un error fatal de configuració. Contacteu amb el vostre administrador immediatament. <b>El vostre missatge no pot ser enviat.</b>';
$messages['smtpconnerror'] = 'Error SMTP ($code): La connexió al servidor ha fallat.';
$messages['smtpautherror'] = 'Error SMTP ($code): La identificació ha fallat.';
$messages['smtpfromerror'] = 'Error SMTP ($code): No s\'ha pogut posar "$from" com a remitent ($msg).';
$messages['smtptoerror'] = 'Error SMTP ($code): No s\'ha pogut posar "$to" com a destinatari ($msg).';
$messages['smtprecipientserror'] = 'Error SMTP: No s\'ha pogut analitzar la llista de destinataris.';
$messages['smtperror'] = 'Error SMTP: $msg';
$messages['emailformaterror'] = 'Adreça de correu electrònic no vàlida: $email';
$messages['toomanyrecipients'] = 'Hi ha masses destinataris. Reduïu el nombre de destinataris a $max.';
$messages['maxgroupmembersreached'] = 'El nombre de membres del grup excedeix el màxim de $max.';
$messages['internalerror'] = 'S\'ha produït un error intern. Si us plau torneu-ho a provar.';
$messages['contactdelerror'] = 'No s\'han pogut suprimir el(s) contacte(s).';
$messages['contactdeleted'] = 'Contacte(s) suprimit(s) correctament.';
$messages['contactrestoreerror'] = 'No s\'ha pogut restaurar el(s) contacte(s) suprimit(s).';
$messages['contactrestored'] = 'Contacte(s) restaurat(s) correctament.';
$messages['groupdeleted'] = 'Grup suprimit correctament.';
$messages['grouprenamed'] = 'Grup reanomenat correctament.';
$messages['groupcreated'] = 'Grup creat correctament.';
$messages['savedsearchdeleted'] = 'S\'ha suprimit correctament la cerca desada.';
$messages['savedsearchdeleteerror'] = 'No s\'ha pogut suprimir la cerca desada.';
$messages['savedsearchcreated'] = 'S\'ha creat correctament la cerca desada.';
$messages['savedsearchcreateerror'] = 'No s\'ha pogut crear la cerca desada.';
$messages['messagedeleted'] = 'Missatge(s) suprimit(s) correctament.';
$messages['messagemoved'] = 'Missatge(s) mogut(s) correctament.';
$messages['messagemovedtotrash'] = 'El(s) missatge(s) s\'ha(n) mogut correctament a la Paperera.';
$messages['messagecopied'] = 'Missatge(s) copiat(s) correctament.';
$messages['messagemarked'] = 'Missatge(s) marcat(s) correctament.';
$messages['autocompletechars'] = 'Introduïu com a mínim $min caràcters per l\'autocompleció.';
$messages['autocompletemore'] = 'S\'han trobat més entrades coincidents. Si us plau, introduïu més caràcters.';
$messages['namecannotbeempty'] = 'El nom no pot estar buit.';
$messages['nametoolong'] = 'El nom és massa llarg.';
$messages['namedotforbidden'] = 'El nom de carpeta no pot començar amb un punt.';
$messages['folderupdated'] = 'La carpeta ha estat actualitzada correctament.';
$messages['foldercreated'] = 'La carpeta ha estat creada correctament.';
$messages['invalidimageformat'] = 'No és un format d\'imatge vàlid.';
$messages['mispellingsfound'] = 'S\'han detectat errors d\'ortografia al missatge.';
$messages['parentnotwritable'] = 'No s\'ha pogut crear/moure la carpeta dins de la carpeta ascendent seleccionada. No hi ha permisos d\'escriptura.';
$messages['messagetoobig'] = 'La part del missatge és massa gran per processar-la.';
$messages['noscriptwarning'] = 'Atenció: Aquest client de correu necessita Javascript! Per a poder fer-lo servir heu d\'activar Javascript a les opcions del navegador.';
$messages['messageissent'] = 'El missatge ja ha estat enviat, però encara no s\'ha desat. Voleu desar-lo ara?';
$messages['errnotfound'] = 'No s\'ha trobat el fitxer';
$messages['errnotfoundexplain'] = 'No s\'ha trobat el recurs sol·licitat!';
$messages['errfailedrequest'] = 'La petició ha fallat';
$messages['errauthorizationfailed'] = 'L\'autorització ha fallat';
$messages['errunauthorizedexplain'] = 'No s\'ha pogut verificar que tingueu accés autoritzat a aquest servei!';
$messages['errrequestcheckfailed'] = 'Ha fallat la verificació de la petició';
$messages['errcontactserveradmin'] = 'Si us plau, contacteu amb el vostre administrador de sistemes.';
$messages['clicktoresumesession'] = 'Feu clic aquí per reprendre la vostre sessió anterior';
$messages['clicktocompose'] = 'Feu clic aquí per editar un nou missatge';
