<?php

/*
 +-----------------------------------------------------------------------+
 | plugins/archive/localization/<lang>.inc                                |
 |                                                                       |
 | Localization file of the Roundcube Webmail Archive plugin             |
 | Copyright (C) 2016, The Roundcube Dev Team                            |
 |                                                                       |
 | Licensed under the GNU General Public License version 3 or            |
 | any later version with exceptions for skins & plugins.                |
 | See the README file for a full license statement.                     |
 |                                                                       |
 +-----------------------------------------------------------------------+

 For translation see https://www.transifex.com/projects/p/roundcube-webmail/resource/plugin-archive/
*/
$labels['buttontext'] = 'Arkivera';
$labels['buttontitle'] = 'Arkivera meddelande';
$labels['archived'] = 'Meddelandet är arkiverat';
$labels['archivedreload'] = 'Meddelandet är arkiverat. Ladda om sidan för att se de nya arkivkatalogerna.';
$labels['archiveerror'] = 'Några meddelanden kunde inte arkiveras';
$labels['archivefolder'] = 'Arkiv';
$labels['settingstitle'] = 'Arkiv';
$labels['archivetype'] = 'Uppdelning av arkiv';
$labels['archivetypeyear'] = 'År (ex. Arkiv/2012)';
$labels['archivetypemonth'] = 'Månad (ex. Arkiv/2012/06)';
$labels['archivetypetbmonth'] = 'Månad - Anpassad för Thunderbird (ex. Arkiv/2012/2012-06)';
$labels['archivetypefolder'] = 'Ursprunglig katalog';
$labels['archivetypesender'] = 'Avsändaradress';
$labels['unkownsender'] = 'Okänd';
$labels['readonarchive'] = 'Märk meddelande som läst vid arkivering';
?>
