<?php

/*
 +-----------------------------------------------------------------------+
 | localization/<lang>/messages.inc                                      |
 |                                                                       |
 | Localization file of the Roundcube Webmail client                     |
 | Copyright (C) 2005-2015, The Roundcube Dev Team                       |
 |                                                                       |
 | Licensed under the GNU General Public License version 3 or            |
 | any later version with exceptions for skins & plugins.                |
 | See the README file for a full license statement.                     |
 |                                                                       |
 +-----------------------------------------------------------------------+

 For translation see https://www.transifex.com/projects/p/roundcube-webmail/resource/messages/
*/
$messages['errortitle']  = 'Villa kom upp!';
$messages['loginfailed']  = 'Innskráning mistókst.';
$messages['cookiesdisabled'] = 'Vafrinn þinn vill ekki taka við vefkökum (cookies).';
$messages['sessionerror'] = 'Innskráningin þín ógild eða útrunnin';
$messages['storageerror'] = 'Tenging við geymsluþjón mistókst.';
$messages['servererror'] = 'Villa í þjóni!';
$messages['servererrormsg'] = 'Villa í þjóni: $msg';
$messages['accountlocked'] = 'Of margar tilraunir til innskráningar. Reyndu aftur síðar.';
$messages['connerror'] = 'Villa í tengingu (mistókst að ná í þjóninn)!';
$messages['dberror'] = 'Villa í gagnagrunni!';
$messages['windowopenerror'] = 'Lokað var á sprettgluggann!';
$messages['requesttimedout'] = 'Fyrirspurn féll á tíma';
$messages['errorreadonly'] = 'Tókst ekki að framkvæma aðgerð. Mappa er skrifvarin.';
$messages['errornoperm'] = 'Tókst ekki að framkvæma aðgerð. Heimild var hafnað.';
$messages['erroroverquota'] = 'Tókst ekki að framkvæma aðgerð. Ekkert laust diskpláss.';
$messages['erroroverquotadelete'] = 'Ekki nægt laust diskpláss. Notaðu SHIFT+DEL til að eyða skeyti.';
$messages['invalidrequest'] = 'Ógild fyrirspurn! Engin gögn voru vistuð.';
$messages['invalidhost'] = 'Ógilt heiti á þjóni.';
$messages['nomessagesfound'] = 'Engin skeyti eru í þessu pósthólfi';
$messages['loggedout'] = 'Þú hefur lokað setunni. Bless í bili!';
$messages['mailboxempty'] = 'Pósthólf er tómt';
$messages['nomessages'] = 'Engin skeyti';
$messages['refreshing'] = 'Endurles...';
$messages['loading'] = 'Hleð...';
$messages['uploading'] = 'Sendi inn skrá...';
$messages['attaching'] = 'Hengi við skrá...';
$messages['uploadingmany'] = 'Sendi inn skrár...';
$messages['loadingdata'] = 'Hleð inn gögnum...';
$messages['checkingmail'] = 'Athuga með ný skeyti...';
$messages['sendingmessage'] = 'Sendi skeyti...';
$messages['messagesent'] = 'Skeytið var sent.';
$messages['savingmessage'] = 'Vista skeyti...';
$messages['messagesaved'] = 'Skeytið vistað í Drög.';
$messages['successfullysaved'] = 'Vistun heppnaðist!';
$messages['savingresponse'] = 'Vista texta svars...';
$messages['deleteresponseconfirm'] = 'Ertu viss um að þú viljir eyða þessum svartexta?';
$messages['addedsuccessfully'] = 'Netfangi var bætt í netfangaskrá.';
$messages['contactexists'] = 'Tengiliður með sama nafn er þegar skráður í netfangaskrána.';
$messages['contactnameexists'] = 'Tengiliður með sama nafn er þegar skráður í netfangaskrána.';
$messages['blockedimages'] = 'Til verndar hafa allar myndir í þessu skeyti verið blokkaðar.';
$messages['encryptedmessage'] = 'Þetta er dulkóðað skeyti og því miður er ekki hægt að birta það';
$messages['externalmessagedecryption'] = 'Þetta er dulritað skeyti og er hægt að afkóða með vafraviðbótinni.';
$messages['nopubkeyfor'] = 'Enginn gildur dreifilykill fannst fyrir $email';
$messages['encryptnoattachments'] = 'Viðhengi sem þegar er búið að senda inn er ekki hægt að dulrita. Bættu þeim við aftur í dulritunarritlinum.';
$messages['searchpubkeyservers'] = 'Viltu leita að þeim lyklum sem vantar á opinberum lyklaþjónum?';
$messages['encryptpubkeysfound'] = 'Eftirfarandi dreifilyklar fundust:';
$messages['keyservererror'] = 'Mistókst að nálgast lykil á lyklaþjóni';
$messages['keyimportsuccess'] = 'Það tókst að flytja $key dreifilykilinn inn í lyklakippuna þína';
$messages['nocontactsfound'] = 'Engir tengiliðir fundust.';
$messages['contactnotfound'] = 'Umbeðinn tengiliður fannst ekki.';
$messages['contactsearchonly'] = 'Settu inn leitartexta til að finna tengiliði';
$messages['sendingfailed'] = 'Sending misheppnaðist.';
$messages['senttooquickly'] = 'Bíða í $sec sekúndu(r) áður en þetta skeyti er sent.';
$messages['errorsavingsent'] = 'Villa kom upp við vistun sends skeytis.';
$messages['errorsaving'] = 'Villa kom upp við vistun.';
$messages['errormoving'] = 'Gat ekki fært skeytið';
$messages['errorcopying'] = 'Gat ekki afritað skeyti(n).';
$messages['errordeleting'] = 'Gat ekki eytt skeytinu';
$messages['errormarking'] = 'Gat ekki merkt skeytið/skeytin.';
$messages['deletecontactconfirm']  = 'Ertu viss um að þú viljir eyða völdum tengiliðum?';
$messages['deletegroupconfirm']  = 'Ertu viss um að þú viljir eyða völdum hópi?';
$messages['deletemessagesconfirm'] = 'Ertu viss um að þú viljir eyða völdum skeytum?';
$messages['deletefolderconfirm']  = 'Ertu viss um að vilja eyða þessari möppu?';
$messages['purgefolderconfirm']  = 'Ertu viss um að þú viljir eyða öllum skeytum í þessari möppu?';
$messages['contactdeleting'] = 'Eyði tengilið(um)...';
$messages['groupdeleting'] = 'Eyði hóp...';
$messages['folderdeleting'] = 'Eyði möppu...';
$messages['foldermoving'] = 'Færi möppu...';
$messages['foldersubscribing'] = 'Tek möppu í áskrift...';
$messages['folderunsubscribing'] = 'Segi upp áskrift að möppu...';
$messages['formincomplete'] = 'Formið var ekki fyllt út að fullu';
$messages['noemailwarning'] = 'Sláðu inn gildt netfang';
$messages['nonamewarning']  = 'Sláðu inn nafn';
$messages['nopagesizewarning'] = 'Sláðu inn síðustærð';
$messages['nosenderwarning'] = 'Settu inn tölvupóstfang sendanda.';
$messages['norecipientwarning'] = 'Í það minnsta einn viðtakandi verður að vera';
$messages['disclosedreciptitle'] = 'Of margir opinberir viðtakendur';
$messages['nosubjectwarning']  = 'Efnislínan er tóm. Viltu slá eitthvað inn í hana?';
$messages['nosubjecttitle']  = 'Án titils';
$messages['nobodywarning'] = 'Viltu senda tómt skeyti?';
$messages['notsentwarning'] = 'Þetta skeyti hefur ekki verið sent og er með óvistaðar breytingar. Viltu henda þessum breytingum?';
$messages['nosearchname'] = 'Sláðu inn nafn eða netfang';
$messages['searchsuccessful'] = '$nr skeyti fundust';
$messages['contactsearchsuccessful'] = '$nr tengiliðir fundust.';
$messages['searchnomatch'] = 'Leit skilaði engu';
$messages['searching'] = 'Leita...';
$messages['checking'] = 'Gái...';
$messages['stillsearching'] = 'Enn að leita...';
$messages['nospellerrors'] = 'Engar innsláttarvillur fundust';
$messages['folderdeleted'] = 'Möppu var eytt';
$messages['foldersubscribed'] = 'Tókst að setja möppu í áskrift.';
$messages['folderunsubscribed'] = 'Tókst að taka möppu úr áskrift.';
$messages['folderpurged'] = 'Tókst að tæma möppu.';
$messages['folderexpunged'] = 'Tókst að þjappa möppu.';
$messages['deletedsuccessfully'] = 'Tókst að eyða.';
$messages['messageopenerror'] = 'Gat ekki hlaðið skeyti inn af póstþjóni.';
$messages['filelinkerror'] = 'Mistókst að hengja við skrá.';
$messages['fileuploaderror'] = 'Innsending skráar mistókst.';
$messages['filecounterror'] = 'Þú getur í mesta lagi sent inn $count skrár í einu.';
$messages['copysuccess'] = 'Tókst að afrita $nr tengiliði';
$messages['movesuccess'] = 'Tókst að færa $nr tengiliði';
$messages['copyerror'] = 'Gat ekki afritað neina tengiliði.';
$messages['moveerror'] = 'Gat ekki fært neina tengiliði.';
$messages['errorsavingcontact'] = 'Gat ekki vistað vistfang tengiliðar.';
$messages['movingmessage'] = 'Færi skeyti...';
$messages['copyingmessage'] = 'Afrita skeyti...';
$messages['copyingcontact'] = 'Afrita tengiliði...';
$messages['movingcontact'] = 'Færi tengiliði...';
$messages['deletingmessage'] = 'Eyði skeytum...';
$messages['markingmessage'] = 'Merki skeyti...';
$messages['addingmember'] = 'Bæti tengiliðum í hópinn...';
$messages['removingmember'] = 'Fjarlægi tengiliði úr hópi...';
$messages['receiptsent'] = 'Tókst að senda leskvittun.';
$messages['errorsendingreceipt'] = 'Gat ekki sent leskvittunina.';
$messages['selectimportfile'] = 'Veldu skrá til að senda inn.';
$messages['addresswriterror'] = 'Valin nafnaskrá er ekki ritanleg.';
$messages['importwait'] = 'Flyt inn, bíddu aðeins...';
$messages['importconfirm'] = '<b>Tókst að flytja inn $inserted tengiliði</b>';
$messages['importconfirmskipped'] = '<b>Sleppti $skipped fyrirliggjandi færslum</b>';
$messages['importmessagesuccess'] = 'Tókst að flytja inn $nr skeyti';
$messages['opnotpermitted'] = 'Aðgerð ekki leyfð!';
$messages['smtpconnerror'] = 'SMTP-villa ($code): Tenging við póstþjón mistókst.';
$messages['smtpautherror'] = 'SMTP-villa ($code): Auðkenning mistókst.';
$messages['smtpfromerror'] = 'SMTP-villa ($code): Mistókst að setja sendanda "$from" ($msg).';
$messages['smtptoerror'] = 'SMTP-villa ($code): Mistókst að bæta við viðtakandanum "$to" ($msg).';
$messages['smtprecipientserror'] = 'SMTP-villa: Mistókst að þátta lista yfir viðtakendur.';
$messages['smtperror'] = 'SMTP villa: $msg';
$messages['emailformaterror'] = 'Ógilt tölvupóstfang: $email';
$messages['toomanyrecipients'] = 'Of margir viðtakendur. Fækkaðu þeim í $max.';
$messages['internalerror'] = 'Innri villa kom upp. Prófaðu aftur.';
$messages['contactdelerror'] = 'Gat ekki eytt tengilið(um).';
$messages['contactdeleted'] = 'Tókst að eyða tengilið(um).';
$messages['contactrestoreerror'] = 'Gat ekki endurheimt eydda tengiliði.';
$messages['contactrestored'] = 'Tókst að endurheimta tengilið(i).';
$messages['groupdeleted'] = 'Tókst að eyða hópi.';
$messages['grouprenamed'] = 'Tókst að endurnefna hóp.';
$messages['groupcreated'] = 'Tókst að búa til hóp.';
$messages['savedsearchdeleted'] = 'Tókst að eyða vistaðri leit.';
$messages['savedsearchdeleteerror'] = 'Gat ekki eytt vistaðri leit.';
$messages['savedsearchcreated'] = 'Tókst að búa til vistaða leit.';
$messages['savedsearchcreateerror'] = 'Gat ekki búið til vistaða leit.';
$messages['messagedeleted'] = 'Tókst að eyða skeyti/skeytum.';
$messages['messagemoved'] = 'Tókst að færa skeyti.';
$messages['messagemovedtotrash'] = 'Tókst að færa skeyti í rusl.';
$messages['messagecopied'] = 'Tókst að afrita skeyti.';
$messages['messagemarked'] = 'Tókst að merkja skeyti.';
$messages['autocompletechars'] = 'Settu inn a.m.k. $min stafi fyrir orðaklárun.';
$messages['namecannotbeempty'] = 'Nafn má ekki vera autt.';
$messages['nametoolong'] = 'Nafn er of langt.';
$messages['namedotforbidden'] = 'Heiti möppu má ekki byrja á punkti.';
$messages['folderupdated'] = 'Tókst að uppfæra möppu';
$messages['foldercreated'] = 'Tókst að búa til möppu.';
$messages['invalidimageformat'] = 'Ekki gilt myndasnið.';
$messages['mispellingsfound'] = 'Stafsetningarvillur fundust í skeytinu.';
$messages['messagetoobig'] = 'Efnishluti skeytisins er of stór til að hægt sé að meðhöndla skeytið.';
$messages['errnotfound'] = 'Skrá fannst ekki';
$messages['errnotfoundexplain'] = 'Umbeðið tilfang fannst ekki!';
$messages['errfailedrequest'] = 'Beiðni misfórst';
$messages['errauthorizationfailed'] = 'Auðkenning mistókst';
$messages['errunauthorizedexplain'] = 'Gat ekki gengið úr skugga um að þú hafir heimild til að nota þessa þjónustu!';
$messages['errcontactserveradmin'] = 'Hafðu samband við kerfisstjóra þjónsins þíns';
$messages['clicktoresumesession'] = 'Smelltu hér til að halda áfram með fyrri setu';
$messages['errcomposesession'] = 'Villa í samningarsetu';
$messages['errcomposesessionexplain'] = 'Umbeðin samningarseta fannst ekki.';
$messages['clicktocompose'] = 'Smelltu hér til að búa til nýtt skeyti';
