<roundcube:object name="doctype" value="html5" />
<html>
<head>
<title><roundcube:object name="pagetitle" /></title>
<roundcube:include file="/includes/links.html" />
</head>
<roundcube:if condition="env:extwin" /><body class="extwin"><roundcube:else /><body><roundcube:endif />

<roundcube:include file="/includes/header.html" />

<div id="mainscreen">

<h1 class="voice"><roundcube:label name="addressbook" /> : <roundcube:label name="importcontacts" /></h1>

<h2 id="aria-label-toolbar" class="voice"><roundcube:label name="arialabeltoolbar" /></h2>
<div id="addressbooktoolbar" class="toolbar" role="toolbar" aria-labelledby="aria-label-toolbar">
	<roundcube:button command="list" type="link" class="button back disabled" classAct="button back" classSel="button back pressed" label="back" />
</div>

<div id="mainscreencontent" class="uibox contentbox">
	<h2 class="boxtitle"><roundcube:label name="importcontacts" /></h2>

	<div id="import-box" class="boxcontent">
		<roundcube:object name="importstep" class="propform" />
		<br/>
		<p class="formbuttons">
		<roundcube:object name="importnav" class="button" />
		</p>
	</div>

</div>
</div>

<roundcube:include file="/includes/footer.html" />

</body>
</html>
