<?php

/*
 +-----------------------------------------------------------------------+
 | plugins/attachment_reminder/localization/<lang>.inc                   |
 |                                                                       |
 | Localization file of the Roundcube Webmail Archive plugin             |
 | Copyright (C) 2013, The Roundcube Dev Team                            |
 |                                                                       |
 | Licensed under the GNU General Public License version 3 or            |
 | any later version with exceptions for skins & plugins.                |
 | See the README file for a full license statement.                     |
 |                                                                       |
 +-----------------------------------------------------------------------+

 For translation see https://www.transifex.com/projects/p/roundcube-webmail/resource/plugin-attachment_reminder/
*/
$messages['forgotattachment'] = "Hawwo jo ferjitten in bestân ta te heakjen?";
$messages['reminderoption'] = "Herinnerje oer ferjitten taheaksels";
$messages['keywords'] = "bestân,triem,hechtsje,ferbûn,taheak,ynsletten,CV,brief";
